BOOT:
        newXS("Bio::Emboss::ajAcdGetAlign", XS_Bio__Emboss_ajAcdGetAlign, file);
        newXS("Bio::Emboss::ajAcdGetArray", XS_Bio__Emboss_ajAcdGetArray, file);
        newXS("Bio::Emboss::ajAcdGetBool", XS_Bio__Emboss_ajAcdGetBool, file);
        newXS("Bio::Emboss::ajAcdGetCodon", XS_Bio__Emboss_ajAcdGetCodon, file);
        newXS("Bio::Emboss::ajAcdGetCpdb", XS_Bio__Emboss_ajAcdGetCpdb, file);
        newXS("Bio::Emboss::ajAcdGetDatafile", XS_Bio__Emboss_ajAcdGetDatafile, file);
        newXS("Bio::Emboss::ajAcdGetDirectory", XS_Bio__Emboss_ajAcdGetDirectory, file);
        newXS("Bio::Emboss::ajAcdGetDirectoryName", XS_Bio__Emboss_ajAcdGetDirectoryName, file);
        newXS("Bio::Emboss::ajAcdGetDirlist", XS_Bio__Emboss_ajAcdGetDirlist, file);
        newXS("Bio::Emboss::ajAcdGetDiscretestates", XS_Bio__Emboss_ajAcdGetDiscretestates, file);
        newXS("Bio::Emboss::ajAcdGetDiscretestatesSingle", XS_Bio__Emboss_ajAcdGetDiscretestatesSingle, file);
        newXS("Bio::Emboss::ajAcdGetDistances", XS_Bio__Emboss_ajAcdGetDistances, file);
        newXS("Bio::Emboss::ajAcdGetFeat", XS_Bio__Emboss_ajAcdGetFeat, file);
        newXS("Bio::Emboss::ajAcdGetFeatout", XS_Bio__Emboss_ajAcdGetFeatout, file);
        newXS("Bio::Emboss::ajAcdGetFilelist", XS_Bio__Emboss_ajAcdGetFilelist, file);
        newXS("Bio::Emboss::ajAcdGetFloat", XS_Bio__Emboss_ajAcdGetFloat, file);
        newXS("Bio::Emboss::ajAcdGetFrequencies", XS_Bio__Emboss_ajAcdGetFrequencies, file);
        newXS("Bio::Emboss::ajAcdGetGraph", XS_Bio__Emboss_ajAcdGetGraph, file);
        newXS("Bio::Emboss::ajAcdGetGraphxy", XS_Bio__Emboss_ajAcdGetGraphxy, file);
        newXS("Bio::Emboss::ajAcdGetInfile", XS_Bio__Emboss_ajAcdGetInfile, file);
        newXS("Bio::Emboss::ajAcdGetInt", XS_Bio__Emboss_ajAcdGetInt, file);
        newXS("Bio::Emboss::ajAcdGetList", XS_Bio__Emboss_ajAcdGetList, file);
        newXS("Bio::Emboss::ajAcdGetListSingle", XS_Bio__Emboss_ajAcdGetListSingle, file);
        newXS("Bio::Emboss::ajAcdGetMatrix", XS_Bio__Emboss_ajAcdGetMatrix, file);
        newXS("Bio::Emboss::ajAcdGetMatrixf", XS_Bio__Emboss_ajAcdGetMatrixf, file);
        newXS("Bio::Emboss::ajAcdGetOutcodon", XS_Bio__Emboss_ajAcdGetOutcodon, file);
        newXS("Bio::Emboss::ajAcdGetOutcpdb", XS_Bio__Emboss_ajAcdGetOutcpdb, file);
        newXS("Bio::Emboss::ajAcdGetOutdata", XS_Bio__Emboss_ajAcdGetOutdata, file);
        newXS("Bio::Emboss::ajAcdGetOutdir", XS_Bio__Emboss_ajAcdGetOutdir, file);
        newXS("Bio::Emboss::ajAcdGetOutdirName", XS_Bio__Emboss_ajAcdGetOutdirName, file);
        newXS("Bio::Emboss::ajAcdGetOutdiscrete", XS_Bio__Emboss_ajAcdGetOutdiscrete, file);
        newXS("Bio::Emboss::ajAcdGetOutdistance", XS_Bio__Emboss_ajAcdGetOutdistance, file);
        newXS("Bio::Emboss::ajAcdGetOutfile", XS_Bio__Emboss_ajAcdGetOutfile, file);
        newXS("Bio::Emboss::ajAcdGetOutfileall", XS_Bio__Emboss_ajAcdGetOutfileall, file);
        newXS("Bio::Emboss::ajAcdGetOutfreq", XS_Bio__Emboss_ajAcdGetOutfreq, file);
        newXS("Bio::Emboss::ajAcdGetOutmatrix", XS_Bio__Emboss_ajAcdGetOutmatrix, file);
        newXS("Bio::Emboss::ajAcdGetOutmatrixf", XS_Bio__Emboss_ajAcdGetOutmatrixf, file);
        newXS("Bio::Emboss::ajAcdGetOutproperties", XS_Bio__Emboss_ajAcdGetOutproperties, file);
        newXS("Bio::Emboss::ajAcdGetOutscop", XS_Bio__Emboss_ajAcdGetOutscop, file);
        newXS("Bio::Emboss::ajAcdGetOuttree", XS_Bio__Emboss_ajAcdGetOuttree, file);
        newXS("Bio::Emboss::ajAcdGetPattern", XS_Bio__Emboss_ajAcdGetPattern, file);
        newXS("Bio::Emboss::ajAcdGetProperties", XS_Bio__Emboss_ajAcdGetProperties, file);
        newXS("Bio::Emboss::ajAcdGetRange", XS_Bio__Emboss_ajAcdGetRange, file);
        newXS("Bio::Emboss::ajAcdGetRegexp", XS_Bio__Emboss_ajAcdGetRegexp, file);
        newXS("Bio::Emboss::ajAcdGetRegexpSingle", XS_Bio__Emboss_ajAcdGetRegexpSingle, file);
        newXS("Bio::Emboss::ajAcdGetReport", XS_Bio__Emboss_ajAcdGetReport, file);
        newXS("Bio::Emboss::ajAcdGetScop", XS_Bio__Emboss_ajAcdGetScop, file);
        newXS("Bio::Emboss::ajAcdGetSelect", XS_Bio__Emboss_ajAcdGetSelect, file);
        newXS("Bio::Emboss::ajAcdGetSelectSingle", XS_Bio__Emboss_ajAcdGetSelectSingle, file);
        newXS("Bio::Emboss::ajAcdGetSeq", XS_Bio__Emboss_ajAcdGetSeq, file);
        newXS("Bio::Emboss::ajAcdGetSeqall", XS_Bio__Emboss_ajAcdGetSeqall, file);
        newXS("Bio::Emboss::ajAcdGetSeqout", XS_Bio__Emboss_ajAcdGetSeqout, file);
        newXS("Bio::Emboss::ajAcdGetSeqoutall", XS_Bio__Emboss_ajAcdGetSeqoutall, file);
        newXS("Bio::Emboss::ajAcdGetSeqoutset", XS_Bio__Emboss_ajAcdGetSeqoutset, file);
        newXS("Bio::Emboss::ajAcdGetSeqset", XS_Bio__Emboss_ajAcdGetSeqset, file);
        newXS("Bio::Emboss::ajAcdGetSeqsetall", XS_Bio__Emboss_ajAcdGetSeqsetall, file);
        newXS("Bio::Emboss::ajAcdGetSeqsetallSingle", XS_Bio__Emboss_ajAcdGetSeqsetallSingle, file);
        newXS("Bio::Emboss::ajAcdGetString", XS_Bio__Emboss_ajAcdGetString, file);
        newXS("Bio::Emboss::ajAcdGetToggle", XS_Bio__Emboss_ajAcdGetToggle, file);
        newXS("Bio::Emboss::ajAcdGetTree", XS_Bio__Emboss_ajAcdGetTree, file);
        newXS("Bio::Emboss::ajAcdGetTreeSingle", XS_Bio__Emboss_ajAcdGetTreeSingle, file);
        newXS("Bio::Emboss::ajAcdGetValue", XS_Bio__Emboss_ajAcdGetValue, file);
        newXS("Bio::Emboss::ajAcdSetControl", XS_Bio__Emboss_ajAcdSetControl, file);
        newXS("Bio::Emboss::ajAcdGetCmdline", XS_Bio__Emboss_ajAcdGetCmdline, file);
        newXS("Bio::Emboss::ajAcdGetInputs", XS_Bio__Emboss_ajAcdGetInputs, file);
        newXS("Bio::Emboss::ajAcdGetProgram", XS_Bio__Emboss_ajAcdGetProgram, file);
        newXS("Bio::Emboss::ajAcdPrintAppl", XS_Bio__Emboss_ajAcdPrintAppl, file);
        newXS("Bio::Emboss::ajAcdPrintQual", XS_Bio__Emboss_ajAcdPrintQual, file);
        newXS("Bio::Emboss::ajAcdPrintType", XS_Bio__Emboss_ajAcdPrintType, file);
        newXS("Bio::Emboss::ajAcdExit", XS_Bio__Emboss_ajAcdExit, file);
        newXS("Bio::Emboss::ajAcdUnused", XS_Bio__Emboss_ajAcdUnused, file);
        newXS("Bio::Emboss::ajAlignDefine", XS_Bio__Emboss_ajAlignDefine, file);
        newXS("Bio::Emboss::ajAlignDefineSS", XS_Bio__Emboss_ajAlignDefineSS, file);
        newXS("Bio::Emboss::ajAlignDefineCC", XS_Bio__Emboss_ajAlignDefineCC, file);
        newXS("Bio::Emboss::ajAlignDel", XS_Bio__Emboss_ajAlignDel, file);
        newXS("Bio::Emboss::ajAlignReset", XS_Bio__Emboss_ajAlignReset, file);
        newXS("Bio::Emboss::ajAlignOpen", XS_Bio__Emboss_ajAlignOpen, file);
        newXS("Bio::Emboss::ajAlignFormatDefault", XS_Bio__Emboss_ajAlignFormatDefault, file);
        newXS("Bio::Emboss::ajAlignGetFilename", XS_Bio__Emboss_ajAlignGetFilename, file);
        newXS("Bio::Emboss::ajAlignGetFormat", XS_Bio__Emboss_ajAlignGetFormat, file);
        newXS("Bio::Emboss::ajAlignFindFormat", XS_Bio__Emboss_ajAlignFindFormat, file);
        newXS("Bio::Emboss::ajAlignValid", XS_Bio__Emboss_ajAlignValid, file);
        newXS("Bio::Emboss::ajAlignNew", XS_Bio__Emboss_ajAlignNew, file);
        newXS("Bio::Emboss::ajAlignWrite", XS_Bio__Emboss_ajAlignWrite, file);
        newXS("Bio::Emboss::ajAlignClose", XS_Bio__Emboss_ajAlignClose, file);
        newXS("Bio::Emboss::ajAlignWriteHeader", XS_Bio__Emboss_ajAlignWriteHeader, file);
        newXS("Bio::Emboss::ajAlignWriteTail", XS_Bio__Emboss_ajAlignWriteTail, file);
        newXS("Bio::Emboss::ajAlignSetHeader", XS_Bio__Emboss_ajAlignSetHeader, file);
        newXS("Bio::Emboss::ajAlignSetHeaderC", XS_Bio__Emboss_ajAlignSetHeaderC, file);
        newXS("Bio::Emboss::ajAlignSetHeaderApp", XS_Bio__Emboss_ajAlignSetHeaderApp, file);
        newXS("Bio::Emboss::ajAlignSetTail", XS_Bio__Emboss_ajAlignSetTail, file);
        newXS("Bio::Emboss::ajAlignSetTailC", XS_Bio__Emboss_ajAlignSetTailC, file);
        newXS("Bio::Emboss::ajAlignSetTailApp", XS_Bio__Emboss_ajAlignSetTailApp, file);
        newXS("Bio::Emboss::ajAlignSetSubTail", XS_Bio__Emboss_ajAlignSetSubTail, file);
        newXS("Bio::Emboss::ajAlignSetSubTailC", XS_Bio__Emboss_ajAlignSetSubTailC, file);
        newXS("Bio::Emboss::ajAlignSetSubTailApp", XS_Bio__Emboss_ajAlignSetSubTailApp, file);
        newXS("Bio::Emboss::ajAlignSetSubHeader", XS_Bio__Emboss_ajAlignSetSubHeader, file);
        newXS("Bio::Emboss::ajAlignSetSubHeaderC", XS_Bio__Emboss_ajAlignSetSubHeaderC, file);
        newXS("Bio::Emboss::ajAlignSetSubHeaderApp", XS_Bio__Emboss_ajAlignSetSubHeaderApp, file);
        newXS("Bio::Emboss::ajAlignSetSubHeaderPre", XS_Bio__Emboss_ajAlignSetSubHeaderPre, file);
        newXS("Bio::Emboss::ajAlignSetMatrixName", XS_Bio__Emboss_ajAlignSetMatrixName, file);
        newXS("Bio::Emboss::ajAlignSetMatrixNameC", XS_Bio__Emboss_ajAlignSetMatrixNameC, file);
        newXS("Bio::Emboss::ajAlignSetMatrixInt", XS_Bio__Emboss_ajAlignSetMatrixInt, file);
        newXS("Bio::Emboss::ajAlignSetMatrixFloat", XS_Bio__Emboss_ajAlignSetMatrixFloat, file);
        newXS("Bio::Emboss::ajAlignSetGapI", XS_Bio__Emboss_ajAlignSetGapI, file);
        newXS("Bio::Emboss::ajAlignSetGapR", XS_Bio__Emboss_ajAlignSetGapR, file);
        newXS("Bio::Emboss::ajAlignSetScoreI", XS_Bio__Emboss_ajAlignSetScoreI, file);
        newXS("Bio::Emboss::ajAlignSetScoreL", XS_Bio__Emboss_ajAlignSetScoreL, file);
        newXS("Bio::Emboss::ajAlignSetScoreR", XS_Bio__Emboss_ajAlignSetScoreR, file);
        newXS("Bio::Emboss::ajAlignSetStats", XS_Bio__Emboss_ajAlignSetStats, file);
        newXS("Bio::Emboss::ajAlignSetSubStandard", XS_Bio__Emboss_ajAlignSetSubStandard, file);
        newXS("Bio::Emboss::ajAlignSetType", XS_Bio__Emboss_ajAlignSetType, file);
        newXS("Bio::Emboss::ajAlignSetExternal", XS_Bio__Emboss_ajAlignSetExternal, file);
        newXS("Bio::Emboss::ajAlignSetRange", XS_Bio__Emboss_ajAlignSetRange, file);
        newXS("Bio::Emboss::ajAlignSetSubRange", XS_Bio__Emboss_ajAlignSetSubRange, file);
        newXS("Bio::Emboss::ajAlignTraceT", XS_Bio__Emboss_ajAlignTraceT, file);
        newXS("Bio::Emboss::ajAlignTrace", XS_Bio__Emboss_ajAlignTrace, file);
        newXS("Bio::Emboss::ajAlignPrintFormat", XS_Bio__Emboss_ajAlignPrintFormat, file);
        newXS("Bio::Emboss::ajAlignConsStats", XS_Bio__Emboss_ajAlignConsStats, file);
        newXS("Bio::Emboss::ajAlignExit", XS_Bio__Emboss_ajAlignExit, file);
        newXS("Bio::Emboss::ajChararrNew", XS_Bio__Emboss_ajChararrNew, file);
        newXS("Bio::Emboss::ajChararrNewL", XS_Bio__Emboss_ajChararrNewL, file);
        newXS("Bio::Emboss::ajChararrDel", XS_Bio__Emboss_ajChararrDel, file);
        newXS("Bio::Emboss::ajChararrGet", XS_Bio__Emboss_ajChararrGet, file);
        newXS("Bio::Emboss::ajChararrPut", XS_Bio__Emboss_ajChararrPut, file);
        newXS("Bio::Emboss::ajChararrChararr", XS_Bio__Emboss_ajChararrChararr, file);
        newXS("Bio::Emboss::ajIntNew", XS_Bio__Emboss_ajIntNew, file);
        newXS("Bio::Emboss::ajIntNewL", XS_Bio__Emboss_ajIntNewL, file);
        newXS("Bio::Emboss::ajIntDel", XS_Bio__Emboss_ajIntDel, file);
        newXS("Bio::Emboss::ajIntGet", XS_Bio__Emboss_ajIntGet, file);
        newXS("Bio::Emboss::ajIntPut", XS_Bio__Emboss_ajIntPut, file);
        newXS("Bio::Emboss::ajIntInc", XS_Bio__Emboss_ajIntInc, file);
        newXS("Bio::Emboss::ajIntDec", XS_Bio__Emboss_ajIntDec, file);
        newXS("Bio::Emboss::ajIntInt", XS_Bio__Emboss_ajIntInt, file);
        newXS("Bio::Emboss::ajIntLen", XS_Bio__Emboss_ajIntLen, file);
        newXS("Bio::Emboss::ajFloatNew", XS_Bio__Emboss_ajFloatNew, file);
        newXS("Bio::Emboss::ajFloatNewL", XS_Bio__Emboss_ajFloatNewL, file);
        newXS("Bio::Emboss::ajFloatDel", XS_Bio__Emboss_ajFloatDel, file);
        newXS("Bio::Emboss::ajFloatGet", XS_Bio__Emboss_ajFloatGet, file);
        newXS("Bio::Emboss::ajFloatPut", XS_Bio__Emboss_ajFloatPut, file);
        newXS("Bio::Emboss::ajFloatFloat", XS_Bio__Emboss_ajFloatFloat, file);
        newXS("Bio::Emboss::ajFloatLen", XS_Bio__Emboss_ajFloatLen, file);
        newXS("Bio::Emboss::ajDoubleNew", XS_Bio__Emboss_ajDoubleNew, file);
        newXS("Bio::Emboss::ajDoubleNewL", XS_Bio__Emboss_ajDoubleNewL, file);
        newXS("Bio::Emboss::ajDoubleDel", XS_Bio__Emboss_ajDoubleDel, file);
        newXS("Bio::Emboss::ajDoubleGet", XS_Bio__Emboss_ajDoubleGet, file);
        newXS("Bio::Emboss::ajDoublePut", XS_Bio__Emboss_ajDoublePut, file);
        newXS("Bio::Emboss::ajDoubleDouble", XS_Bio__Emboss_ajDoubleDouble, file);
        newXS("Bio::Emboss::ajDoubleLen", XS_Bio__Emboss_ajDoubleLen, file);
        newXS("Bio::Emboss::ajShortNew", XS_Bio__Emboss_ajShortNew, file);
        newXS("Bio::Emboss::ajShortNewL", XS_Bio__Emboss_ajShortNewL, file);
        newXS("Bio::Emboss::ajShortDel", XS_Bio__Emboss_ajShortDel, file);
        newXS("Bio::Emboss::ajShortGet", XS_Bio__Emboss_ajShortGet, file);
        newXS("Bio::Emboss::ajShortPut", XS_Bio__Emboss_ajShortPut, file);
        newXS("Bio::Emboss::ajShortShort", XS_Bio__Emboss_ajShortShort, file);
        newXS("Bio::Emboss::ajShortLen", XS_Bio__Emboss_ajShortLen, file);
        newXS("Bio::Emboss::ajLongNew", XS_Bio__Emboss_ajLongNew, file);
        newXS("Bio::Emboss::ajLongNewL", XS_Bio__Emboss_ajLongNewL, file);
        newXS("Bio::Emboss::ajLongDel", XS_Bio__Emboss_ajLongDel, file);
        newXS("Bio::Emboss::ajLongGet", XS_Bio__Emboss_ajLongGet, file);
        newXS("Bio::Emboss::ajLongPut", XS_Bio__Emboss_ajLongPut, file);
        newXS("Bio::Emboss::ajLongLong", XS_Bio__Emboss_ajLongLong, file);
        newXS("Bio::Emboss::ajLongLen", XS_Bio__Emboss_ajLongLen, file);
        newXS("Bio::Emboss::ajFloatParse", XS_Bio__Emboss_ajFloatParse, file);
        newXS("Bio::Emboss::ajFloatStr", XS_Bio__Emboss_ajFloatStr, file);
        newXS("Bio::Emboss::ajFloatTrace", XS_Bio__Emboss_ajFloatTrace, file);
        newXS("Bio::Emboss::ajArrCommaList", XS_Bio__Emboss_ajArrCommaList, file);
        newXS("Bio::Emboss::ajArrIntLine", XS_Bio__Emboss_ajArrIntLine, file);
        newXS("Bio::Emboss::ajInt2dNew", XS_Bio__Emboss_ajInt2dNew, file);
        newXS("Bio::Emboss::ajInt2dNewL", XS_Bio__Emboss_ajInt2dNewL, file);
        newXS("Bio::Emboss::ajInt2dNewLL", XS_Bio__Emboss_ajInt2dNewLL, file);
        newXS("Bio::Emboss::ajInt2dDel", XS_Bio__Emboss_ajInt2dDel, file);
        newXS("Bio::Emboss::ajInt2dGet", XS_Bio__Emboss_ajInt2dGet, file);
        newXS("Bio::Emboss::ajInt2dPut", XS_Bio__Emboss_ajInt2dPut, file);
        newXS("Bio::Emboss::ajInt2dLen", XS_Bio__Emboss_ajInt2dLen, file);
        newXS("Bio::Emboss::ajInt2dInt", XS_Bio__Emboss_ajInt2dInt, file);
        newXS("Bio::Emboss::ajInt3dNew", XS_Bio__Emboss_ajInt3dNew, file);
        newXS("Bio::Emboss::ajInt3dNewL", XS_Bio__Emboss_ajInt3dNewL, file);
        newXS("Bio::Emboss::ajInt3dDel", XS_Bio__Emboss_ajInt3dDel, file);
        newXS("Bio::Emboss::ajInt3dGet", XS_Bio__Emboss_ajInt3dGet, file);
        newXS("Bio::Emboss::ajInt3dPut", XS_Bio__Emboss_ajInt3dPut, file);
        newXS("Bio::Emboss::ajInt3dLen", XS_Bio__Emboss_ajInt3dLen, file);
        newXS("Bio::Emboss::ajInt3dInt", XS_Bio__Emboss_ajInt3dInt, file);
        newXS("Bio::Emboss::ajFloat2dNew", XS_Bio__Emboss_ajFloat2dNew, file);
        newXS("Bio::Emboss::ajFloat2dNewL", XS_Bio__Emboss_ajFloat2dNewL, file);
        newXS("Bio::Emboss::ajFloat2dDel", XS_Bio__Emboss_ajFloat2dDel, file);
        newXS("Bio::Emboss::ajFloat2dGet", XS_Bio__Emboss_ajFloat2dGet, file);
        newXS("Bio::Emboss::ajFloat2dPut", XS_Bio__Emboss_ajFloat2dPut, file);
        newXS("Bio::Emboss::ajFloat2dLen", XS_Bio__Emboss_ajFloat2dLen, file);
        newXS("Bio::Emboss::ajFloat2dFloat", XS_Bio__Emboss_ajFloat2dFloat, file);
        newXS("Bio::Emboss::ajFloat3dNew", XS_Bio__Emboss_ajFloat3dNew, file);
        newXS("Bio::Emboss::ajFloat3dNewL", XS_Bio__Emboss_ajFloat3dNewL, file);
        newXS("Bio::Emboss::ajFloat3dDel", XS_Bio__Emboss_ajFloat3dDel, file);
        newXS("Bio::Emboss::ajFloat3dGet", XS_Bio__Emboss_ajFloat3dGet, file);
        newXS("Bio::Emboss::ajFloat3dPut", XS_Bio__Emboss_ajFloat3dPut, file);
        newXS("Bio::Emboss::ajFloat3dLen", XS_Bio__Emboss_ajFloat3dLen, file);
        newXS("Bio::Emboss::ajFloat3dFloat", XS_Bio__Emboss_ajFloat3dFloat, file);
        newXS("Bio::Emboss::ajDouble2dNew", XS_Bio__Emboss_ajDouble2dNew, file);
        newXS("Bio::Emboss::ajDouble2dNewL", XS_Bio__Emboss_ajDouble2dNewL, file);
        newXS("Bio::Emboss::ajDouble2dDel", XS_Bio__Emboss_ajDouble2dDel, file);
        newXS("Bio::Emboss::ajDouble2dGet", XS_Bio__Emboss_ajDouble2dGet, file);
        newXS("Bio::Emboss::ajDouble2dPut", XS_Bio__Emboss_ajDouble2dPut, file);
        newXS("Bio::Emboss::ajDouble2dLen", XS_Bio__Emboss_ajDouble2dLen, file);
        newXS("Bio::Emboss::ajDouble2dDouble", XS_Bio__Emboss_ajDouble2dDouble, file);
        newXS("Bio::Emboss::ajDouble3dNew", XS_Bio__Emboss_ajDouble3dNew, file);
        newXS("Bio::Emboss::ajDouble3dNewL", XS_Bio__Emboss_ajDouble3dNewL, file);
        newXS("Bio::Emboss::ajDouble3dDel", XS_Bio__Emboss_ajDouble3dDel, file);
        newXS("Bio::Emboss::ajDouble3dGet", XS_Bio__Emboss_ajDouble3dGet, file);
        newXS("Bio::Emboss::ajDouble3dPut", XS_Bio__Emboss_ajDouble3dPut, file);
        newXS("Bio::Emboss::ajDouble3dLen", XS_Bio__Emboss_ajDouble3dLen, file);
        newXS("Bio::Emboss::ajDouble3dDouble", XS_Bio__Emboss_ajDouble3dDouble, file);
        newXS("Bio::Emboss::ajShort2dNew", XS_Bio__Emboss_ajShort2dNew, file);
        newXS("Bio::Emboss::ajShort2dNewL", XS_Bio__Emboss_ajShort2dNewL, file);
        newXS("Bio::Emboss::ajShort2dDel", XS_Bio__Emboss_ajShort2dDel, file);
        newXS("Bio::Emboss::ajShort2dGet", XS_Bio__Emboss_ajShort2dGet, file);
        newXS("Bio::Emboss::ajShort2dPut", XS_Bio__Emboss_ajShort2dPut, file);
        newXS("Bio::Emboss::ajShort2dLen", XS_Bio__Emboss_ajShort2dLen, file);
        newXS("Bio::Emboss::ajShort2dShort", XS_Bio__Emboss_ajShort2dShort, file);
        newXS("Bio::Emboss::ajShort3dNew", XS_Bio__Emboss_ajShort3dNew, file);
        newXS("Bio::Emboss::ajShort3dNewL", XS_Bio__Emboss_ajShort3dNewL, file);
        newXS("Bio::Emboss::ajShort3dDel", XS_Bio__Emboss_ajShort3dDel, file);
        newXS("Bio::Emboss::ajShort3dGet", XS_Bio__Emboss_ajShort3dGet, file);
        newXS("Bio::Emboss::ajShort3dPut", XS_Bio__Emboss_ajShort3dPut, file);
        newXS("Bio::Emboss::ajShort3dLen", XS_Bio__Emboss_ajShort3dLen, file);
        newXS("Bio::Emboss::ajShort3dShort", XS_Bio__Emboss_ajShort3dShort, file);
        newXS("Bio::Emboss::ajLong2dNew", XS_Bio__Emboss_ajLong2dNew, file);
        newXS("Bio::Emboss::ajLong2dNewL", XS_Bio__Emboss_ajLong2dNewL, file);
        newXS("Bio::Emboss::ajLong2dDel", XS_Bio__Emboss_ajLong2dDel, file);
        newXS("Bio::Emboss::ajLong2dGet", XS_Bio__Emboss_ajLong2dGet, file);
        newXS("Bio::Emboss::ajLong2dPut", XS_Bio__Emboss_ajLong2dPut, file);
        newXS("Bio::Emboss::ajLong2dLen", XS_Bio__Emboss_ajLong2dLen, file);
        newXS("Bio::Emboss::ajLong2dLong", XS_Bio__Emboss_ajLong2dLong, file);
        newXS("Bio::Emboss::ajLong3dNew", XS_Bio__Emboss_ajLong3dNew, file);
        newXS("Bio::Emboss::ajLong3dNewL", XS_Bio__Emboss_ajLong3dNewL, file);
        newXS("Bio::Emboss::ajLong3dDel", XS_Bio__Emboss_ajLong3dDel, file);
        newXS("Bio::Emboss::ajLong3dGet", XS_Bio__Emboss_ajLong3dGet, file);
        newXS("Bio::Emboss::ajLong3dPut", XS_Bio__Emboss_ajLong3dPut, file);
        newXS("Bio::Emboss::ajLong3dLen", XS_Bio__Emboss_ajLong3dLen, file);
        newXS("Bio::Emboss::ajLong3dLong", XS_Bio__Emboss_ajLong3dLong, file);
        newXS("Bio::Emboss::ajArrExit", XS_Bio__Emboss_ajArrExit, file);
        newXS("Bio::Emboss::ajBaseCodes", XS_Bio__Emboss_ajBaseCodes, file);
        newXS("Bio::Emboss::ajAZToInt", XS_Bio__Emboss_ajAZToInt, file);
        newXS("Bio::Emboss::ajIntToAZ", XS_Bio__Emboss_ajIntToAZ, file);
        newXS("Bio::Emboss::ajBinToAZ", XS_Bio__Emboss_ajBinToAZ, file);
        newXS("Bio::Emboss::ajAZToBin", XS_Bio__Emboss_ajAZToBin, file);
        newXS("Bio::Emboss::ajAZToBinC", XS_Bio__Emboss_ajAZToBinC, file);
        newXS("Bio::Emboss::ajBaseInit", XS_Bio__Emboss_ajBaseInit, file);
        newXS("Bio::Emboss::ajBaseAa1ToAa3", XS_Bio__Emboss_ajBaseAa1ToAa3, file);
        newXS("Bio::Emboss::ajBaseProb", XS_Bio__Emboss_ajBaseProb, file);
        newXS("Bio::Emboss::ajBaseExit", XS_Bio__Emboss_ajBaseExit, file);
        newXS("Bio::Emboss::ajCall", XS_Bio__Emboss_ajCall, file);
        newXS("Bio::Emboss::ajCallExit", XS_Bio__Emboss_ajCallExit, file);
        newXS("Bio::Emboss::ajCodNew", XS_Bio__Emboss_ajCodNew, file);
        newXS("Bio::Emboss::ajCodNewCode", XS_Bio__Emboss_ajCodNewCode, file);
        newXS("Bio::Emboss::ajCodDup", XS_Bio__Emboss_ajCodDup, file);
        newXS("Bio::Emboss::ajCodDel", XS_Bio__Emboss_ajCodDel, file);
        newXS("Bio::Emboss::ajCodBacktranslate", XS_Bio__Emboss_ajCodBacktranslate, file);
        newXS("Bio::Emboss::ajCodBacktranslateAmbig", XS_Bio__Emboss_ajCodBacktranslateAmbig, file);
        newXS("Bio::Emboss::ajCodBase", XS_Bio__Emboss_ajCodBase, file);
        newXS("Bio::Emboss::ajCodCalcGribskov", XS_Bio__Emboss_ajCodCalcGribskov, file);
        newXS("Bio::Emboss::ajCodCalcNc", XS_Bio__Emboss_ajCodCalcNc, file);
        newXS("Bio::Emboss::ajCodCalculateUsage", XS_Bio__Emboss_ajCodCalculateUsage, file);
        newXS("Bio::Emboss::ajCodClear", XS_Bio__Emboss_ajCodClear, file);
        newXS("Bio::Emboss::ajCodClearData", XS_Bio__Emboss_ajCodClearData, file);
        newXS("Bio::Emboss::ajCodCountTriplets", XS_Bio__Emboss_ajCodCountTriplets, file);
        newXS("Bio::Emboss::ajCodIndex", XS_Bio__Emboss_ajCodIndex, file);
        newXS("Bio::Emboss::ajCodIndexC", XS_Bio__Emboss_ajCodIndexC, file);
        newXS("Bio::Emboss::ajCodRead", XS_Bio__Emboss_ajCodRead, file);
        newXS("Bio::Emboss::ajCodSetBacktranslate", XS_Bio__Emboss_ajCodSetBacktranslate, file);
        newXS("Bio::Emboss::ajCodTriplet", XS_Bio__Emboss_ajCodTriplet, file);
        newXS("Bio::Emboss::ajCodWriteOut", XS_Bio__Emboss_ajCodWriteOut, file);
        newXS("Bio::Emboss::ajCodWrite", XS_Bio__Emboss_ajCodWrite, file);
        newXS("Bio::Emboss::ajCodComp", XS_Bio__Emboss_ajCodComp, file);
        newXS("Bio::Emboss::ajCodCalcCai", XS_Bio__Emboss_ajCodCalcCai, file);
        newXS("Bio::Emboss::ajCodCaiW", XS_Bio__Emboss_ajCodCaiW, file);
        newXS("Bio::Emboss::ajCodCai", XS_Bio__Emboss_ajCodCai, file);
        newXS("Bio::Emboss::ajCodGetName", XS_Bio__Emboss_ajCodGetName, file);
        newXS("Bio::Emboss::ajCodGetNameC", XS_Bio__Emboss_ajCodGetNameC, file);
        newXS("Bio::Emboss::ajCodGetDesc", XS_Bio__Emboss_ajCodGetDesc, file);
        newXS("Bio::Emboss::ajCodGetDescC", XS_Bio__Emboss_ajCodGetDescC, file);
        newXS("Bio::Emboss::ajCodGetSpecies", XS_Bio__Emboss_ajCodGetSpecies, file);
        newXS("Bio::Emboss::ajCodGetSpeciesC", XS_Bio__Emboss_ajCodGetSpeciesC, file);
        newXS("Bio::Emboss::ajCodGetDivision", XS_Bio__Emboss_ajCodGetDivision, file);
        newXS("Bio::Emboss::ajCodGetDivisionC", XS_Bio__Emboss_ajCodGetDivisionC, file);
        newXS("Bio::Emboss::ajCodGetRelease", XS_Bio__Emboss_ajCodGetRelease, file);
        newXS("Bio::Emboss::ajCodGetReleaseC", XS_Bio__Emboss_ajCodGetReleaseC, file);
        newXS("Bio::Emboss::ajCodGetNumcodon", XS_Bio__Emboss_ajCodGetNumcodon, file);
        newXS("Bio::Emboss::ajCodGetNumcds", XS_Bio__Emboss_ajCodGetNumcds, file);
        newXS("Bio::Emboss::ajCodGetCode", XS_Bio__Emboss_ajCodGetCode, file);
        newXS("Bio::Emboss::ajCodAssName", XS_Bio__Emboss_ajCodAssName, file);
        newXS("Bio::Emboss::ajCodAssNameC", XS_Bio__Emboss_ajCodAssNameC, file);
        newXS("Bio::Emboss::ajCodAssDesc", XS_Bio__Emboss_ajCodAssDesc, file);
        newXS("Bio::Emboss::ajCodAssDescC", XS_Bio__Emboss_ajCodAssDescC, file);
        newXS("Bio::Emboss::ajCodAssSpecies", XS_Bio__Emboss_ajCodAssSpecies, file);
        newXS("Bio::Emboss::ajCodAssSpeciesC", XS_Bio__Emboss_ajCodAssSpeciesC, file);
        newXS("Bio::Emboss::ajCodAssRelease", XS_Bio__Emboss_ajCodAssRelease, file);
        newXS("Bio::Emboss::ajCodAssReleaseC", XS_Bio__Emboss_ajCodAssReleaseC, file);
        newXS("Bio::Emboss::ajCodAssDivision", XS_Bio__Emboss_ajCodAssDivision, file);
        newXS("Bio::Emboss::ajCodAssDivisionC", XS_Bio__Emboss_ajCodAssDivisionC, file);
        newXS("Bio::Emboss::ajCodAssNumcodon", XS_Bio__Emboss_ajCodAssNumcodon, file);
        newXS("Bio::Emboss::ajCodAssNumcds", XS_Bio__Emboss_ajCodAssNumcds, file);
        newXS("Bio::Emboss::ajCodAssCode", XS_Bio__Emboss_ajCodAssCode, file);
        newXS("Bio::Emboss::ajCodOutFormat", XS_Bio__Emboss_ajCodOutFormat, file);
        newXS("Bio::Emboss::ajCodPrintFormat", XS_Bio__Emboss_ajCodPrintFormat, file);
        newXS("Bio::Emboss::ajCodGetCodonlist", XS_Bio__Emboss_ajCodGetCodonlist, file);
        newXS("Bio::Emboss::ajCodExit", XS_Bio__Emboss_ajCodExit, file);
        newXS("Bio::Emboss::ajMeltInit", XS_Bio__Emboss_ajMeltInit, file);
        newXS("Bio::Emboss::ajProbScore", XS_Bio__Emboss_ajProbScore, file);
        newXS("Bio::Emboss::ajMeltEnergy", XS_Bio__Emboss_ajMeltEnergy, file);
        newXS("Bio::Emboss::ajTm", XS_Bio__Emboss_ajTm, file);
        newXS("Bio::Emboss::ajMeltGC", XS_Bio__Emboss_ajMeltGC, file);
        newXS("Bio::Emboss::ajMeltEnergy2", XS_Bio__Emboss_ajMeltEnergy2, file);
        newXS("Bio::Emboss::ajTm2", XS_Bio__Emboss_ajTm2, file);
        newXS("Bio::Emboss::ajProdTm", XS_Bio__Emboss_ajProdTm, file);
        newXS("Bio::Emboss::ajAnneal", XS_Bio__Emboss_ajAnneal, file);
        newXS("Bio::Emboss::ajMeltExit", XS_Bio__Emboss_ajMeltExit, file);
        newXS("Bio::Emboss::ajDmxScophitNew", XS_Bio__Emboss_ajDmxScophitNew, file);
        newXS("Bio::Emboss::ajDmxScopalgNew", XS_Bio__Emboss_ajDmxScopalgNew, file);
        newXS("Bio::Emboss::ajDmxScopalgRead", XS_Bio__Emboss_ajDmxScopalgRead, file);
        newXS("Bio::Emboss::ajDmxScophitDel", XS_Bio__Emboss_ajDmxScophitDel, file);
        newXS("Bio::Emboss::ajDmxScophitDelWrap", XS_Bio__Emboss_ajDmxScophitDelWrap, file);
        newXS("Bio::Emboss::ajDmxScopalgDel", XS_Bio__Emboss_ajDmxScopalgDel, file);
        newXS("Bio::Emboss::ajDmxScophitListCopy", XS_Bio__Emboss_ajDmxScophitListCopy, file);
        newXS("Bio::Emboss::ajDmxScophitCopy", XS_Bio__Emboss_ajDmxScophitCopy, file);
        newXS("Bio::Emboss::ajDmxScophitTargetLowPriority", XS_Bio__Emboss_ajDmxScophitTargetLowPriority, file);
        newXS("Bio::Emboss::ajDmxScophitTarget2", XS_Bio__Emboss_ajDmxScophitTarget2, file);
        newXS("Bio::Emboss::ajDmxScophitTarget", XS_Bio__Emboss_ajDmxScophitTarget, file);
        newXS("Bio::Emboss::ajDmxScophitCheckTarget", XS_Bio__Emboss_ajDmxScophitCheckTarget, file);
        newXS("Bio::Emboss::ajDmxScophitCompScore", XS_Bio__Emboss_ajDmxScophitCompScore, file);
        newXS("Bio::Emboss::ajDmxScophitCompPval", XS_Bio__Emboss_ajDmxScophitCompPval, file);
        newXS("Bio::Emboss::ajDmxScophitCompAcc", XS_Bio__Emboss_ajDmxScophitCompAcc, file);
        newXS("Bio::Emboss::ajDmxScophitCompSunid", XS_Bio__Emboss_ajDmxScophitCompSunid, file);
        newXS("Bio::Emboss::ajDmxScophitCompSpr", XS_Bio__Emboss_ajDmxScophitCompSpr, file);
        newXS("Bio::Emboss::ajDmxScophitCompEnd", XS_Bio__Emboss_ajDmxScophitCompEnd, file);
        newXS("Bio::Emboss::ajDmxScophitCompStart", XS_Bio__Emboss_ajDmxScophitCompStart, file);
        newXS("Bio::Emboss::ajDmxScophitCompFam", XS_Bio__Emboss_ajDmxScophitCompFam, file);
        newXS("Bio::Emboss::ajDmxScophitCompSfam", XS_Bio__Emboss_ajDmxScophitCompSfam, file);
        newXS("Bio::Emboss::ajDmxScophitCompClass", XS_Bio__Emboss_ajDmxScophitCompClass, file);
        newXS("Bio::Emboss::ajDmxScophitCompFold", XS_Bio__Emboss_ajDmxScophitCompFold, file);
        newXS("Bio::Emboss::ajDmxScopalgGetseqs", XS_Bio__Emboss_ajDmxScopalgGetseqs, file);
        newXS("Bio::Emboss::ajDmxScophitsWrite", XS_Bio__Emboss_ajDmxScophitsWrite, file);
        newXS("Bio::Emboss::ajDmxScophitsWriteFasta", XS_Bio__Emboss_ajDmxScophitsWriteFasta, file);
        newXS("Bio::Emboss::ajDmxScophitReadFasta", XS_Bio__Emboss_ajDmxScophitReadFasta, file);
        newXS("Bio::Emboss::ajDmxScopalgWrite", XS_Bio__Emboss_ajDmxScopalgWrite, file);
        newXS("Bio::Emboss::ajDmxScopalgWriteClustal", XS_Bio__Emboss_ajDmxScopalgWriteClustal, file);
        newXS("Bio::Emboss::ajDmxScopalgWriteClustal2", XS_Bio__Emboss_ajDmxScopalgWriteClustal2, file);
        newXS("Bio::Emboss::ajDmxScopalgWriteFasta", XS_Bio__Emboss_ajDmxScopalgWriteFasta, file);
        newXS("Bio::Emboss::ajDmxScopSeqFromSunid", XS_Bio__Emboss_ajDmxScopSeqFromSunid, file);
        newXS("Bio::Emboss::ajDmxDummyFunction", XS_Bio__Emboss_ajDmxDummyFunction, file);
        newXS("Bio::Emboss::ajCathReadAllNew", XS_Bio__Emboss_ajCathReadAllNew, file);
        newXS("Bio::Emboss::ajCathReadAllRawNew", XS_Bio__Emboss_ajCathReadAllRawNew, file);
        newXS("Bio::Emboss::ajCathReadCNew", XS_Bio__Emboss_ajCathReadCNew, file);
        newXS("Bio::Emboss::ajCathReadNew", XS_Bio__Emboss_ajCathReadNew, file);
        newXS("Bio::Emboss::ajDomainReadAllNew", XS_Bio__Emboss_ajDomainReadAllNew, file);
        newXS("Bio::Emboss::ajScopReadAllNew", XS_Bio__Emboss_ajScopReadAllNew, file);
        newXS("Bio::Emboss::ajScopReadAllRawNew", XS_Bio__Emboss_ajScopReadAllRawNew, file);
        newXS("Bio::Emboss::ajCathNew", XS_Bio__Emboss_ajCathNew, file);
        newXS("Bio::Emboss::ajDomainNew", XS_Bio__Emboss_ajDomainNew, file);
        newXS("Bio::Emboss::ajScopNew", XS_Bio__Emboss_ajScopNew, file);
        newXS("Bio::Emboss::ajDomainReadNew", XS_Bio__Emboss_ajDomainReadNew, file);
        newXS("Bio::Emboss::ajScopReadNew", XS_Bio__Emboss_ajScopReadNew, file);
        newXS("Bio::Emboss::ajDomainReadCNew", XS_Bio__Emboss_ajDomainReadCNew, file);
        newXS("Bio::Emboss::ajScopReadCNew", XS_Bio__Emboss_ajScopReadCNew, file);
        newXS("Bio::Emboss::ajDomainDel", XS_Bio__Emboss_ajDomainDel, file);
        newXS("Bio::Emboss::ajScopDel", XS_Bio__Emboss_ajScopDel, file);
        newXS("Bio::Emboss::ajCathDel", XS_Bio__Emboss_ajCathDel, file);
        newXS("Bio::Emboss::ajDomainCopy", XS_Bio__Emboss_ajDomainCopy, file);
        newXS("Bio::Emboss::ajCathCopy", XS_Bio__Emboss_ajCathCopy, file);
        newXS("Bio::Emboss::ajScopCopy", XS_Bio__Emboss_ajScopCopy, file);
        newXS("Bio::Emboss::ajScopMatchSunid", XS_Bio__Emboss_ajScopMatchSunid, file);
        newXS("Bio::Emboss::ajScopMatchScopid", XS_Bio__Emboss_ajScopMatchScopid, file);
        newXS("Bio::Emboss::ajScopMatchPdbId", XS_Bio__Emboss_ajScopMatchPdbId, file);
        newXS("Bio::Emboss::ajCathMatchPdbId", XS_Bio__Emboss_ajCathMatchPdbId, file);
        newXS("Bio::Emboss::ajDomainGetId", XS_Bio__Emboss_ajDomainGetId, file);
        newXS("Bio::Emboss::ajDomainGetSeqPdb", XS_Bio__Emboss_ajDomainGetSeqPdb, file);
        newXS("Bio::Emboss::ajDomainGetSeqSpr", XS_Bio__Emboss_ajDomainGetSeqSpr, file);
        newXS("Bio::Emboss::ajDomainGetPdb", XS_Bio__Emboss_ajDomainGetPdb, file);
        newXS("Bio::Emboss::ajDomainGetAcc", XS_Bio__Emboss_ajDomainGetAcc, file);
        newXS("Bio::Emboss::ajDomainGetSpr", XS_Bio__Emboss_ajDomainGetSpr, file);
        newXS("Bio::Emboss::ajDomainGetN", XS_Bio__Emboss_ajDomainGetN, file);
        newXS("Bio::Emboss::ajScopArrFindScopid", XS_Bio__Emboss_ajScopArrFindScopid, file);
        newXS("Bio::Emboss::ajScopArrFindSunid", XS_Bio__Emboss_ajScopArrFindSunid, file);
        newXS("Bio::Emboss::ajScopArrFindPdbid", XS_Bio__Emboss_ajScopArrFindPdbid, file);
        newXS("Bio::Emboss::ajCathArrFindPdbid", XS_Bio__Emboss_ajCathArrFindPdbid, file);
        newXS("Bio::Emboss::ajPdbWriteDomain", XS_Bio__Emboss_ajPdbWriteDomain, file);
        newXS("Bio::Emboss::ajCathWrite", XS_Bio__Emboss_ajCathWrite, file);
        newXS("Bio::Emboss::ajDomainWrite", XS_Bio__Emboss_ajDomainWrite, file);
        newXS("Bio::Emboss::ajScopWrite", XS_Bio__Emboss_ajScopWrite, file);
        newXS("Bio::Emboss::ajDomainDCFType", XS_Bio__Emboss_ajDomainDCFType, file);
        newXS("Bio::Emboss::ajDomainDummyFunction", XS_Bio__Emboss_ajDomainDummyFunction, file);
        newXS("Bio::Emboss::ajFeattabOutOpen", XS_Bio__Emboss_ajFeattabOutOpen, file);
        newXS("Bio::Emboss::ajFeattabOutFile", XS_Bio__Emboss_ajFeattabOutFile, file);
        newXS("Bio::Emboss::ajFeattabOutFilename", XS_Bio__Emboss_ajFeattabOutFilename, file);
        newXS("Bio::Emboss::ajFeattabOutIsOpen", XS_Bio__Emboss_ajFeattabOutIsOpen, file);
        newXS("Bio::Emboss::ajFeattabOutIsLocal", XS_Bio__Emboss_ajFeattabOutIsLocal, file);
        newXS("Bio::Emboss::ajFeattabOutSet", XS_Bio__Emboss_ajFeattabOutSet, file);
        newXS("Bio::Emboss::ajFeattabInNew", XS_Bio__Emboss_ajFeattabInNew, file);
        newXS("Bio::Emboss::ajFeattabInNewSS", XS_Bio__Emboss_ajFeattabInNewSS, file);
        newXS("Bio::Emboss::ajFeattabInNewSSF", XS_Bio__Emboss_ajFeattabInNewSSF, file);
        newXS("Bio::Emboss::ajFeattabOutNew", XS_Bio__Emboss_ajFeattabOutNew, file);
        newXS("Bio::Emboss::ajFeattabOutSetBasename", XS_Bio__Emboss_ajFeattabOutSetBasename, file);
        newXS("Bio::Emboss::ajFeattabOutNewSSF", XS_Bio__Emboss_ajFeattabOutNewSSF, file);
        newXS("Bio::Emboss::ajFeatRead", XS_Bio__Emboss_ajFeatRead, file);
        newXS("Bio::Emboss::ajFeatNew", XS_Bio__Emboss_ajFeatNew, file);
        newXS("Bio::Emboss::ajFeatNewII", XS_Bio__Emboss_ajFeatNewII, file);
        newXS("Bio::Emboss::ajFeatNewIIRev", XS_Bio__Emboss_ajFeatNewIIRev, file);
        newXS("Bio::Emboss::ajFeatNewProt", XS_Bio__Emboss_ajFeatNewProt, file);
        newXS("Bio::Emboss::ajFeattabInDel", XS_Bio__Emboss_ajFeattabInDel, file);
        newXS("Bio::Emboss::ajFeattableDel", XS_Bio__Emboss_ajFeattableDel, file);
        newXS("Bio::Emboss::ajFeatDel", XS_Bio__Emboss_ajFeatDel, file);
        newXS("Bio::Emboss::ajFeatUfoWrite", XS_Bio__Emboss_ajFeatUfoWrite, file);
        newXS("Bio::Emboss::ajFeattableWrite", XS_Bio__Emboss_ajFeattableWrite, file);
        newXS("Bio::Emboss::ajFeatSortByType", XS_Bio__Emboss_ajFeatSortByType, file);
        newXS("Bio::Emboss::ajFeatSortByStart", XS_Bio__Emboss_ajFeatSortByStart, file);
        newXS("Bio::Emboss::ajFeatSortByEnd", XS_Bio__Emboss_ajFeatSortByEnd, file);
        newXS("Bio::Emboss::ajFeattableAdd", XS_Bio__Emboss_ajFeattableAdd, file);
        newXS("Bio::Emboss::ajFeattableClear", XS_Bio__Emboss_ajFeattableClear, file);
        newXS("Bio::Emboss::ajFeatOutFormatDefault", XS_Bio__Emboss_ajFeatOutFormatDefault, file);
        newXS("Bio::Emboss::ajFeatWrite", XS_Bio__Emboss_ajFeatWrite, file);
        newXS("Bio::Emboss::ajFeattableWriteGff", XS_Bio__Emboss_ajFeattableWriteGff, file);
        newXS("Bio::Emboss::ajFeattableWriteDdbj", XS_Bio__Emboss_ajFeattableWriteDdbj, file);
        newXS("Bio::Emboss::ajFeattableWriteEmbl", XS_Bio__Emboss_ajFeattableWriteEmbl, file);
        newXS("Bio::Emboss::ajFeattableWriteGenbank", XS_Bio__Emboss_ajFeattableWriteGenbank, file);
        newXS("Bio::Emboss::ajFeattableWriteSwiss", XS_Bio__Emboss_ajFeattableWriteSwiss, file);
        newXS("Bio::Emboss::ajFeattableWritePir", XS_Bio__Emboss_ajFeattableWritePir, file);
        newXS("Bio::Emboss::ajFeattableGetName", XS_Bio__Emboss_ajFeattableGetName, file);
        newXS("Bio::Emboss::ajFeattableGetTypeC", XS_Bio__Emboss_ajFeattableGetTypeC, file);
        newXS("Bio::Emboss::ajFeattableGetTypeS", XS_Bio__Emboss_ajFeattableGetTypeS, file);
        newXS("Bio::Emboss::ajFeattableIsNuc", XS_Bio__Emboss_ajFeattableIsNuc, file);
        newXS("Bio::Emboss::ajFeattableIsProt", XS_Bio__Emboss_ajFeattableIsProt, file);
        newXS("Bio::Emboss::ajFeattableBegin", XS_Bio__Emboss_ajFeattableBegin, file);
        newXS("Bio::Emboss::ajFeattableEnd", XS_Bio__Emboss_ajFeattableEnd, file);
        newXS("Bio::Emboss::ajFeattableLen", XS_Bio__Emboss_ajFeattableLen, file);
        newXS("Bio::Emboss::ajFeattableSize", XS_Bio__Emboss_ajFeattableSize, file);
        newXS("Bio::Emboss::ajFeattabInClear", XS_Bio__Emboss_ajFeattabInClear, file);
        newXS("Bio::Emboss::ajFeatLocToSeq", XS_Bio__Emboss_ajFeatLocToSeq, file);
        newXS("Bio::Emboss::ajFeatGetLocs", XS_Bio__Emboss_ajFeatGetLocs, file);
        newXS("Bio::Emboss::ajFeatGetNote", XS_Bio__Emboss_ajFeatGetNote, file);
        newXS("Bio::Emboss::ajFeatGetNoteC", XS_Bio__Emboss_ajFeatGetNoteC, file);
        newXS("Bio::Emboss::ajFeatGetNoteCI", XS_Bio__Emboss_ajFeatGetNoteCI, file);
        newXS("Bio::Emboss::ajFeatGetNoteI", XS_Bio__Emboss_ajFeatGetNoteI, file);
        newXS("Bio::Emboss::ajFeatGetTag", XS_Bio__Emboss_ajFeatGetTag, file);
        newXS("Bio::Emboss::ajFeatGetType", XS_Bio__Emboss_ajFeatGetType, file);
        newXS("Bio::Emboss::ajFeatGetSource", XS_Bio__Emboss_ajFeatGetSource, file);
        newXS("Bio::Emboss::ajFeatGetStart", XS_Bio__Emboss_ajFeatGetStart, file);
        newXS("Bio::Emboss::ajFeatGetStrand", XS_Bio__Emboss_ajFeatGetStrand, file);
        newXS("Bio::Emboss::ajFeatGetEnd", XS_Bio__Emboss_ajFeatGetEnd, file);
        newXS("Bio::Emboss::ajFeatGetLength", XS_Bio__Emboss_ajFeatGetLength, file);
        newXS("Bio::Emboss::ajFeatGetScore", XS_Bio__Emboss_ajFeatGetScore, file);
        newXS("Bio::Emboss::ajFeatGetForward", XS_Bio__Emboss_ajFeatGetForward, file);
        newXS("Bio::Emboss::ajFeatGetFrame", XS_Bio__Emboss_ajFeatGetFrame, file);
        newXS("Bio::Emboss::ajFeatGetTrans", XS_Bio__Emboss_ajFeatGetTrans, file);
        newXS("Bio::Emboss::ajFeatTest", XS_Bio__Emboss_ajFeatTest, file);
        newXS("Bio::Emboss::ajFeatSetDescApp", XS_Bio__Emboss_ajFeatSetDescApp, file);
        newXS("Bio::Emboss::ajFeatSetDesc", XS_Bio__Emboss_ajFeatSetDesc, file);
        newXS("Bio::Emboss::ajFeatSetScore", XS_Bio__Emboss_ajFeatSetScore, file);
        newXS("Bio::Emboss::ajFeatSetStrand", XS_Bio__Emboss_ajFeatSetStrand, file);
        newXS("Bio::Emboss::ajFeattabInSetType", XS_Bio__Emboss_ajFeattabInSetType, file);
        newXS("Bio::Emboss::ajFeattabInSetTypeC", XS_Bio__Emboss_ajFeattabInSetTypeC, file);
        newXS("Bio::Emboss::ajFeattabOutSetType", XS_Bio__Emboss_ajFeattabOutSetType, file);
        newXS("Bio::Emboss::ajFeattabOutSetTypeC", XS_Bio__Emboss_ajFeattabOutSetTypeC, file);
        newXS("Bio::Emboss::ajFeatTagSetC", XS_Bio__Emboss_ajFeatTagSetC, file);
        newXS("Bio::Emboss::ajFeatTagSet", XS_Bio__Emboss_ajFeatTagSet, file);
        newXS("Bio::Emboss::ajFeatTagAddCC", XS_Bio__Emboss_ajFeatTagAddCC, file);
        newXS("Bio::Emboss::ajFeatTagAddC", XS_Bio__Emboss_ajFeatTagAddC, file);
        newXS("Bio::Emboss::ajFeatTagAdd", XS_Bio__Emboss_ajFeatTagAdd, file);
        newXS("Bio::Emboss::ajFeattableNew", XS_Bio__Emboss_ajFeattableNew, file);
        newXS("Bio::Emboss::ajFeatUfoRead", XS_Bio__Emboss_ajFeatUfoRead, file);
        newXS("Bio::Emboss::ajFeattableSetNuc", XS_Bio__Emboss_ajFeattableSetNuc, file);
        newXS("Bio::Emboss::ajFeattableSetProt", XS_Bio__Emboss_ajFeattableSetProt, file);
        newXS("Bio::Emboss::ajFeattableReverse", XS_Bio__Emboss_ajFeattableReverse, file);
        newXS("Bio::Emboss::ajFeatReverse", XS_Bio__Emboss_ajFeatReverse, file);
        newXS("Bio::Emboss::ajFeattableSetRange", XS_Bio__Emboss_ajFeattableSetRange, file);
        newXS("Bio::Emboss::ajFeattableNewDna", XS_Bio__Emboss_ajFeattableNewDna, file);
        newXS("Bio::Emboss::ajFeattableNewSeq", XS_Bio__Emboss_ajFeattableNewSeq, file);
        newXS("Bio::Emboss::ajFeattableNewProt", XS_Bio__Emboss_ajFeattableNewProt, file);
        newXS("Bio::Emboss::ajFeattableCopy", XS_Bio__Emboss_ajFeattableCopy, file);
        newXS("Bio::Emboss::ajFeatCopy", XS_Bio__Emboss_ajFeatCopy, file);
        newXS("Bio::Emboss::ajFeatTrace", XS_Bio__Emboss_ajFeatTrace, file);
        newXS("Bio::Emboss::ajFeatTagTrace", XS_Bio__Emboss_ajFeatTagTrace, file);
        newXS("Bio::Emboss::ajFeatTagIter", XS_Bio__Emboss_ajFeatTagIter, file);
        newXS("Bio::Emboss::ajFeatTagval", XS_Bio__Emboss_ajFeatTagval, file);
        newXS("Bio::Emboss::ajFeattableTrace", XS_Bio__Emboss_ajFeattableTrace, file);
        newXS("Bio::Emboss::ajFeatExit", XS_Bio__Emboss_ajFeatExit, file);
        newXS("Bio::Emboss::ajFeatUnused", XS_Bio__Emboss_ajFeatUnused, file);
        newXS("Bio::Emboss::ajFeatIsLocal", XS_Bio__Emboss_ajFeatIsLocal, file);
        newXS("Bio::Emboss::ajFeatIsLocalRange", XS_Bio__Emboss_ajFeatIsLocalRange, file);
        newXS("Bio::Emboss::ajFeatIsChild", XS_Bio__Emboss_ajFeatIsChild, file);
        newXS("Bio::Emboss::ajFeatIsMultiple", XS_Bio__Emboss_ajFeatIsMultiple, file);
        newXS("Bio::Emboss::ajFeatIsCompMult", XS_Bio__Emboss_ajFeatIsCompMult, file);
        newXS("Bio::Emboss::ajFeattabOutDel", XS_Bio__Emboss_ajFeattabOutDel, file);
        newXS("Bio::Emboss::ajFeattablePos", XS_Bio__Emboss_ajFeattablePos, file);
        newXS("Bio::Emboss::ajFeattablePosI", XS_Bio__Emboss_ajFeattablePosI, file);
        newXS("Bio::Emboss::ajFeattablePosII", XS_Bio__Emboss_ajFeattablePosII, file);
        newXS("Bio::Emboss::ajFeattableTrimOff", XS_Bio__Emboss_ajFeattableTrimOff, file);
        newXS("Bio::Emboss::ajFeatTrimOffRange", XS_Bio__Emboss_ajFeatTrimOffRange, file);
        newXS("Bio::Emboss::ajFeatDefName", XS_Bio__Emboss_ajFeatDefName, file);
        newXS("Bio::Emboss::ajFeatPrintFormat", XS_Bio__Emboss_ajFeatPrintFormat, file);
        newXS("Bio::Emboss::ajOutfileNew", XS_Bio__Emboss_ajOutfileNew, file);
        newXS("Bio::Emboss::ajDirNew", XS_Bio__Emboss_ajDirNew, file);
        newXS("Bio::Emboss::ajDirNewS", XS_Bio__Emboss_ajDirNewS, file);
        newXS("Bio::Emboss::ajDirNewSS", XS_Bio__Emboss_ajDirNewSS, file);
        newXS("Bio::Emboss::ajDiroutNew", XS_Bio__Emboss_ajDiroutNew, file);
        newXS("Bio::Emboss::ajDiroutNewS", XS_Bio__Emboss_ajDiroutNewS, file);
        newXS("Bio::Emboss::ajDiroutNewSS", XS_Bio__Emboss_ajDiroutNewSS, file);
        newXS("Bio::Emboss::ajDirName", XS_Bio__Emboss_ajDirName, file);
        newXS("Bio::Emboss::ajDirExt", XS_Bio__Emboss_ajDirExt, file);
        newXS("Bio::Emboss::ajFileNew", XS_Bio__Emboss_ajFileNew, file);
        newXS("Bio::Emboss::ajFileNewInPipe", XS_Bio__Emboss_ajFileNewInPipe, file);
        newXS("Bio::Emboss::ajFileNewIn", XS_Bio__Emboss_ajFileNewIn, file);
        newXS("Bio::Emboss::ajFileNewInC", XS_Bio__Emboss_ajFileNewInC, file);
        newXS("Bio::Emboss::ajFileNewInList", XS_Bio__Emboss_ajFileNewInList, file);
        newXS("Bio::Emboss::ajFileNewApp", XS_Bio__Emboss_ajFileNewApp, file);
        newXS("Bio::Emboss::ajFileNewOut", XS_Bio__Emboss_ajFileNewOut, file);
        newXS("Bio::Emboss::ajFileNewOutC", XS_Bio__Emboss_ajFileNewOutC, file);
        newXS("Bio::Emboss::ajFileNewOutD", XS_Bio__Emboss_ajFileNewOutD, file);
        newXS("Bio::Emboss::ajFileNewOutDir", XS_Bio__Emboss_ajFileNewOutDir, file);
        newXS("Bio::Emboss::ajFileSetDir", XS_Bio__Emboss_ajFileSetDir, file);
        newXS("Bio::Emboss::ajFileHasDir", XS_Bio__Emboss_ajFileHasDir, file);
        newXS("Bio::Emboss::ajFileNewF", XS_Bio__Emboss_ajFileNewF, file);
        newXS("Bio::Emboss::ajOutfileClose", XS_Bio__Emboss_ajOutfileClose, file);
        newXS("Bio::Emboss::ajOutfileDel", XS_Bio__Emboss_ajOutfileDel, file);
        newXS("Bio::Emboss::ajDirDel", XS_Bio__Emboss_ajDirDel, file);
        newXS("Bio::Emboss::ajDiroutDel", XS_Bio__Emboss_ajDiroutDel, file);
        newXS("Bio::Emboss::ajFileClose", XS_Bio__Emboss_ajFileClose, file);
        newXS("Bio::Emboss::ajFileOutClose", XS_Bio__Emboss_ajFileOutClose, file);
        newXS("Bio::Emboss::ajFileDataNew", XS_Bio__Emboss_ajFileDataNew, file);
        newXS("Bio::Emboss::ajFileDataNewC", XS_Bio__Emboss_ajFileDataNewC, file);
        newXS("Bio::Emboss::ajFileDataDirNew", XS_Bio__Emboss_ajFileDataDirNew, file);
        newXS("Bio::Emboss::ajFileDataDirNewC", XS_Bio__Emboss_ajFileDataDirNewC, file);
        newXS("Bio::Emboss::ajFileSeek", XS_Bio__Emboss_ajFileSeek, file);
        newXS("Bio::Emboss::ajFileRead", XS_Bio__Emboss_ajFileRead, file);
        newXS("Bio::Emboss::ajFileReadUint", XS_Bio__Emboss_ajFileReadUint, file);
        newXS("Bio::Emboss::ajFileWrite", XS_Bio__Emboss_ajFileWrite, file);
        newXS("Bio::Emboss::ajFileNext", XS_Bio__Emboss_ajFileNext, file);
        newXS("Bio::Emboss::ajFileReopen", XS_Bio__Emboss_ajFileReopen, file);
        newXS("Bio::Emboss::ajFileReadLine", XS_Bio__Emboss_ajFileReadLine, file);
        newXS("Bio::Emboss::ajFileGetsTrimL", XS_Bio__Emboss_ajFileGetsTrimL, file);
        newXS("Bio::Emboss::ajFileGetsTrim", XS_Bio__Emboss_ajFileGetsTrim, file);
        newXS("Bio::Emboss::ajFileGets", XS_Bio__Emboss_ajFileGets, file);
        newXS("Bio::Emboss::ajFileGetsL", XS_Bio__Emboss_ajFileGetsL, file);
        newXS("Bio::Emboss::ajFileUnbuffer", XS_Bio__Emboss_ajFileUnbuffer, file);
        newXS("Bio::Emboss::ajFileReadAppend", XS_Bio__Emboss_ajFileReadAppend, file);
        newXS("Bio::Emboss::ajFileOutHeader", XS_Bio__Emboss_ajFileOutHeader, file);
        newXS("Bio::Emboss::ajFileNameShorten", XS_Bio__Emboss_ajFileNameShorten, file);
        newXS("Bio::Emboss::ajFileNameTrim", XS_Bio__Emboss_ajFileNameTrim, file);
        newXS("Bio::Emboss::ajFileDataNewWrite", XS_Bio__Emboss_ajFileDataNewWrite, file);
        newXS("Bio::Emboss::ajFileDir", XS_Bio__Emboss_ajFileDir, file);
        newXS("Bio::Emboss::ajFileDirPath", XS_Bio__Emboss_ajFileDirPath, file);
        newXS("Bio::Emboss::ajFileGetwd", XS_Bio__Emboss_ajFileGetwd, file);
        newXS("Bio::Emboss::ajFileDirUp", XS_Bio__Emboss_ajFileDirUp, file);
        newXS("Bio::Emboss::ajFileDirFix", XS_Bio__Emboss_ajFileDirFix, file);
        newXS("Bio::Emboss::ajFileExit", XS_Bio__Emboss_ajFileExit, file);
        newXS("Bio::Emboss::ajFileTrace", XS_Bio__Emboss_ajFileTrace, file);
        newXS("Bio::Emboss::ajOutfileFile", XS_Bio__Emboss_ajOutfileFile, file);
        newXS("Bio::Emboss::ajOutfileFp", XS_Bio__Emboss_ajOutfileFp, file);
        newXS("Bio::Emboss::ajOutfileFormat", XS_Bio__Emboss_ajOutfileFormat, file);
        newXS("Bio::Emboss::ajFileBuffSize", XS_Bio__Emboss_ajFileBuffSize, file);
        newXS("Bio::Emboss::ajFileName", XS_Bio__Emboss_ajFileName, file);
        newXS("Bio::Emboss::ajFileNameS", XS_Bio__Emboss_ajFileNameS, file);
        newXS("Bio::Emboss::ajFileGetApp", XS_Bio__Emboss_ajFileGetApp, file);
        newXS("Bio::Emboss::ajFileGetName", XS_Bio__Emboss_ajFileGetName, file);
        newXS("Bio::Emboss::ajFileStat", XS_Bio__Emboss_ajFileStat, file);
        newXS("Bio::Emboss::ajFileLength", XS_Bio__Emboss_ajFileLength, file);
        newXS("Bio::Emboss::ajFileTell", XS_Bio__Emboss_ajFileTell, file);
        newXS("Bio::Emboss::ajFileStdout", XS_Bio__Emboss_ajFileStdout, file);
        newXS("Bio::Emboss::ajFileStderr", XS_Bio__Emboss_ajFileStderr, file);
        newXS("Bio::Emboss::ajFileStdin", XS_Bio__Emboss_ajFileStdin, file);
        newXS("Bio::Emboss::ajFileFp", XS_Bio__Emboss_ajFileFp, file);
        newXS("Bio::Emboss::ajFileEof", XS_Bio__Emboss_ajFileEof, file);
        newXS("Bio::Emboss::ajFileBuffNewIn", XS_Bio__Emboss_ajFileBuffNewIn, file);
        newXS("Bio::Emboss::ajFileBuffNew", XS_Bio__Emboss_ajFileBuffNew, file);
        newXS("Bio::Emboss::ajFileBuffNewFile", XS_Bio__Emboss_ajFileBuffNewFile, file);
        newXS("Bio::Emboss::ajFileBuffSetFile", XS_Bio__Emboss_ajFileBuffSetFile, file);
        newXS("Bio::Emboss::ajFileBuffNewS", XS_Bio__Emboss_ajFileBuffNewS, file);
        newXS("Bio::Emboss::ajFileBuffNewF", XS_Bio__Emboss_ajFileBuffNewF, file);
        newXS("Bio::Emboss::ajFileBuffNewDW", XS_Bio__Emboss_ajFileBuffNewDW, file);
        newXS("Bio::Emboss::ajFileBuffNewDWE", XS_Bio__Emboss_ajFileBuffNewDWE, file);
        newXS("Bio::Emboss::ajFileBuffNewDC", XS_Bio__Emboss_ajFileBuffNewDC, file);
        newXS("Bio::Emboss::ajFileBuffNewDF", XS_Bio__Emboss_ajFileBuffNewDF, file);
        newXS("Bio::Emboss::ajFileNewDW", XS_Bio__Emboss_ajFileNewDW, file);
        newXS("Bio::Emboss::ajFileNewDWE", XS_Bio__Emboss_ajFileNewDWE, file);
        newXS("Bio::Emboss::ajFileNewDF", XS_Bio__Emboss_ajFileNewDF, file);
        newXS("Bio::Emboss::ajFileNewDirF", XS_Bio__Emboss_ajFileNewDirF, file);
        newXS("Bio::Emboss::ajFileNewDC", XS_Bio__Emboss_ajFileNewDC, file);
        newXS("Bio::Emboss::ajFileBuffNewInList", XS_Bio__Emboss_ajFileBuffNewInList, file);
        newXS("Bio::Emboss::ajFileBuffDel", XS_Bio__Emboss_ajFileBuffDel, file);
        newXS("Bio::Emboss::ajFileBuffGet", XS_Bio__Emboss_ajFileBuffGet, file);
        newXS("Bio::Emboss::ajFileBuffGetStore", XS_Bio__Emboss_ajFileBuffGetStore, file);
        newXS("Bio::Emboss::ajFileBuffGetStoreL", XS_Bio__Emboss_ajFileBuffGetStoreL, file);
        newXS("Bio::Emboss::ajFileBuffGetL", XS_Bio__Emboss_ajFileBuffGetL, file);
        newXS("Bio::Emboss::ajFileBuffStripHtml", XS_Bio__Emboss_ajFileBuffStripHtml, file);
        newXS("Bio::Emboss::ajFileBuffLoadC", XS_Bio__Emboss_ajFileBuffLoadC, file);
        newXS("Bio::Emboss::ajFileBuffLoadS", XS_Bio__Emboss_ajFileBuffLoadS, file);
        newXS("Bio::Emboss::ajFileBuffEof", XS_Bio__Emboss_ajFileBuffEof, file);
        newXS("Bio::Emboss::ajFileBuffEnd", XS_Bio__Emboss_ajFileBuffEnd, file);
        newXS("Bio::Emboss::ajFileBuffReset", XS_Bio__Emboss_ajFileBuffReset, file);
        newXS("Bio::Emboss::ajFileBuffResetStore", XS_Bio__Emboss_ajFileBuffResetStore, file);
        newXS("Bio::Emboss::ajFileBuffResetPos", XS_Bio__Emboss_ajFileBuffResetPos, file);
        newXS("Bio::Emboss::ajFileBuffFix", XS_Bio__Emboss_ajFileBuffFix, file);
        newXS("Bio::Emboss::ajFileBuffFreeClear", XS_Bio__Emboss_ajFileBuffFreeClear, file);
        newXS("Bio::Emboss::ajFileBuffClear", XS_Bio__Emboss_ajFileBuffClear, file);
        newXS("Bio::Emboss::ajFileBuffClearStore", XS_Bio__Emboss_ajFileBuffClearStore, file);
        newXS("Bio::Emboss::ajFileBuffNobuff", XS_Bio__Emboss_ajFileBuffNobuff, file);
        newXS("Bio::Emboss::ajFileBuffBuff", XS_Bio__Emboss_ajFileBuffBuff, file);
        newXS("Bio::Emboss::ajFileBuffEmpty", XS_Bio__Emboss_ajFileBuffEmpty, file);
        newXS("Bio::Emboss::ajFileBuffTrace", XS_Bio__Emboss_ajFileBuffTrace, file);
        newXS("Bio::Emboss::ajFileBuffTraceFull", XS_Bio__Emboss_ajFileBuffTraceFull, file);
        newXS("Bio::Emboss::ajFileBuffPrint", XS_Bio__Emboss_ajFileBuffPrint, file);
        newXS("Bio::Emboss::ajFileBuffIsBuffered", XS_Bio__Emboss_ajFileBuffIsBuffered, file);
        newXS("Bio::Emboss::ajFileBuffFp", XS_Bio__Emboss_ajFileBuffFp, file);
        newXS("Bio::Emboss::ajFileBuffFile", XS_Bio__Emboss_ajFileBuffFile, file);
        newXS("Bio::Emboss::ajFileBuffLoad", XS_Bio__Emboss_ajFileBuffLoad, file);
        newXS("Bio::Emboss::ajFileNameDir", XS_Bio__Emboss_ajFileNameDir, file);
        newXS("Bio::Emboss::ajFileNameDirSet", XS_Bio__Emboss_ajFileNameDirSet, file);
        newXS("Bio::Emboss::ajFileNameDirSetC", XS_Bio__Emboss_ajFileNameDirSetC, file);
        newXS("Bio::Emboss::ajFileNameExt", XS_Bio__Emboss_ajFileNameExt, file);
        newXS("Bio::Emboss::ajFileNameExtC", XS_Bio__Emboss_ajFileNameExtC, file);
        newXS("Bio::Emboss::ajFileScan", XS_Bio__Emboss_ajFileScan, file);
        newXS("Bio::Emboss::ajFileTestSkip", XS_Bio__Emboss_ajFileTestSkip, file);
        newXS("Bio::Emboss::ajFileDirTrim", XS_Bio__Emboss_ajFileDirTrim, file);
        newXS("Bio::Emboss::ajFileExtnTrim", XS_Bio__Emboss_ajFileExtnTrim, file);
        newXS("Bio::Emboss::ajFileDirExtnTrim", XS_Bio__Emboss_ajFileDirExtnTrim, file);
        newXS("Bio::Emboss::ajFileTempName", XS_Bio__Emboss_ajFileTempName, file);
        newXS("Bio::Emboss::ajFileWriteByte", XS_Bio__Emboss_ajFileWriteByte, file);
        newXS("Bio::Emboss::ajFileWriteChar", XS_Bio__Emboss_ajFileWriteChar, file);
        newXS("Bio::Emboss::ajFileWriteInt2", XS_Bio__Emboss_ajFileWriteInt2, file);
        newXS("Bio::Emboss::ajFileWriteInt4", XS_Bio__Emboss_ajFileWriteInt4, file);
        newXS("Bio::Emboss::ajFileWriteInt8", XS_Bio__Emboss_ajFileWriteInt8, file);
        newXS("Bio::Emboss::ajFileWriteStr", XS_Bio__Emboss_ajFileWriteStr, file);
        newXS("Bio::Emboss::ajFileBuffStripHtmlPre", XS_Bio__Emboss_ajFileBuffStripHtmlPre, file);
        newXS("Bio::Emboss::ajFileFileList", XS_Bio__Emboss_ajFileFileList, file);
        newXS("Bio::Emboss::ajFmtPrint", XS_Bio__Emboss_ajFmtPrint, file);
        newXS("Bio::Emboss::ajFmtError", XS_Bio__Emboss_ajFmtError, file);
        newXS("Bio::Emboss::ajFmtPrintF", XS_Bio__Emboss_ajFmtPrintF, file);
        newXS("Bio::Emboss::ajFmtPrintFp", XS_Bio__Emboss_ajFmtPrintFp, file);
        newXS("Bio::Emboss::ajFmtPrintCL", XS_Bio__Emboss_ajFmtPrintCL, file);
        newXS("Bio::Emboss::ajFmtStr", XS_Bio__Emboss_ajFmtStr, file);
        newXS("Bio::Emboss::ajFmtPrintS", XS_Bio__Emboss_ajFmtPrintS, file);
        newXS("Bio::Emboss::ajFmtPrintAppS", XS_Bio__Emboss_ajFmtPrintAppS, file);
        newXS("Bio::Emboss::ajFmtString", XS_Bio__Emboss_ajFmtString, file);
        newXS("Bio::Emboss::ajFmtPrintSplit", XS_Bio__Emboss_ajFmtPrintSplit, file);
        newXS("Bio::Emboss::ajFmtScanS", XS_Bio__Emboss_ajFmtScanS, file);
        newXS("Bio::Emboss::ajFmtScanC", XS_Bio__Emboss_ajFmtScanC, file);
        newXS("Bio::Emboss::ajFmtScanF", XS_Bio__Emboss_ajFmtScanF, file);
        newXS("Bio::Emboss::ajGraphSetDevice", XS_Bio__Emboss_ajGraphSetDevice, file);
        newXS("Bio::Emboss::ajGraphSetName", XS_Bio__Emboss_ajGraphSetName, file);
        newXS("Bio::Emboss::ajGraphLabel", XS_Bio__Emboss_ajGraphLabel, file);
        newXS("Bio::Emboss::ajGraphSetPenWidth", XS_Bio__Emboss_ajGraphSetPenWidth, file);
        newXS("Bio::Emboss::ajGraphOpenPlot", XS_Bio__Emboss_ajGraphOpenPlot, file);
        newXS("Bio::Emboss::ajGraphOpenWin", XS_Bio__Emboss_ajGraphOpenWin, file);
        newXS("Bio::Emboss::ajGraphNewPage", XS_Bio__Emboss_ajGraphNewPage, file);
        newXS("Bio::Emboss::ajGraphCloseWin", XS_Bio__Emboss_ajGraphCloseWin, file);
        newXS("Bio::Emboss::ajGraphOpen", XS_Bio__Emboss_ajGraphOpen, file);
        newXS("Bio::Emboss::ajGraphLabelYRight", XS_Bio__Emboss_ajGraphLabelYRight, file);
        newXS("Bio::Emboss::ajGraphClose", XS_Bio__Emboss_ajGraphClose, file);
        newXS("Bio::Emboss::ajGraphSet", XS_Bio__Emboss_ajGraphSet, file);
        newXS("Bio::Emboss::ajGraphxySet", XS_Bio__Emboss_ajGraphxySet, file);
        newXS("Bio::Emboss::ajGraphDumpDevices", XS_Bio__Emboss_ajGraphDumpDevices, file);
        newXS("Bio::Emboss::ajGraphTraceInt", XS_Bio__Emboss_ajGraphTraceInt, file);
        newXS("Bio::Emboss::ajGraphTrace", XS_Bio__Emboss_ajGraphTrace, file);
        newXS("Bio::Emboss::ajGraphPlpDataTrace", XS_Bio__Emboss_ajGraphPlpDataTrace, file);
        newXS("Bio::Emboss::ajGraphCircle", XS_Bio__Emboss_ajGraphCircle, file);
        newXS("Bio::Emboss::ajGraphPolyFill", XS_Bio__Emboss_ajGraphPolyFill, file);
        newXS("Bio::Emboss::ajGraphPoly", XS_Bio__Emboss_ajGraphPoly, file);
        newXS("Bio::Emboss::ajGraphTriFill", XS_Bio__Emboss_ajGraphTriFill, file);
        newXS("Bio::Emboss::ajGraphTri", XS_Bio__Emboss_ajGraphTri, file);
        newXS("Bio::Emboss::ajGraphDiaFill", XS_Bio__Emboss_ajGraphDiaFill, file);
        newXS("Bio::Emboss::ajGraphDia", XS_Bio__Emboss_ajGraphDia, file);
        newXS("Bio::Emboss::ajGraphBoxFill", XS_Bio__Emboss_ajGraphBoxFill, file);
        newXS("Bio::Emboss::ajGraphBox", XS_Bio__Emboss_ajGraphBox, file);
        newXS("Bio::Emboss::ajGraphRectFill", XS_Bio__Emboss_ajGraphRectFill, file);
        newXS("Bio::Emboss::ajGraphRect", XS_Bio__Emboss_ajGraphRect, file);
        newXS("Bio::Emboss::ajGraphSetBackWhite", XS_Bio__Emboss_ajGraphSetBackWhite, file);
        newXS("Bio::Emboss::ajGraphSetBackBlack", XS_Bio__Emboss_ajGraphSetBackBlack, file);
        newXS("Bio::Emboss::ajGraphColourBack", XS_Bio__Emboss_ajGraphColourBack, file);
        newXS("Bio::Emboss::ajGraphColourFore", XS_Bio__Emboss_ajGraphColourFore, file);
        newXS("Bio::Emboss::ajGraphSetFore", XS_Bio__Emboss_ajGraphSetFore, file);
        newXS("Bio::Emboss::ajGraphCheckColour", XS_Bio__Emboss_ajGraphCheckColour, file);
        newXS("Bio::Emboss::ajGraphGetBaseColour", XS_Bio__Emboss_ajGraphGetBaseColour, file);
        newXS("Bio::Emboss::ajGraphGetBaseColourProt", XS_Bio__Emboss_ajGraphGetBaseColourProt, file);
        newXS("Bio::Emboss::ajGraphGetBaseColourNuc", XS_Bio__Emboss_ajGraphGetBaseColourNuc, file);
        newXS("Bio::Emboss::ajGraphGetCharSize", XS_Bio__Emboss_ajGraphGetCharSize, file);
        newXS("Bio::Emboss::ajGraphGetOut", XS_Bio__Emboss_ajGraphGetOut, file);
        newXS("Bio::Emboss::ajGraphSetOri", XS_Bio__Emboss_ajGraphSetOri, file);
        newXS("Bio::Emboss::ajGraphPlenv", XS_Bio__Emboss_ajGraphPlenv, file);
        newXS("Bio::Emboss::ajGraphGetColour", XS_Bio__Emboss_ajGraphGetColour, file);
        newXS("Bio::Emboss::ajGraphGetSubTitle", XS_Bio__Emboss_ajGraphGetSubTitle, file);
        newXS("Bio::Emboss::ajGraphGetSubTitleC", XS_Bio__Emboss_ajGraphGetSubTitleC, file);
        newXS("Bio::Emboss::ajGraphGetTitle", XS_Bio__Emboss_ajGraphGetTitle, file);
        newXS("Bio::Emboss::ajGraphGetTitleC", XS_Bio__Emboss_ajGraphGetTitleC, file);
        newXS("Bio::Emboss::ajGraphGetXTitle", XS_Bio__Emboss_ajGraphGetXTitle, file);
        newXS("Bio::Emboss::ajGraphGetXTitleC", XS_Bio__Emboss_ajGraphGetXTitleC, file);
        newXS("Bio::Emboss::ajGraphGetYTitle", XS_Bio__Emboss_ajGraphGetYTitle, file);
        newXS("Bio::Emboss::ajGraphGetYTitleC", XS_Bio__Emboss_ajGraphGetYTitleC, file);
        newXS("Bio::Emboss::ajGraphSetLineStyle", XS_Bio__Emboss_ajGraphSetLineStyle, file);
        newXS("Bio::Emboss::ajGraphSetFillPat", XS_Bio__Emboss_ajGraphSetFillPat, file);
        newXS("Bio::Emboss::ajGraphSetCharSize", XS_Bio__Emboss_ajGraphSetCharSize, file);
        newXS("Bio::Emboss::ajGraphLine", XS_Bio__Emboss_ajGraphLine, file);
        newXS("Bio::Emboss::ajGraphLines", XS_Bio__Emboss_ajGraphLines, file);
        newXS("Bio::Emboss::ajGraphDots", XS_Bio__Emboss_ajGraphDots, file);
        newXS("Bio::Emboss::ajGraphSymbols", XS_Bio__Emboss_ajGraphSymbols, file);
        newXS("Bio::Emboss::ajGraphTextLine", XS_Bio__Emboss_ajGraphTextLine, file);
        newXS("Bio::Emboss::ajGraphText", XS_Bio__Emboss_ajGraphText, file);
        newXS("Bio::Emboss::ajGraphTextStart", XS_Bio__Emboss_ajGraphTextStart, file);
        newXS("Bio::Emboss::ajGraphTextEnd", XS_Bio__Emboss_ajGraphTextEnd, file);
        newXS("Bio::Emboss::ajGraphTextMid", XS_Bio__Emboss_ajGraphTextMid, file);
        newXS("Bio::Emboss::ajGraphVertBars", XS_Bio__Emboss_ajGraphVertBars, file);
        newXS("Bio::Emboss::ajGraphHoriBars", XS_Bio__Emboss_ajGraphHoriBars, file);
        newXS("Bio::Emboss::ajGraphInitSeq", XS_Bio__Emboss_ajGraphInitSeq, file);
        newXS("Bio::Emboss::ajGraphSetOut", XS_Bio__Emboss_ajGraphSetOut, file);
        newXS("Bio::Emboss::ajGraphSetOutC", XS_Bio__Emboss_ajGraphSetOutC, file);
        newXS("Bio::Emboss::ajGraphSetDir", XS_Bio__Emboss_ajGraphSetDir, file);
        newXS("Bio::Emboss::ajGraphPlpDataSetLineType", XS_Bio__Emboss_ajGraphPlpDataSetLineType, file);
        newXS("Bio::Emboss::ajGraphxySetXStart", XS_Bio__Emboss_ajGraphxySetXStart, file);
        newXS("Bio::Emboss::ajGraphxySetXEnd", XS_Bio__Emboss_ajGraphxySetXEnd, file);
        newXS("Bio::Emboss::ajGraphxySetYStart", XS_Bio__Emboss_ajGraphxySetYStart, file);
        newXS("Bio::Emboss::ajGraphxySetYEnd", XS_Bio__Emboss_ajGraphxySetYEnd, file);
        newXS("Bio::Emboss::ajGraphPlpDataSetColour", XS_Bio__Emboss_ajGraphPlpDataSetColour, file);
        newXS("Bio::Emboss::ajGraphSetYTitle", XS_Bio__Emboss_ajGraphSetYTitle, file);
        newXS("Bio::Emboss::ajGraphSetYTitleC", XS_Bio__Emboss_ajGraphSetYTitleC, file);
        newXS("Bio::Emboss::ajGraphSetXTitle", XS_Bio__Emboss_ajGraphSetXTitle, file);
        newXS("Bio::Emboss::ajGraphSetXTitleC", XS_Bio__Emboss_ajGraphSetXTitleC, file);
        newXS("Bio::Emboss::ajGraphSetTitle", XS_Bio__Emboss_ajGraphSetTitle, file);
        newXS("Bio::Emboss::ajGraphSetTitleC", XS_Bio__Emboss_ajGraphSetTitleC, file);
        newXS("Bio::Emboss::ajGraphSetSubTitle", XS_Bio__Emboss_ajGraphSetSubTitle, file);
        newXS("Bio::Emboss::ajGraphSetSubTitleC", XS_Bio__Emboss_ajGraphSetSubTitleC, file);
        newXS("Bio::Emboss::ajGraphPlpDataSetYTitle", XS_Bio__Emboss_ajGraphPlpDataSetYTitle, file);
        newXS("Bio::Emboss::ajGraphPlpDataSetYTitleC", XS_Bio__Emboss_ajGraphPlpDataSetYTitleC, file);
        newXS("Bio::Emboss::ajGraphPlpDataSetXTitle", XS_Bio__Emboss_ajGraphPlpDataSetXTitle, file);
        newXS("Bio::Emboss::ajGraphPlpDataSetXTitleC", XS_Bio__Emboss_ajGraphPlpDataSetXTitleC, file);
        newXS("Bio::Emboss::ajGraphxyDel", XS_Bio__Emboss_ajGraphxyDel, file);
        newXS("Bio::Emboss::ajGraphPlpDataNew", XS_Bio__Emboss_ajGraphPlpDataNew, file);
        newXS("Bio::Emboss::ajGraphPlpDataSetXY", XS_Bio__Emboss_ajGraphPlpDataSetXY, file);
        newXS("Bio::Emboss::ajGraphPlpDataCalcXY", XS_Bio__Emboss_ajGraphPlpDataCalcXY, file);
        newXS("Bio::Emboss::ajGraphxySetXRangeII", XS_Bio__Emboss_ajGraphxySetXRangeII, file);
        newXS("Bio::Emboss::ajGraphxySetYRangeII", XS_Bio__Emboss_ajGraphxySetYRangeII, file);
        newXS("Bio::Emboss::ajGraphPlpDataNewI", XS_Bio__Emboss_ajGraphPlpDataNewI, file);
        newXS("Bio::Emboss::ajGraphDataAdd", XS_Bio__Emboss_ajGraphDataAdd, file);
        newXS("Bio::Emboss::ajGraphDataReplace", XS_Bio__Emboss_ajGraphDataReplace, file);
        newXS("Bio::Emboss::ajGraphNew", XS_Bio__Emboss_ajGraphNew, file);
        newXS("Bio::Emboss::ajGraphxyNewI", XS_Bio__Emboss_ajGraphxyNewI, file);
        newXS("Bio::Emboss::ajGraphSetMulti", XS_Bio__Emboss_ajGraphSetMulti, file);
        newXS("Bio::Emboss::ajGraphPlpDataSetTitle", XS_Bio__Emboss_ajGraphPlpDataSetTitle, file);
        newXS("Bio::Emboss::ajGraphPlpDataSetTitleC", XS_Bio__Emboss_ajGraphPlpDataSetTitleC, file);
        newXS("Bio::Emboss::ajGraphPlpDataSetSubTitle", XS_Bio__Emboss_ajGraphPlpDataSetSubTitle, file);
        newXS("Bio::Emboss::ajGraphPlpDataSetSubTitleC", XS_Bio__Emboss_ajGraphPlpDataSetSubTitleC, file);
        newXS("Bio::Emboss::ajGraphSetFlag", XS_Bio__Emboss_ajGraphSetFlag, file);
        newXS("Bio::Emboss::ajGraphxySetOverLap", XS_Bio__Emboss_ajGraphxySetOverLap, file);
        newXS("Bio::Emboss::ajGraphxySetGaps", XS_Bio__Emboss_ajGraphxySetGaps, file);
        newXS("Bio::Emboss::ajGraphxySetXBottom", XS_Bio__Emboss_ajGraphxySetXBottom, file);
        newXS("Bio::Emboss::ajGraphxySetXTop", XS_Bio__Emboss_ajGraphxySetXTop, file);
        newXS("Bio::Emboss::ajGraphxySetYRight", XS_Bio__Emboss_ajGraphxySetYRight, file);
        newXS("Bio::Emboss::ajGraphxySetYLeft", XS_Bio__Emboss_ajGraphxySetYLeft, file);
        newXS("Bio::Emboss::ajGraphxySetXTick", XS_Bio__Emboss_ajGraphxySetXTick, file);
        newXS("Bio::Emboss::ajGraphxySetYTick", XS_Bio__Emboss_ajGraphxySetYTick, file);
        newXS("Bio::Emboss::ajGraphxySetXLabel", XS_Bio__Emboss_ajGraphxySetXLabel, file);
        newXS("Bio::Emboss::ajGraphxySetYLabel", XS_Bio__Emboss_ajGraphxySetYLabel, file);
        newXS("Bio::Emboss::ajGraphSetTitleDo", XS_Bio__Emboss_ajGraphSetTitleDo, file);
        newXS("Bio::Emboss::ajGraphSetSubTitleDo", XS_Bio__Emboss_ajGraphSetSubTitleDo, file);
        newXS("Bio::Emboss::ajGraphxySetCirclePoints", XS_Bio__Emboss_ajGraphxySetCirclePoints, file);
        newXS("Bio::Emboss::ajGraphxySetJoinPoints", XS_Bio__Emboss_ajGraphxySetJoinPoints, file);
        newXS("Bio::Emboss::ajGraphxySetXLabelTop", XS_Bio__Emboss_ajGraphxySetXLabelTop, file);
        newXS("Bio::Emboss::ajGraphxySetYLabelLeft", XS_Bio__Emboss_ajGraphxySetYLabelLeft, file);
        newXS("Bio::Emboss::ajGraphxySetXInvTicks", XS_Bio__Emboss_ajGraphxySetXInvTicks, file);
        newXS("Bio::Emboss::ajGraphxySetYInvTicks", XS_Bio__Emboss_ajGraphxySetYInvTicks, file);
        newXS("Bio::Emboss::ajGraphxySetXGrid", XS_Bio__Emboss_ajGraphxySetXGrid, file);
        newXS("Bio::Emboss::ajGraphxySetYGrid", XS_Bio__Emboss_ajGraphxySetYGrid, file);
        newXS("Bio::Emboss::ajGraphxySetMaxMin", XS_Bio__Emboss_ajGraphxySetMaxMin, file);
        newXS("Bio::Emboss::ajGraphPlpDataSetMaxMin", XS_Bio__Emboss_ajGraphPlpDataSetMaxMin, file);
        newXS("Bio::Emboss::ajGraphArrayMaxMin", XS_Bio__Emboss_ajGraphArrayMaxMin, file);
        newXS("Bio::Emboss::ajGraphPlpDataSetMaxima", XS_Bio__Emboss_ajGraphPlpDataSetMaxima, file);
        newXS("Bio::Emboss::ajGraphPlpDataSetTypeC", XS_Bio__Emboss_ajGraphPlpDataSetTypeC, file);
        newXS("Bio::Emboss::ajGraphxyCheckMaxMin", XS_Bio__Emboss_ajGraphxyCheckMaxMin, file);
        newXS("Bio::Emboss::ajGraphxyDisplay", XS_Bio__Emboss_ajGraphxyDisplay, file);
        newXS("Bio::Emboss::ajGraphAddRect", XS_Bio__Emboss_ajGraphAddRect, file);
        newXS("Bio::Emboss::ajGraphAddText", XS_Bio__Emboss_ajGraphAddText, file);
        newXS("Bio::Emboss::ajGraphAddLine", XS_Bio__Emboss_ajGraphAddLine, file);
        newXS("Bio::Emboss::ajGraphPlpDataDel", XS_Bio__Emboss_ajGraphPlpDataDel, file);
        newXS("Bio::Emboss::ajGraphClear", XS_Bio__Emboss_ajGraphClear, file);
        newXS("Bio::Emboss::ajGraphPlpDataAddRect", XS_Bio__Emboss_ajGraphPlpDataAddRect, file);
        newXS("Bio::Emboss::ajGraphPlpDataAddText", XS_Bio__Emboss_ajGraphPlpDataAddText, file);
        newXS("Bio::Emboss::ajGraphPlpDataAddLine", XS_Bio__Emboss_ajGraphPlpDataAddLine, file);
        newXS("Bio::Emboss::ajGraphPrintType", XS_Bio__Emboss_ajGraphPrintType, file);
        newXS("Bio::Emboss::ajGraphTextLength", XS_Bio__Emboss_ajGraphTextLength, file);
        newXS("Bio::Emboss::ajGraphTextHeight", XS_Bio__Emboss_ajGraphTextHeight, file);
        newXS("Bio::Emboss::ajGraphDistPts", XS_Bio__Emboss_ajGraphDistPts, file);
        newXS("Bio::Emboss::ajGraphSetDefCharSize", XS_Bio__Emboss_ajGraphSetDefCharSize, file);
        newXS("Bio::Emboss::ajGraphFitTextOnLine", XS_Bio__Emboss_ajGraphFitTextOnLine, file);
        newXS("Bio::Emboss::ajGraphPartCircle", XS_Bio__Emboss_ajGraphPartCircle, file);
        newXS("Bio::Emboss::ajComputeCoord", XS_Bio__Emboss_ajComputeCoord, file);
        newXS("Bio::Emboss::ajGraphDrawTextOnCurve", XS_Bio__Emboss_ajGraphDrawTextOnCurve, file);
        newXS("Bio::Emboss::ajGraphRectangleOnCurve", XS_Bio__Emboss_ajGraphRectangleOnCurve, file);
        newXS("Bio::Emboss::ajGraphInfo", XS_Bio__Emboss_ajGraphInfo, file);
        newXS("Bio::Emboss::ajGraphFillRectangleOnCurve", XS_Bio__Emboss_ajGraphFillRectangleOnCurve, file);
        newXS("Bio::Emboss::ajGraphIsData", XS_Bio__Emboss_ajGraphIsData, file);
        newXS("Bio::Emboss::ajGraphUnused", XS_Bio__Emboss_ajGraphUnused, file);
        newXS("Bio::Emboss::ajHistDisplay", XS_Bio__Emboss_ajHistDisplay, file);
        newXS("Bio::Emboss::ajHistClose", XS_Bio__Emboss_ajHistClose, file);
        newXS("Bio::Emboss::ajHistDelete", XS_Bio__Emboss_ajHistDelete, file);
        newXS("Bio::Emboss::ajHistNew", XS_Bio__Emboss_ajHistNew, file);
        newXS("Bio::Emboss::ajHistNewG", XS_Bio__Emboss_ajHistNewG, file);
        newXS("Bio::Emboss::ajHistSetMultiTitle", XS_Bio__Emboss_ajHistSetMultiTitle, file);
        newXS("Bio::Emboss::ajHistSetMultiTitleC", XS_Bio__Emboss_ajHistSetMultiTitleC, file);
        newXS("Bio::Emboss::ajHistSetMultiXTitle", XS_Bio__Emboss_ajHistSetMultiXTitle, file);
        newXS("Bio::Emboss::ajHistSetMultiXTitleC", XS_Bio__Emboss_ajHistSetMultiXTitleC, file);
        newXS("Bio::Emboss::ajHistSetMultiYTitle", XS_Bio__Emboss_ajHistSetMultiYTitle, file);
        newXS("Bio::Emboss::ajHistSetMultiYTitleC", XS_Bio__Emboss_ajHistSetMultiYTitleC, file);
        newXS("Bio::Emboss::ajHistSetPtrToData", XS_Bio__Emboss_ajHistSetPtrToData, file);
        newXS("Bio::Emboss::ajHistCopyData", XS_Bio__Emboss_ajHistCopyData, file);
        newXS("Bio::Emboss::ajHistSetTitleC", XS_Bio__Emboss_ajHistSetTitleC, file);
        newXS("Bio::Emboss::ajHistSetXAxisC", XS_Bio__Emboss_ajHistSetXAxisC, file);
        newXS("Bio::Emboss::ajHistSetYAxisLeftC", XS_Bio__Emboss_ajHistSetYAxisLeftC, file);
        newXS("Bio::Emboss::ajHistSetYAxisRightC", XS_Bio__Emboss_ajHistSetYAxisRightC, file);
        newXS("Bio::Emboss::ajBtreeCacheNewC", XS_Bio__Emboss_ajBtreeCacheNewC, file);
        newXS("Bio::Emboss::ajBtreeCacheDel", XS_Bio__Emboss_ajBtreeCacheDel, file);
        newXS("Bio::Emboss::ajBtreeCacheRead", XS_Bio__Emboss_ajBtreeCacheRead, file);
        newXS("Bio::Emboss::ajBtreeCacheSync", XS_Bio__Emboss_ajBtreeCacheSync, file);
        newXS("Bio::Emboss::ajBtreeCacheWrite", XS_Bio__Emboss_ajBtreeCacheWrite, file);
        newXS("Bio::Emboss::ajBtreeCreateRootNode", XS_Bio__Emboss_ajBtreeCreateRootNode, file);
        newXS("Bio::Emboss::ajBtreeFindInsert", XS_Bio__Emboss_ajBtreeFindInsert, file);
        newXS("Bio::Emboss::ajBtreeIdNew", XS_Bio__Emboss_ajBtreeIdNew, file);
        newXS("Bio::Emboss::ajBtreeIdDel", XS_Bio__Emboss_ajBtreeIdDel, file);
        newXS("Bio::Emboss::ajBtreeInsertId", XS_Bio__Emboss_ajBtreeInsertId, file);
        newXS("Bio::Emboss::ajBtreeIdFromKey", XS_Bio__Emboss_ajBtreeIdFromKey, file);
        newXS("Bio::Emboss::ajBtreeWriteParams", XS_Bio__Emboss_ajBtreeWriteParams, file);
        newXS("Bio::Emboss::ajBtreeReadParams", XS_Bio__Emboss_ajBtreeReadParams, file);
        newXS("Bio::Emboss::ajBtreeDeleteId", XS_Bio__Emboss_ajBtreeDeleteId, file);
        newXS("Bio::Emboss::ajBtreeWildNew", XS_Bio__Emboss_ajBtreeWildNew, file);
        newXS("Bio::Emboss::ajBtreeWildDel", XS_Bio__Emboss_ajBtreeWildDel, file);
        newXS("Bio::Emboss::ajBtreeKeyWildNew", XS_Bio__Emboss_ajBtreeKeyWildNew, file);
        newXS("Bio::Emboss::ajBtreeKeyWildDel", XS_Bio__Emboss_ajBtreeKeyWildDel, file);
        newXS("Bio::Emboss::ajBtreeFindInsertW", XS_Bio__Emboss_ajBtreeFindInsertW, file);
        newXS("Bio::Emboss::ajBtreeIdFromKeyW", XS_Bio__Emboss_ajBtreeIdFromKeyW, file);
        newXS("Bio::Emboss::ajBtreeListFromKeyW", XS_Bio__Emboss_ajBtreeListFromKeyW, file);
        newXS("Bio::Emboss::ajBtreeReplaceId", XS_Bio__Emboss_ajBtreeReplaceId, file);
        newXS("Bio::Emboss::ajBtreeReadEntries", XS_Bio__Emboss_ajBtreeReadEntries, file);
        newXS("Bio::Emboss::ajBtreeInsertDupId", XS_Bio__Emboss_ajBtreeInsertDupId, file);
        newXS("Bio::Emboss::ajBtreeDupFromKey", XS_Bio__Emboss_ajBtreeDupFromKey, file);
        newXS("Bio::Emboss::ajBtreePriNew", XS_Bio__Emboss_ajBtreePriNew, file);
        newXS("Bio::Emboss::ajBtreePriDel", XS_Bio__Emboss_ajBtreePriDel, file);
        newXS("Bio::Emboss::ajBtreeInsertKeyword", XS_Bio__Emboss_ajBtreeInsertKeyword, file);
        newXS("Bio::Emboss::ajBtreePriFromKeyword", XS_Bio__Emboss_ajBtreePriFromKeyword, file);
        newXS("Bio::Emboss::ajBtreeSecCacheNewC", XS_Bio__Emboss_ajBtreeSecCacheNewC, file);
        newXS("Bio::Emboss::ajBtreeInsertSecId", XS_Bio__Emboss_ajBtreeInsertSecId, file);
        newXS("Bio::Emboss::ajBtreeSecFromId", XS_Bio__Emboss_ajBtreeSecFromId, file);
        newXS("Bio::Emboss::ajBtreeSecFindInsert", XS_Bio__Emboss_ajBtreeSecFindInsert, file);
        newXS("Bio::Emboss::ajBtreeLockTest", XS_Bio__Emboss_ajBtreeLockTest, file);
        newXS("Bio::Emboss::ajBtreeSecLeafList", XS_Bio__Emboss_ajBtreeSecLeafList, file);
        newXS("Bio::Emboss::ajBtreeVerifyId", XS_Bio__Emboss_ajBtreeVerifyId, file);
        newXS("Bio::Emboss::ajBtreeIdFromKeywordW", XS_Bio__Emboss_ajBtreeIdFromKeywordW, file);
        newXS("Bio::Emboss::ajBtreeListFromKeywordW", XS_Bio__Emboss_ajBtreeListFromKeywordW, file);
        newXS("Bio::Emboss::ajBtreeHybNew", XS_Bio__Emboss_ajBtreeHybNew, file);
        newXS("Bio::Emboss::ajBtreeHybDel", XS_Bio__Emboss_ajBtreeHybDel, file);
        newXS("Bio::Emboss::ajBtreeHybFindInsert", XS_Bio__Emboss_ajBtreeHybFindInsert, file);
        newXS("Bio::Emboss::ajBtreeHybInsertId", XS_Bio__Emboss_ajBtreeHybInsertId, file);
        newXS("Bio::Emboss::ajBtreeNumFindInsert", XS_Bio__Emboss_ajBtreeNumFindInsert, file);
        newXS("Bio::Emboss::ajBtreeInsertNum", XS_Bio__Emboss_ajBtreeInsertNum, file);
        newXS("Bio::Emboss::ajBtreeFreePriArray", XS_Bio__Emboss_ajBtreeFreePriArray, file);
        newXS("Bio::Emboss::ajBtreeFreeSecArray", XS_Bio__Emboss_ajBtreeFreeSecArray, file);
        newXS("Bio::Emboss::ajBtreeHybLeafList", XS_Bio__Emboss_ajBtreeHybLeafList, file);
        newXS("Bio::Emboss::ajListNew", XS_Bio__Emboss_ajListNew, file);
        newXS("Bio::Emboss::ajListstrNew", XS_Bio__Emboss_ajListstrNew, file);
        newXS("Bio::Emboss::ajListPush", XS_Bio__Emboss_ajListPush, file);
        newXS("Bio::Emboss::ajListstrPush", XS_Bio__Emboss_ajListstrPush, file);
        newXS("Bio::Emboss::ajListTrace", XS_Bio__Emboss_ajListTrace, file);
        newXS("Bio::Emboss::ajListstrTrace", XS_Bio__Emboss_ajListstrTrace, file);
        newXS("Bio::Emboss::ajListNewArgs", XS_Bio__Emboss_ajListNewArgs, file);
        newXS("Bio::Emboss::ajListstrNewArgs", XS_Bio__Emboss_ajListstrNewArgs, file);
        newXS("Bio::Emboss::ajListNodesNew", XS_Bio__Emboss_ajListNodesNew, file);
        newXS("Bio::Emboss::ajListAppend", XS_Bio__Emboss_ajListAppend, file);
        newXS("Bio::Emboss::ajListPushApp", XS_Bio__Emboss_ajListPushApp, file);
        newXS("Bio::Emboss::ajListstrPushApp", XS_Bio__Emboss_ajListstrPushApp, file);
        newXS("Bio::Emboss::ajListstrCopy", XS_Bio__Emboss_ajListstrCopy, file);
        newXS("Bio::Emboss::ajListCopy", XS_Bio__Emboss_ajListCopy, file);
        newXS("Bio::Emboss::ajListstrClone", XS_Bio__Emboss_ajListstrClone, file);
        newXS("Bio::Emboss::ajListFirst", XS_Bio__Emboss_ajListFirst, file);
        newXS("Bio::Emboss::ajListLast", XS_Bio__Emboss_ajListLast, file);
        newXS("Bio::Emboss::ajListNth", XS_Bio__Emboss_ajListNth, file);
        newXS("Bio::Emboss::ajListPop", XS_Bio__Emboss_ajListPop, file);
        newXS("Bio::Emboss::ajListPeek", XS_Bio__Emboss_ajListPeek, file);
        newXS("Bio::Emboss::ajListstrPop", XS_Bio__Emboss_ajListstrPop, file);
        newXS("Bio::Emboss::ajListstrPeek", XS_Bio__Emboss_ajListstrPeek, file);
        newXS("Bio::Emboss::ajListReverse", XS_Bio__Emboss_ajListReverse, file);
        newXS("Bio::Emboss::ajListstrReverse", XS_Bio__Emboss_ajListstrReverse, file);
        newXS("Bio::Emboss::ajListLength", XS_Bio__Emboss_ajListLength, file);
        newXS("Bio::Emboss::ajListstrLength", XS_Bio__Emboss_ajListstrLength, file);
        newXS("Bio::Emboss::ajListFree", XS_Bio__Emboss_ajListFree, file);
        newXS("Bio::Emboss::ajListstrFree", XS_Bio__Emboss_ajListstrFree, file);
        newXS("Bio::Emboss::ajListDel", XS_Bio__Emboss_ajListDel, file);
        newXS("Bio::Emboss::ajListstrDel", XS_Bio__Emboss_ajListstrDel, file);
        newXS("Bio::Emboss::ajListToArray", XS_Bio__Emboss_ajListToArray, file);
        newXS("Bio::Emboss::ajListstrToArray", XS_Bio__Emboss_ajListstrToArray, file);
        newXS("Bio::Emboss::ajListstrToArrayApp", XS_Bio__Emboss_ajListstrToArrayApp, file);
        newXS("Bio::Emboss::ajListIter", XS_Bio__Emboss_ajListIter, file);
        newXS("Bio::Emboss::ajListIterRead", XS_Bio__Emboss_ajListIterRead, file);
        newXS("Bio::Emboss::ajListIterBack", XS_Bio__Emboss_ajListIterBack, file);
        newXS("Bio::Emboss::ajListIterBackRead", XS_Bio__Emboss_ajListIterBackRead, file);
        newXS("Bio::Emboss::ajListIterDone", XS_Bio__Emboss_ajListIterDone, file);
        newXS("Bio::Emboss::ajListIterBackDone", XS_Bio__Emboss_ajListIterBackDone, file);
        newXS("Bio::Emboss::ajListIterFree", XS_Bio__Emboss_ajListIterFree, file);
        newXS("Bio::Emboss::ajListIterMore", XS_Bio__Emboss_ajListIterMore, file);
        newXS("Bio::Emboss::ajListIterBackMore", XS_Bio__Emboss_ajListIterBackMore, file);
        newXS("Bio::Emboss::ajListIterNext", XS_Bio__Emboss_ajListIterNext, file);
        newXS("Bio::Emboss::ajListIterBackNext", XS_Bio__Emboss_ajListIterBackNext, file);
        newXS("Bio::Emboss::ajListRemove", XS_Bio__Emboss_ajListRemove, file);
        newXS("Bio::Emboss::ajListstrRemove", XS_Bio__Emboss_ajListstrRemove, file);
        newXS("Bio::Emboss::ajListInsert", XS_Bio__Emboss_ajListInsert, file);
        newXS("Bio::Emboss::ajListstrInsert", XS_Bio__Emboss_ajListstrInsert, file);
        newXS("Bio::Emboss::ajListIterTrace", XS_Bio__Emboss_ajListIterTrace, file);
        newXS("Bio::Emboss::ajListstrIterTrace", XS_Bio__Emboss_ajListstrIterTrace, file);
        newXS("Bio::Emboss::ajListPushList", XS_Bio__Emboss_ajListPushList, file);
        newXS("Bio::Emboss::ajListstrPushList", XS_Bio__Emboss_ajListstrPushList, file);
        newXS("Bio::Emboss::ajListPopEnd", XS_Bio__Emboss_ajListPopEnd, file);
        newXS("Bio::Emboss::ajListstrPopEnd", XS_Bio__Emboss_ajListstrPopEnd, file);
        newXS("Bio::Emboss::ajListDummyFunction", XS_Bio__Emboss_ajListDummyFunction, file);
        newXS("Bio::Emboss::ajListExit", XS_Bio__Emboss_ajListExit, file);
        newXS("Bio::Emboss::ajRound", XS_Bio__Emboss_ajRound, file);
        newXS("Bio::Emboss::ajRoundF", XS_Bio__Emboss_ajRoundF, file);
        newXS("Bio::Emboss::ajRecToPol", XS_Bio__Emboss_ajRecToPol, file);
        newXS("Bio::Emboss::ajPolToRec", XS_Bio__Emboss_ajPolToRec, file);
        newXS("Bio::Emboss::ajDegToRad", XS_Bio__Emboss_ajDegToRad, file);
        newXS("Bio::Emboss::ajRadToDeg", XS_Bio__Emboss_ajRadToDeg, file);
        newXS("Bio::Emboss::ajGaussProb", XS_Bio__Emboss_ajGaussProb, file);
        newXS("Bio::Emboss::ajGeoMean", XS_Bio__Emboss_ajGeoMean, file);
        newXS("Bio::Emboss::ajPosMod", XS_Bio__Emboss_ajPosMod, file);
        newXS("Bio::Emboss::ajRandomSeed", XS_Bio__Emboss_ajRandomSeed, file);
        newXS("Bio::Emboss::ajRandomNumber", XS_Bio__Emboss_ajRandomNumber, file);
        newXS("Bio::Emboss::ajRandomNumberD", XS_Bio__Emboss_ajRandomNumberD, file);
        newXS("Bio::Emboss::ajSp64Crc", XS_Bio__Emboss_ajSp64Crc, file);
        newXS("Bio::Emboss::ajMathPos", XS_Bio__Emboss_ajMathPos, file);
        newXS("Bio::Emboss::ajMathPosI", XS_Bio__Emboss_ajMathPosI, file);
        newXS("Bio::Emboss::ajMatrixNew", XS_Bio__Emboss_ajMatrixNew, file);
        newXS("Bio::Emboss::ajMatrixNewAsym", XS_Bio__Emboss_ajMatrixNewAsym, file);
        newXS("Bio::Emboss::ajMatrixfNew", XS_Bio__Emboss_ajMatrixfNew, file);
        newXS("Bio::Emboss::ajMatrixfNewAsym", XS_Bio__Emboss_ajMatrixfNewAsym, file);
        newXS("Bio::Emboss::ajMatrixfDel", XS_Bio__Emboss_ajMatrixfDel, file);
        newXS("Bio::Emboss::ajMatrixDel", XS_Bio__Emboss_ajMatrixDel, file);
        newXS("Bio::Emboss::ajMatrixArray", XS_Bio__Emboss_ajMatrixArray, file);
        newXS("Bio::Emboss::ajMatrixfArray", XS_Bio__Emboss_ajMatrixfArray, file);
        newXS("Bio::Emboss::ajMatrixSize", XS_Bio__Emboss_ajMatrixSize, file);
        newXS("Bio::Emboss::ajMatrixfSize", XS_Bio__Emboss_ajMatrixfSize, file);
        newXS("Bio::Emboss::ajMatrixCvt", XS_Bio__Emboss_ajMatrixCvt, file);
        newXS("Bio::Emboss::ajMatrixfCvt", XS_Bio__Emboss_ajMatrixfCvt, file);
        newXS("Bio::Emboss::ajMatrixChar", XS_Bio__Emboss_ajMatrixChar, file);
        newXS("Bio::Emboss::ajMatrixfChar", XS_Bio__Emboss_ajMatrixfChar, file);
        newXS("Bio::Emboss::ajMatrixName", XS_Bio__Emboss_ajMatrixName, file);
        newXS("Bio::Emboss::ajMatrixfName", XS_Bio__Emboss_ajMatrixfName, file);
        newXS("Bio::Emboss::ajMatrixRead", XS_Bio__Emboss_ajMatrixRead, file);
        newXS("Bio::Emboss::ajMatrixfRead", XS_Bio__Emboss_ajMatrixfRead, file);
        newXS("Bio::Emboss::ajMatrixSeqNum", XS_Bio__Emboss_ajMatrixSeqNum, file);
        newXS("Bio::Emboss::ajMatrixfSeqNum", XS_Bio__Emboss_ajMatrixfSeqNum, file);
        newXS("Bio::Emboss::ajMatrixGetCodes", XS_Bio__Emboss_ajMatrixGetCodes, file);
        newXS("Bio::Emboss::ajMatrixfGetCodes", XS_Bio__Emboss_ajMatrixfGetCodes, file);
        newXS("Bio::Emboss::ajMemAlloc", XS_Bio__Emboss_ajMemAlloc, file);
        newXS("Bio::Emboss::ajMemCalloc", XS_Bio__Emboss_ajMemCalloc, file);
        newXS("Bio::Emboss::ajMemCalloc0", XS_Bio__Emboss_ajMemCalloc0, file);
        newXS("Bio::Emboss::ajMemFree", XS_Bio__Emboss_ajMemFree, file);
        newXS("Bio::Emboss::ajMemResize", XS_Bio__Emboss_ajMemResize, file);
        newXS("Bio::Emboss::ajMemArrB", XS_Bio__Emboss_ajMemArrB, file);
        newXS("Bio::Emboss::ajMemArrI", XS_Bio__Emboss_ajMemArrI, file);
        newXS("Bio::Emboss::ajMemArrF", XS_Bio__Emboss_ajMemArrF, file);
        newXS("Bio::Emboss::ajMemStat", XS_Bio__Emboss_ajMemStat, file);
        newXS("Bio::Emboss::ajMemExit", XS_Bio__Emboss_ajMemExit, file);
        newXS("Bio::Emboss::ajMessInvokeDebugger", XS_Bio__Emboss_ajMessInvokeDebugger, file);
        newXS("Bio::Emboss::ajMessBeep", XS_Bio__Emboss_ajMessBeep, file);
        newXS("Bio::Emboss::ajUser", XS_Bio__Emboss_ajUser, file);
        newXS("Bio::Emboss::ajMessOut", XS_Bio__Emboss_ajMessOut, file);
        newXS("Bio::Emboss::ajMessDump", XS_Bio__Emboss_ajMessDump, file);
        newXS("Bio::Emboss::ajMessErrorCount", XS_Bio__Emboss_ajMessErrorCount, file);
        newXS("Bio::Emboss::ajErr", XS_Bio__Emboss_ajErr, file);
        newXS("Bio::Emboss::ajDie", XS_Bio__Emboss_ajDie, file);
        newXS("Bio::Emboss::ajWarn", XS_Bio__Emboss_ajWarn, file);
        newXS("Bio::Emboss::ajMessExitmsg", XS_Bio__Emboss_ajMessExitmsg, file);
        newXS("Bio::Emboss::ajMessCrashFL", XS_Bio__Emboss_ajMessCrashFL, file);
        newXS("Bio::Emboss::ajMessCaughtMessage", XS_Bio__Emboss_ajMessCaughtMessage, file);
        newXS("Bio::Emboss::ajMessSysErrorText", XS_Bio__Emboss_ajMessSysErrorText, file);
        newXS("Bio::Emboss::ajMessErrorInit", XS_Bio__Emboss_ajMessErrorInit, file);
        newXS("Bio::Emboss::ajMessSetErr", XS_Bio__Emboss_ajMessSetErr, file);
        newXS("Bio::Emboss::ajMessErrorSetFile", XS_Bio__Emboss_ajMessErrorSetFile, file);
        newXS("Bio::Emboss::ajMessOutCode", XS_Bio__Emboss_ajMessOutCode, file);
        newXS("Bio::Emboss::ajMessErrorCode", XS_Bio__Emboss_ajMessErrorCode, file);
        newXS("Bio::Emboss::ajMessCrashCodeFL", XS_Bio__Emboss_ajMessCrashCodeFL, file);
        newXS("Bio::Emboss::ajMessCodesDelete", XS_Bio__Emboss_ajMessCodesDelete, file);
        newXS("Bio::Emboss::ajDebug", XS_Bio__Emboss_ajDebug, file);
        newXS("Bio::Emboss::ajDebugFile", XS_Bio__Emboss_ajDebugFile, file);
        newXS("Bio::Emboss::ajUserGet", XS_Bio__Emboss_ajUserGet, file);
        newXS("Bio::Emboss::ajMessExit", XS_Bio__Emboss_ajMessExit, file);
        newXS("Bio::Emboss::ajNamPrintDbAttr", XS_Bio__Emboss_ajNamPrintDbAttr, file);
        newXS("Bio::Emboss::ajNamPrintRsAttr", XS_Bio__Emboss_ajNamPrintRsAttr, file);
        newXS("Bio::Emboss::ajNamDbDetails", XS_Bio__Emboss_ajNamDbDetails, file);
        newXS("Bio::Emboss::ajNamListOrigin", XS_Bio__Emboss_ajNamListOrigin, file);
        newXS("Bio::Emboss::ajNamDebugOrigin", XS_Bio__Emboss_ajNamDebugOrigin, file);
        newXS("Bio::Emboss::ajNamListDatabases", XS_Bio__Emboss_ajNamListDatabases, file);
        newXS("Bio::Emboss::ajNamDebugDatabases", XS_Bio__Emboss_ajNamDebugDatabases, file);
        newXS("Bio::Emboss::ajNamDebugResources", XS_Bio__Emboss_ajNamDebugResources, file);
        newXS("Bio::Emboss::ajNamDebugVariables", XS_Bio__Emboss_ajNamDebugVariables, file);
        newXS("Bio::Emboss::ajNamListListDatabases", XS_Bio__Emboss_ajNamListListDatabases, file);
        newXS("Bio::Emboss::ajNamListListResources", XS_Bio__Emboss_ajNamListListResources, file);
        newXS("Bio::Emboss::ajNamVariables", XS_Bio__Emboss_ajNamVariables, file);
        newXS("Bio::Emboss::ajNamIsDbname", XS_Bio__Emboss_ajNamIsDbname, file);
        newXS("Bio::Emboss::ajNamGetenv", XS_Bio__Emboss_ajNamGetenv, file);
        newXS("Bio::Emboss::ajNamGetenvC", XS_Bio__Emboss_ajNamGetenvC, file);
        newXS("Bio::Emboss::ajNamGetValue", XS_Bio__Emboss_ajNamGetValue, file);
        newXS("Bio::Emboss::ajNamGetValueC", XS_Bio__Emboss_ajNamGetValueC, file);
        newXS("Bio::Emboss::ajNamDatabase", XS_Bio__Emboss_ajNamDatabase, file);
        newXS("Bio::Emboss::ajNamInit", XS_Bio__Emboss_ajNamInit, file);
        newXS("Bio::Emboss::ajNamExit", XS_Bio__Emboss_ajNamExit, file);
        newXS("Bio::Emboss::ajNamDbTest", XS_Bio__Emboss_ajNamDbTest, file);
        newXS("Bio::Emboss::ajNamDbGetUrl", XS_Bio__Emboss_ajNamDbGetUrl, file);
        newXS("Bio::Emboss::ajNamDbGetDbalias", XS_Bio__Emboss_ajNamDbGetDbalias, file);
        newXS("Bio::Emboss::ajNamDbData", XS_Bio__Emboss_ajNamDbData, file);
        newXS("Bio::Emboss::ajNamDbQuery", XS_Bio__Emboss_ajNamDbQuery, file);
        newXS("Bio::Emboss::ajNamRootInstall", XS_Bio__Emboss_ajNamRootInstall, file);
        newXS("Bio::Emboss::ajNamRootPack", XS_Bio__Emboss_ajNamRootPack, file);
        newXS("Bio::Emboss::ajNamRootVersion", XS_Bio__Emboss_ajNamRootVersion, file);
        newXS("Bio::Emboss::ajNamRoot", XS_Bio__Emboss_ajNamRoot, file);
        newXS("Bio::Emboss::ajNamRootBase", XS_Bio__Emboss_ajNamRootBase, file);
        newXS("Bio::Emboss::ajNamResolve", XS_Bio__Emboss_ajNamResolve, file);
        newXS("Bio::Emboss::ajNamSetControl", XS_Bio__Emboss_ajNamSetControl, file);
        newXS("Bio::Emboss::ajNamRsAttrValue", XS_Bio__Emboss_ajNamRsAttrValue, file);
        newXS("Bio::Emboss::ajNamRsAttrValueC", XS_Bio__Emboss_ajNamRsAttrValueC, file);
        newXS("Bio::Emboss::ajNamRsListValue", XS_Bio__Emboss_ajNamRsListValue, file);
        newXS("Bio::Emboss::ajNexusParse", XS_Bio__Emboss_ajNexusParse, file);
        newXS("Bio::Emboss::ajNexusNew", XS_Bio__Emboss_ajNexusNew, file);
        newXS("Bio::Emboss::ajNexusDel", XS_Bio__Emboss_ajNexusDel, file);
        newXS("Bio::Emboss::ajNexusTrace", XS_Bio__Emboss_ajNexusTrace, file);
        newXS("Bio::Emboss::ajNexusGetTaxa", XS_Bio__Emboss_ajNexusGetTaxa, file);
        newXS("Bio::Emboss::ajNexusGetNtaxa", XS_Bio__Emboss_ajNexusGetNtaxa, file);
        newXS("Bio::Emboss::ajNexusGetSequences", XS_Bio__Emboss_ajNexusGetSequences, file);
        newXS("Bio::Emboss::ajPdbtospReadAllRawNew", XS_Bio__Emboss_ajPdbtospReadAllRawNew, file);
        newXS("Bio::Emboss::ajPdbtospReadNew", XS_Bio__Emboss_ajPdbtospReadNew, file);
        newXS("Bio::Emboss::ajPdbtospReadCNew", XS_Bio__Emboss_ajPdbtospReadCNew, file);
        newXS("Bio::Emboss::ajPdbtospReadAllNew", XS_Bio__Emboss_ajPdbtospReadAllNew, file);
        newXS("Bio::Emboss::ajCmapReadINew", XS_Bio__Emboss_ajCmapReadINew, file);
        newXS("Bio::Emboss::ajCmapReadCNew", XS_Bio__Emboss_ajCmapReadCNew, file);
        newXS("Bio::Emboss::ajCmapReadAllNew", XS_Bio__Emboss_ajCmapReadAllNew, file);
        newXS("Bio::Emboss::ajCmapReadNew", XS_Bio__Emboss_ajCmapReadNew, file);
        newXS("Bio::Emboss::ajVdwallReadNew", XS_Bio__Emboss_ajVdwallReadNew, file);
        newXS("Bio::Emboss::ajHetReadNew", XS_Bio__Emboss_ajHetReadNew, file);
        newXS("Bio::Emboss::ajHetReadRawNew", XS_Bio__Emboss_ajHetReadRawNew, file);
        newXS("Bio::Emboss::ajPdbReadFirstModelNew", XS_Bio__Emboss_ajPdbReadFirstModelNew, file);
        newXS("Bio::Emboss::ajPdbReadAllModelsNew", XS_Bio__Emboss_ajPdbReadAllModelsNew, file);
        newXS("Bio::Emboss::ajPdbReadNew", XS_Bio__Emboss_ajPdbReadNew, file);
        newXS("Bio::Emboss::ajPdbReadoldNew", XS_Bio__Emboss_ajPdbReadoldNew, file);
        newXS("Bio::Emboss::ajPdbReadoldFirstModelNew", XS_Bio__Emboss_ajPdbReadoldFirstModelNew, file);
        newXS("Bio::Emboss::ajAtomNew", XS_Bio__Emboss_ajAtomNew, file);
        newXS("Bio::Emboss::ajResidueNew", XS_Bio__Emboss_ajResidueNew, file);
        newXS("Bio::Emboss::ajChainNew", XS_Bio__Emboss_ajChainNew, file);
        newXS("Bio::Emboss::ajPdbNew", XS_Bio__Emboss_ajPdbNew, file);
        newXS("Bio::Emboss::ajHetentNew", XS_Bio__Emboss_ajHetentNew, file);
        newXS("Bio::Emboss::ajHetNew", XS_Bio__Emboss_ajHetNew, file);
        newXS("Bio::Emboss::ajVdwallNew", XS_Bio__Emboss_ajVdwallNew, file);
        newXS("Bio::Emboss::ajVdwresNew", XS_Bio__Emboss_ajVdwresNew, file);
        newXS("Bio::Emboss::ajCmapNew", XS_Bio__Emboss_ajCmapNew, file);
        newXS("Bio::Emboss::ajPdbtospNew", XS_Bio__Emboss_ajPdbtospNew, file);
        newXS("Bio::Emboss::ajAtomDel", XS_Bio__Emboss_ajAtomDel, file);
        newXS("Bio::Emboss::ajResidueDel", XS_Bio__Emboss_ajResidueDel, file);
        newXS("Bio::Emboss::ajChainDel", XS_Bio__Emboss_ajChainDel, file);
        newXS("Bio::Emboss::ajPdbDel", XS_Bio__Emboss_ajPdbDel, file);
        newXS("Bio::Emboss::ajHetentDel", XS_Bio__Emboss_ajHetentDel, file);
        newXS("Bio::Emboss::ajHetDel", XS_Bio__Emboss_ajHetDel, file);
        newXS("Bio::Emboss::ajVdwallDel", XS_Bio__Emboss_ajVdwallDel, file);
        newXS("Bio::Emboss::ajVdwresDel", XS_Bio__Emboss_ajVdwresDel, file);
        newXS("Bio::Emboss::ajCmapDel", XS_Bio__Emboss_ajCmapDel, file);
        newXS("Bio::Emboss::ajPdbtospDel", XS_Bio__Emboss_ajPdbtospDel, file);
        newXS("Bio::Emboss::ajAtomCopy", XS_Bio__Emboss_ajAtomCopy, file);
        newXS("Bio::Emboss::ajResidueCopy", XS_Bio__Emboss_ajResidueCopy, file);
        newXS("Bio::Emboss::ajAtomListCopy", XS_Bio__Emboss_ajAtomListCopy, file);
        newXS("Bio::Emboss::ajResidueListCopy", XS_Bio__Emboss_ajResidueListCopy, file);
        newXS("Bio::Emboss::ajPdbCopy", XS_Bio__Emboss_ajPdbCopy, file);
        newXS("Bio::Emboss::ajResidueSSEnv", XS_Bio__Emboss_ajResidueSSEnv, file);
        newXS("Bio::Emboss::ajResidueEnv1", XS_Bio__Emboss_ajResidueEnv1, file);
        newXS("Bio::Emboss::ajResidueEnv2", XS_Bio__Emboss_ajResidueEnv2, file);
        newXS("Bio::Emboss::ajResidueEnv3", XS_Bio__Emboss_ajResidueEnv3, file);
        newXS("Bio::Emboss::ajResidueEnv4", XS_Bio__Emboss_ajResidueEnv4, file);
        newXS("Bio::Emboss::ajResidueEnv5", XS_Bio__Emboss_ajResidueEnv5, file);
        newXS("Bio::Emboss::ajResidueEnv6", XS_Bio__Emboss_ajResidueEnv6, file);
        newXS("Bio::Emboss::ajResidueEnv7", XS_Bio__Emboss_ajResidueEnv7, file);
        newXS("Bio::Emboss::ajResidueEnv8", XS_Bio__Emboss_ajResidueEnv8, file);
        newXS("Bio::Emboss::ajResidueEnv9", XS_Bio__Emboss_ajResidueEnv9, file);
        newXS("Bio::Emboss::ajResidueEnv10", XS_Bio__Emboss_ajResidueEnv10, file);
        newXS("Bio::Emboss::ajResidueEnv11", XS_Bio__Emboss_ajResidueEnv11, file);
        newXS("Bio::Emboss::ajResidueEnv12", XS_Bio__Emboss_ajResidueEnv12, file);
        newXS("Bio::Emboss::ajResidueEnv13", XS_Bio__Emboss_ajResidueEnv13, file);
        newXS("Bio::Emboss::ajResidueEnv14", XS_Bio__Emboss_ajResidueEnv14, file);
        newXS("Bio::Emboss::ajResidueEnv15", XS_Bio__Emboss_ajResidueEnv15, file);
        newXS("Bio::Emboss::ajResidueEnv16", XS_Bio__Emboss_ajResidueEnv16, file);
        newXS("Bio::Emboss::ajPdbGetEStrideType", XS_Bio__Emboss_ajPdbGetEStrideType, file);
        newXS("Bio::Emboss::ajPdbChnidToNum", XS_Bio__Emboss_ajPdbChnidToNum, file);
        newXS("Bio::Emboss::ajPdbtospArrFindPdbid", XS_Bio__Emboss_ajPdbtospArrFindPdbid, file);
        newXS("Bio::Emboss::ajPdbWriteAll", XS_Bio__Emboss_ajPdbWriteAll, file);
        newXS("Bio::Emboss::ajPdbWriteSegment", XS_Bio__Emboss_ajPdbWriteSegment, file);
        newXS("Bio::Emboss::ajHetWrite", XS_Bio__Emboss_ajHetWrite, file);
        newXS("Bio::Emboss::ajPdbtospWrite", XS_Bio__Emboss_ajPdbtospWrite, file);
        newXS("Bio::Emboss::ajCmapWrite", XS_Bio__Emboss_ajCmapWrite, file);
        newXS("Bio::Emboss::ajPdbWriteDomainRecordRaw", XS_Bio__Emboss_ajPdbWriteDomainRecordRaw, file);
        newXS("Bio::Emboss::ajPdbWriteRecordRaw", XS_Bio__Emboss_ajPdbWriteRecordRaw, file);
        newXS("Bio::Emboss::ajPdbWriteAllRaw", XS_Bio__Emboss_ajPdbWriteAllRaw, file);
        newXS("Bio::Emboss::ajPdbWriteDomainRaw", XS_Bio__Emboss_ajPdbWriteDomainRaw, file);
        newXS("Bio::Emboss::ajPhyloDistNew", XS_Bio__Emboss_ajPhyloDistNew, file);
        newXS("Bio::Emboss::ajPhyloFreqNew", XS_Bio__Emboss_ajPhyloFreqNew, file);
        newXS("Bio::Emboss::ajPhyloPropNew", XS_Bio__Emboss_ajPhyloPropNew, file);
        newXS("Bio::Emboss::ajPhyloStateNew", XS_Bio__Emboss_ajPhyloStateNew, file);
        newXS("Bio::Emboss::ajPhyloTreeNew", XS_Bio__Emboss_ajPhyloTreeNew, file);
        newXS("Bio::Emboss::ajPhyloDistDel", XS_Bio__Emboss_ajPhyloDistDel, file);
        newXS("Bio::Emboss::ajPhyloFreqDel", XS_Bio__Emboss_ajPhyloFreqDel, file);
        newXS("Bio::Emboss::ajPhyloPropDel", XS_Bio__Emboss_ajPhyloPropDel, file);
        newXS("Bio::Emboss::ajPhyloStateDel", XS_Bio__Emboss_ajPhyloStateDel, file);
        newXS("Bio::Emboss::ajPhyloTreeDel", XS_Bio__Emboss_ajPhyloTreeDel, file);
        newXS("Bio::Emboss::ajPhyloDistRead", XS_Bio__Emboss_ajPhyloDistRead, file);
        newXS("Bio::Emboss::ajPhyloDistTrace", XS_Bio__Emboss_ajPhyloDistTrace, file);
        newXS("Bio::Emboss::ajPhyloFreqRead", XS_Bio__Emboss_ajPhyloFreqRead, file);
        newXS("Bio::Emboss::ajPhyloFreqTrace", XS_Bio__Emboss_ajPhyloFreqTrace, file);
        newXS("Bio::Emboss::ajPhyloPropRead", XS_Bio__Emboss_ajPhyloPropRead, file);
        newXS("Bio::Emboss::ajPhyloPropGetSize", XS_Bio__Emboss_ajPhyloPropGetSize, file);
        newXS("Bio::Emboss::ajPhyloPropTrace", XS_Bio__Emboss_ajPhyloPropTrace, file);
        newXS("Bio::Emboss::ajPhyloStateRead", XS_Bio__Emboss_ajPhyloStateRead, file);
        newXS("Bio::Emboss::ajPhyloStateTrace", XS_Bio__Emboss_ajPhyloStateTrace, file);
        newXS("Bio::Emboss::ajPhyloTreeRead", XS_Bio__Emboss_ajPhyloTreeRead, file);
        newXS("Bio::Emboss::ajPhyloTreeTrace", XS_Bio__Emboss_ajPhyloTreeTrace, file);
        newXS("Bio::Emboss::ajRangeNewI", XS_Bio__Emboss_ajRangeNewI, file);
        newXS("Bio::Emboss::ajRangeCopy", XS_Bio__Emboss_ajRangeCopy, file);
        newXS("Bio::Emboss::ajRangeDel", XS_Bio__Emboss_ajRangeDel, file);
        newXS("Bio::Emboss::ajRangeGet", XS_Bio__Emboss_ajRangeGet, file);
        newXS("Bio::Emboss::ajRangeGetLimits", XS_Bio__Emboss_ajRangeGetLimits, file);
        newXS("Bio::Emboss::ajRangeFile", XS_Bio__Emboss_ajRangeFile, file);
        newXS("Bio::Emboss::ajRangeFileLimits", XS_Bio__Emboss_ajRangeFileLimits, file);
        newXS("Bio::Emboss::ajRangeNumber", XS_Bio__Emboss_ajRangeNumber, file);
        newXS("Bio::Emboss::ajRangeValues", XS_Bio__Emboss_ajRangeValues, file);
        newXS("Bio::Emboss::ajRangeText", XS_Bio__Emboss_ajRangeText, file);
        newXS("Bio::Emboss::ajRangeChange", XS_Bio__Emboss_ajRangeChange, file);
        newXS("Bio::Emboss::ajRangeBegin", XS_Bio__Emboss_ajRangeBegin, file);
        newXS("Bio::Emboss::ajRangeSeqExtractList", XS_Bio__Emboss_ajRangeSeqExtractList, file);
        newXS("Bio::Emboss::ajRangeSeqExtract", XS_Bio__Emboss_ajRangeSeqExtract, file);
        newXS("Bio::Emboss::ajRangeSeqStuff", XS_Bio__Emboss_ajRangeSeqStuff, file);
        newXS("Bio::Emboss::ajRangeSeqMask", XS_Bio__Emboss_ajRangeSeqMask, file);
        newXS("Bio::Emboss::ajRangeSeqToLower", XS_Bio__Emboss_ajRangeSeqToLower, file);
        newXS("Bio::Emboss::ajRangeStrExtractList", XS_Bio__Emboss_ajRangeStrExtractList, file);
        newXS("Bio::Emboss::ajRangeStrExtract", XS_Bio__Emboss_ajRangeStrExtract, file);
        newXS("Bio::Emboss::ajRangeStrStuff", XS_Bio__Emboss_ajRangeStrStuff, file);
        newXS("Bio::Emboss::ajRangeStrMask", XS_Bio__Emboss_ajRangeStrMask, file);
        newXS("Bio::Emboss::ajRangeStrToLower", XS_Bio__Emboss_ajRangeStrToLower, file);
        newXS("Bio::Emboss::ajRangeOverlapSingle", XS_Bio__Emboss_ajRangeOverlapSingle, file);
        newXS("Bio::Emboss::ajRangeOverlaps", XS_Bio__Emboss_ajRangeOverlaps, file);
        newXS("Bio::Emboss::ajRangeOrdered", XS_Bio__Emboss_ajRangeOrdered, file);
        newXS("Bio::Emboss::ajRangeDefault", XS_Bio__Emboss_ajRangeDefault, file);
        newXS("Bio::Emboss::ajRegComp", XS_Bio__Emboss_ajRegComp, file);
        newXS("Bio::Emboss::ajRegCompC", XS_Bio__Emboss_ajRegCompC, file);
        newXS("Bio::Emboss::ajRegCompCase", XS_Bio__Emboss_ajRegCompCase, file);
        newXS("Bio::Emboss::ajRegCompCaseC", XS_Bio__Emboss_ajRegCompCaseC, file);
        newXS("Bio::Emboss::ajRegExec", XS_Bio__Emboss_ajRegExec, file);
        newXS("Bio::Emboss::ajRegExecB", XS_Bio__Emboss_ajRegExecB, file);
        newXS("Bio::Emboss::ajRegExecC", XS_Bio__Emboss_ajRegExecC, file);
        newXS("Bio::Emboss::ajRegOffset", XS_Bio__Emboss_ajRegOffset, file);
        newXS("Bio::Emboss::ajRegOffsetI", XS_Bio__Emboss_ajRegOffsetI, file);
        newXS("Bio::Emboss::ajRegLenI", XS_Bio__Emboss_ajRegLenI, file);
        newXS("Bio::Emboss::ajRegPost", XS_Bio__Emboss_ajRegPost, file);
        newXS("Bio::Emboss::ajRegPostC", XS_Bio__Emboss_ajRegPostC, file);
        newXS("Bio::Emboss::ajRegPre", XS_Bio__Emboss_ajRegPre, file);
        newXS("Bio::Emboss::ajRegSubI", XS_Bio__Emboss_ajRegSubI, file);
        newXS("Bio::Emboss::ajRegFree", XS_Bio__Emboss_ajRegFree, file);
        newXS("Bio::Emboss::ajRegTrace", XS_Bio__Emboss_ajRegTrace, file);
        newXS("Bio::Emboss::ajRegExit", XS_Bio__Emboss_ajRegExit, file);
        newXS("Bio::Emboss::ajReportDel", XS_Bio__Emboss_ajReportDel, file);
        newXS("Bio::Emboss::ajReportOpen", XS_Bio__Emboss_ajReportOpen, file);
        newXS("Bio::Emboss::ajReportFormatDefault", XS_Bio__Emboss_ajReportFormatDefault, file);
        newXS("Bio::Emboss::ajReportFindFormat", XS_Bio__Emboss_ajReportFindFormat, file);
        newXS("Bio::Emboss::ajReportSetTags", XS_Bio__Emboss_ajReportSetTags, file);
        newXS("Bio::Emboss::ajReportValid", XS_Bio__Emboss_ajReportValid, file);
        newXS("Bio::Emboss::ajReportNew", XS_Bio__Emboss_ajReportNew, file);
        newXS("Bio::Emboss::ajReportWrite", XS_Bio__Emboss_ajReportWrite, file);
        newXS("Bio::Emboss::ajReportClose", XS_Bio__Emboss_ajReportClose, file);
        newXS("Bio::Emboss::ajReportLists", XS_Bio__Emboss_ajReportLists, file);
        newXS("Bio::Emboss::ajReportWriteHeader", XS_Bio__Emboss_ajReportWriteHeader, file);
        newXS("Bio::Emboss::ajReportWriteTail", XS_Bio__Emboss_ajReportWriteTail, file);
        newXS("Bio::Emboss::ajReportSetHeader", XS_Bio__Emboss_ajReportSetHeader, file);
        newXS("Bio::Emboss::ajReportSetHeaderC", XS_Bio__Emboss_ajReportSetHeaderC, file);
        newXS("Bio::Emboss::ajReportSetSubHeader", XS_Bio__Emboss_ajReportSetSubHeader, file);
        newXS("Bio::Emboss::ajReportSetSubHeaderC", XS_Bio__Emboss_ajReportSetSubHeaderC, file);
        newXS("Bio::Emboss::ajReportSetTail", XS_Bio__Emboss_ajReportSetTail, file);
        newXS("Bio::Emboss::ajReportSetTailC", XS_Bio__Emboss_ajReportSetTailC, file);
        newXS("Bio::Emboss::ajReportSetSubTail", XS_Bio__Emboss_ajReportSetSubTail, file);
        newXS("Bio::Emboss::ajReportSetSubTailC", XS_Bio__Emboss_ajReportSetSubTailC, file);
        newXS("Bio::Emboss::ajReportSetType", XS_Bio__Emboss_ajReportSetType, file);
        newXS("Bio::Emboss::ajReportSeqName", XS_Bio__Emboss_ajReportSeqName, file);
        newXS("Bio::Emboss::ajReportFileAdd", XS_Bio__Emboss_ajReportFileAdd, file);
        newXS("Bio::Emboss::ajReportPrintFormat", XS_Bio__Emboss_ajReportPrintFormat, file);
        newXS("Bio::Emboss::ajReportDummyFunction", XS_Bio__Emboss_ajReportDummyFunction, file);
        newXS("Bio::Emboss::ajReportExit", XS_Bio__Emboss_ajReportExit, file);
        newXS("Bio::Emboss::ajSeqNew", XS_Bio__Emboss_ajSeqNew, file);
        newXS("Bio::Emboss::ajSeqNewNameC", XS_Bio__Emboss_ajSeqNewNameC, file);
        newXS("Bio::Emboss::ajSeqNewNameS", XS_Bio__Emboss_ajSeqNewNameS, file);
        newXS("Bio::Emboss::ajSeqNewRangeC", XS_Bio__Emboss_ajSeqNewRangeC, file);
        newXS("Bio::Emboss::ajSeqNewRangeS", XS_Bio__Emboss_ajSeqNewRangeS, file);
        newXS("Bio::Emboss::ajSeqNewRes", XS_Bio__Emboss_ajSeqNewRes, file);
        newXS("Bio::Emboss::ajSeqNewSeq", XS_Bio__Emboss_ajSeqNewSeq, file);
        newXS("Bio::Emboss::ajSeqAssignAccC", XS_Bio__Emboss_ajSeqAssignAccC, file);
        newXS("Bio::Emboss::ajSeqAssignAccS", XS_Bio__Emboss_ajSeqAssignAccS, file);
        newXS("Bio::Emboss::ajSeqAssignDescC", XS_Bio__Emboss_ajSeqAssignDescC, file);
        newXS("Bio::Emboss::ajSeqAssignDescS", XS_Bio__Emboss_ajSeqAssignDescS, file);
        newXS("Bio::Emboss::ajSeqAssignEntryC", XS_Bio__Emboss_ajSeqAssignEntryC, file);
        newXS("Bio::Emboss::ajSeqAssignEntryS", XS_Bio__Emboss_ajSeqAssignEntryS, file);
        newXS("Bio::Emboss::ajSeqAssignFileC", XS_Bio__Emboss_ajSeqAssignFileC, file);
        newXS("Bio::Emboss::ajSeqAssignFileS", XS_Bio__Emboss_ajSeqAssignFileS, file);
        newXS("Bio::Emboss::ajSeqAssignFullC", XS_Bio__Emboss_ajSeqAssignFullC, file);
        newXS("Bio::Emboss::ajSeqAssignFullS", XS_Bio__Emboss_ajSeqAssignFullS, file);
        newXS("Bio::Emboss::ajSeqAssignGiC", XS_Bio__Emboss_ajSeqAssignGiC, file);
        newXS("Bio::Emboss::ajSeqAssignGiS", XS_Bio__Emboss_ajSeqAssignGiS, file);
        newXS("Bio::Emboss::ajSeqAssignNameC", XS_Bio__Emboss_ajSeqAssignNameC, file);
        newXS("Bio::Emboss::ajSeqAssignNameS", XS_Bio__Emboss_ajSeqAssignNameS, file);
        newXS("Bio::Emboss::ajSeqAssignSeqC", XS_Bio__Emboss_ajSeqAssignSeqC, file);
        newXS("Bio::Emboss::ajSeqAssignSeqLenC", XS_Bio__Emboss_ajSeqAssignSeqLenC, file);
        newXS("Bio::Emboss::ajSeqAssignSeqS", XS_Bio__Emboss_ajSeqAssignSeqS, file);
        newXS("Bio::Emboss::ajSeqAssignSvC", XS_Bio__Emboss_ajSeqAssignSvC, file);
        newXS("Bio::Emboss::ajSeqAssignSvS", XS_Bio__Emboss_ajSeqAssignSvS, file);
        newXS("Bio::Emboss::ajSeqAssignUfoC", XS_Bio__Emboss_ajSeqAssignUfoC, file);
        newXS("Bio::Emboss::ajSeqAssignUfoS", XS_Bio__Emboss_ajSeqAssignUfoS, file);
        newXS("Bio::Emboss::ajSeqAssignUsaC", XS_Bio__Emboss_ajSeqAssignUsaC, file);
        newXS("Bio::Emboss::ajSeqAssignUsaS", XS_Bio__Emboss_ajSeqAssignUsaS, file);
        newXS("Bio::Emboss::ajSeqSetOffsets", XS_Bio__Emboss_ajSeqSetOffsets, file);
        newXS("Bio::Emboss::ajSeqSetRange", XS_Bio__Emboss_ajSeqSetRange, file);
        newXS("Bio::Emboss::ajSeqSetRangeRev", XS_Bio__Emboss_ajSeqSetRangeRev, file);
        newXS("Bio::Emboss::ajSeqComplementOnly", XS_Bio__Emboss_ajSeqComplementOnly, file);
        newXS("Bio::Emboss::ajSeqFmtLower", XS_Bio__Emboss_ajSeqFmtLower, file);
        newXS("Bio::Emboss::ajSeqFmtUpper", XS_Bio__Emboss_ajSeqFmtUpper, file);
        newXS("Bio::Emboss::ajSeqReverseDo", XS_Bio__Emboss_ajSeqReverseDo, file);
        newXS("Bio::Emboss::ajSeqReverseForce", XS_Bio__Emboss_ajSeqReverseForce, file);
        newXS("Bio::Emboss::ajSeqReverseOnly", XS_Bio__Emboss_ajSeqReverseOnly, file);
        newXS("Bio::Emboss::ajSeqGetAccC", XS_Bio__Emboss_ajSeqGetAccC, file);
        newXS("Bio::Emboss::ajSeqGetAccS", XS_Bio__Emboss_ajSeqGetAccS, file);
        newXS("Bio::Emboss::ajSeqGetBegin", XS_Bio__Emboss_ajSeqGetBegin, file);
        newXS("Bio::Emboss::ajSeqGetBeginTrue", XS_Bio__Emboss_ajSeqGetBeginTrue, file);
        newXS("Bio::Emboss::ajSeqGetDescC", XS_Bio__Emboss_ajSeqGetDescC, file);
        newXS("Bio::Emboss::ajSeqGetDescS", XS_Bio__Emboss_ajSeqGetDescS, file);
        newXS("Bio::Emboss::ajSeqGetEnd", XS_Bio__Emboss_ajSeqGetEnd, file);
        newXS("Bio::Emboss::ajSeqGetEndTrue", XS_Bio__Emboss_ajSeqGetEndTrue, file);
        newXS("Bio::Emboss::ajSeqGetEntryC", XS_Bio__Emboss_ajSeqGetEntryC, file);
        newXS("Bio::Emboss::ajSeqGetEntryS", XS_Bio__Emboss_ajSeqGetEntryS, file);
        newXS("Bio::Emboss::ajSeqGetFeat", XS_Bio__Emboss_ajSeqGetFeat, file);
        newXS("Bio::Emboss::ajSeqGetFeatCopy", XS_Bio__Emboss_ajSeqGetFeatCopy, file);
        newXS("Bio::Emboss::ajSeqGetGiC", XS_Bio__Emboss_ajSeqGetGiC, file);
        newXS("Bio::Emboss::ajSeqGetGiS", XS_Bio__Emboss_ajSeqGetGiS, file);
        newXS("Bio::Emboss::ajSeqGetLen", XS_Bio__Emboss_ajSeqGetLen, file);
        newXS("Bio::Emboss::ajSeqGetLenTrue", XS_Bio__Emboss_ajSeqGetLenTrue, file);
        newXS("Bio::Emboss::ajSeqGetNameC", XS_Bio__Emboss_ajSeqGetNameC, file);
        newXS("Bio::Emboss::ajSeqGetNameS", XS_Bio__Emboss_ajSeqGetNameS, file);
        newXS("Bio::Emboss::ajSeqGetOffend", XS_Bio__Emboss_ajSeqGetOffend, file);
        newXS("Bio::Emboss::ajSeqGetOffset", XS_Bio__Emboss_ajSeqGetOffset, file);
        newXS("Bio::Emboss::ajSeqGetRange", XS_Bio__Emboss_ajSeqGetRange, file);
        newXS("Bio::Emboss::ajSeqGetRev", XS_Bio__Emboss_ajSeqGetRev, file);
        newXS("Bio::Emboss::ajSeqGetSeqC", XS_Bio__Emboss_ajSeqGetSeqC, file);
        newXS("Bio::Emboss::ajSeqGetSeqS", XS_Bio__Emboss_ajSeqGetSeqS, file);
        newXS("Bio::Emboss::ajSeqGetSeqCopyC", XS_Bio__Emboss_ajSeqGetSeqCopyC, file);
        newXS("Bio::Emboss::ajSeqGetSeqCopyS", XS_Bio__Emboss_ajSeqGetSeqCopyS, file);
        newXS("Bio::Emboss::ajSeqGetSvC", XS_Bio__Emboss_ajSeqGetSvC, file);
        newXS("Bio::Emboss::ajSeqGetSvS", XS_Bio__Emboss_ajSeqGetSvS, file);
        newXS("Bio::Emboss::ajSeqGetTaxC", XS_Bio__Emboss_ajSeqGetTaxC, file);
        newXS("Bio::Emboss::ajSeqGetTaxS", XS_Bio__Emboss_ajSeqGetTaxS, file);
        newXS("Bio::Emboss::ajSeqGetUsaC", XS_Bio__Emboss_ajSeqGetUsaC, file);
        newXS("Bio::Emboss::ajSeqGetUsaS", XS_Bio__Emboss_ajSeqGetUsaS, file);
        newXS("Bio::Emboss::ajSeqIsNuc", XS_Bio__Emboss_ajSeqIsNuc, file);
        newXS("Bio::Emboss::ajSeqIsProt", XS_Bio__Emboss_ajSeqIsProt, file);
        newXS("Bio::Emboss::ajSeqIsReversedTrue", XS_Bio__Emboss_ajSeqIsReversedTrue, file);
        newXS("Bio::Emboss::ajSeqIsReversed", XS_Bio__Emboss_ajSeqIsReversed, file);
        newXS("Bio::Emboss::ajSeqIsTrimmed", XS_Bio__Emboss_ajSeqIsTrimmed, file);
        newXS("Bio::Emboss::ajSeqCalcCheckgcg", XS_Bio__Emboss_ajSeqCalcCheckgcg, file);
        newXS("Bio::Emboss::ajSeqCalcCount", XS_Bio__Emboss_ajSeqCalcCount, file);
        newXS("Bio::Emboss::ajSeqCalcCrc", XS_Bio__Emboss_ajSeqCalcCrc, file);
        newXS("Bio::Emboss::ajSeqCalcMolwt", XS_Bio__Emboss_ajSeqCalcMolwt, file);
        newXS("Bio::Emboss::ajSeqCalcTrueposMin", XS_Bio__Emboss_ajSeqCalcTrueposMin, file);
        newXS("Bio::Emboss::ajSeqCalcTruepos", XS_Bio__Emboss_ajSeqCalcTruepos, file);
        newXS("Bio::Emboss::ajSeqExit", XS_Bio__Emboss_ajSeqExit, file);
        newXS("Bio::Emboss::ajSeqallNew", XS_Bio__Emboss_ajSeqallNew, file);
        newXS("Bio::Emboss::ajSeqallDel", XS_Bio__Emboss_ajSeqallDel, file);
        newXS("Bio::Emboss::ajSeqallSetRange", XS_Bio__Emboss_ajSeqallSetRange, file);
        newXS("Bio::Emboss::ajSeqallSetRangeRev", XS_Bio__Emboss_ajSeqallSetRangeRev, file);
        newXS("Bio::Emboss::ajSeqallBegin", XS_Bio__Emboss_ajSeqallBegin, file);
        newXS("Bio::Emboss::ajSeqallEnd", XS_Bio__Emboss_ajSeqallEnd, file);
        newXS("Bio::Emboss::ajSeqallGetFilename", XS_Bio__Emboss_ajSeqallGetFilename, file);
        newXS("Bio::Emboss::ajSeqallLen", XS_Bio__Emboss_ajSeqallLen, file);
        newXS("Bio::Emboss::ajSeqallGetName", XS_Bio__Emboss_ajSeqallGetName, file);
        newXS("Bio::Emboss::ajSeqallGetNameSeq", XS_Bio__Emboss_ajSeqallGetNameSeq, file);
        newXS("Bio::Emboss::ajSeqallGetRange", XS_Bio__Emboss_ajSeqallGetRange, file);
        newXS("Bio::Emboss::ajSeqallGetUsa", XS_Bio__Emboss_ajSeqallGetUsa, file);
        newXS("Bio::Emboss::ajSeqsetNew", XS_Bio__Emboss_ajSeqsetNew, file);
        newXS("Bio::Emboss::ajSeqsetDel", XS_Bio__Emboss_ajSeqsetDel, file);
        newXS("Bio::Emboss::ajSeqsetDelarray", XS_Bio__Emboss_ajSeqsetDelarray, file);
        newXS("Bio::Emboss::ajSeqsetGetFilename", XS_Bio__Emboss_ajSeqsetGetFilename, file);
        newXS("Bio::Emboss::ajSeqsetGetFormat", XS_Bio__Emboss_ajSeqsetGetFormat, file);
        newXS("Bio::Emboss::ajSeqsetGetRange", XS_Bio__Emboss_ajSeqsetGetRange, file);
        newXS("Bio::Emboss::ajSeqsetGetUsa", XS_Bio__Emboss_ajSeqsetGetUsa, file);
        newXS("Bio::Emboss::ajSeqsetFill", XS_Bio__Emboss_ajSeqsetFill, file);
        newXS("Bio::Emboss::ajSeqsetReverse", XS_Bio__Emboss_ajSeqsetReverse, file);
        newXS("Bio::Emboss::ajSeqsetSetRange", XS_Bio__Emboss_ajSeqsetSetRange, file);
        newXS("Bio::Emboss::ajSeqsetToLower", XS_Bio__Emboss_ajSeqsetToLower, file);
        newXS("Bio::Emboss::ajSeqsetToUpper", XS_Bio__Emboss_ajSeqsetToUpper, file);
        newXS("Bio::Emboss::ajSeqsetTrim", XS_Bio__Emboss_ajSeqsetTrim, file);
        newXS("Bio::Emboss::ajSeqsetAcc", XS_Bio__Emboss_ajSeqsetAcc, file);
        newXS("Bio::Emboss::ajSeqsetBegin", XS_Bio__Emboss_ajSeqsetBegin, file);
        newXS("Bio::Emboss::ajSeqsetEnd", XS_Bio__Emboss_ajSeqsetEnd, file);
        newXS("Bio::Emboss::ajSeqsetLen", XS_Bio__Emboss_ajSeqsetLen, file);
        newXS("Bio::Emboss::ajSeqsetGetName", XS_Bio__Emboss_ajSeqsetGetName, file);
        newXS("Bio::Emboss::ajSeqsetName", XS_Bio__Emboss_ajSeqsetName, file);
        newXS("Bio::Emboss::ajSeqsetSeq", XS_Bio__Emboss_ajSeqsetSeq, file);
        newXS("Bio::Emboss::ajSeqsetGetSeq", XS_Bio__Emboss_ajSeqsetGetSeq, file);
        newXS("Bio::Emboss::ajSeqsetGetSeqArray", XS_Bio__Emboss_ajSeqsetGetSeqArray, file);
        newXS("Bio::Emboss::ajSeqsetSize", XS_Bio__Emboss_ajSeqsetSize, file);
        newXS("Bio::Emboss::ajSeqsetTotweight", XS_Bio__Emboss_ajSeqsetTotweight, file);
        newXS("Bio::Emboss::ajSeqsetWeight", XS_Bio__Emboss_ajSeqsetWeight, file);
        newXS("Bio::Emboss::ajSeqsetIsDna", XS_Bio__Emboss_ajSeqsetIsDna, file);
        newXS("Bio::Emboss::ajSeqsetIsNuc", XS_Bio__Emboss_ajSeqsetIsNuc, file);
        newXS("Bio::Emboss::ajSeqsetIsProt", XS_Bio__Emboss_ajSeqsetIsProt, file);
        newXS("Bio::Emboss::ajSeqsetIsRna", XS_Bio__Emboss_ajSeqsetIsRna, file);
        newXS("Bio::Emboss::ajSeqDel", XS_Bio__Emboss_ajSeqDel, file);
        newXS("Bio::Emboss::ajSeqClear", XS_Bio__Emboss_ajSeqClear, file);
        newXS("Bio::Emboss::ajSeqallClear", XS_Bio__Emboss_ajSeqallClear, file);
        newXS("Bio::Emboss::ajSeqMod", XS_Bio__Emboss_ajSeqMod, file);
        newXS("Bio::Emboss::ajSeqTrace", XS_Bio__Emboss_ajSeqTrace, file);
        newXS("Bio::Emboss::ajSeqTraceT", XS_Bio__Emboss_ajSeqTraceT, file);
        newXS("Bio::Emboss::ajSeqNum", XS_Bio__Emboss_ajSeqNum, file);
        newXS("Bio::Emboss::ajSeqNumS", XS_Bio__Emboss_ajSeqNumS, file);
        newXS("Bio::Emboss::ajSeqIsGarbage", XS_Bio__Emboss_ajSeqIsGarbage, file);
        newXS("Bio::Emboss::ajSeqCvtTrace", XS_Bio__Emboss_ajSeqCvtTrace, file);
        newXS("Bio::Emboss::ajSeqCvtNewZero", XS_Bio__Emboss_ajSeqCvtNewZero, file);
        newXS("Bio::Emboss::ajSeqCvtNewZeroS", XS_Bio__Emboss_ajSeqCvtNewZeroS, file);
        newXS("Bio::Emboss::ajSeqCvtNewZeroSS", XS_Bio__Emboss_ajSeqCvtNewZeroSS, file);
        newXS("Bio::Emboss::ajSeqCvtNew", XS_Bio__Emboss_ajSeqCvtNew, file);
        newXS("Bio::Emboss::ajSeqCvtDel", XS_Bio__Emboss_ajSeqCvtDel, file);
        newXS("Bio::Emboss::ajSeqCvtNewText", XS_Bio__Emboss_ajSeqCvtNewText, file);
        newXS("Bio::Emboss::ajSeqCvtLen", XS_Bio__Emboss_ajSeqCvtLen, file);
        newXS("Bio::Emboss::ajSeqCvtK", XS_Bio__Emboss_ajSeqCvtK, file);
        newXS("Bio::Emboss::ajSeqCvtKS", XS_Bio__Emboss_ajSeqCvtKS, file);
        newXS("Bio::Emboss::ajSeqCvtKSRow", XS_Bio__Emboss_ajSeqCvtKSRow, file);
        newXS("Bio::Emboss::ajSeqCvtKSColumn", XS_Bio__Emboss_ajSeqCvtKSColumn, file);
        newXS("Bio::Emboss::ajSeqoutNew", XS_Bio__Emboss_ajSeqoutNew, file);
        newXS("Bio::Emboss::ajSeqoutNewF", XS_Bio__Emboss_ajSeqoutNewF, file);
        newXS("Bio::Emboss::ajSeqoutDel", XS_Bio__Emboss_ajSeqoutDel, file);
        newXS("Bio::Emboss::ajSeqTrim", XS_Bio__Emboss_ajSeqTrim, file);
        newXS("Bio::Emboss::ajSeqGapCount", XS_Bio__Emboss_ajSeqGapCount, file);
        newXS("Bio::Emboss::ajSeqGapCountS", XS_Bio__Emboss_ajSeqGapCountS, file);
        newXS("Bio::Emboss::ajSeqGapStandard", XS_Bio__Emboss_ajSeqGapStandard, file);
        newXS("Bio::Emboss::ajSeqGapStandardS", XS_Bio__Emboss_ajSeqGapStandardS, file);
        newXS("Bio::Emboss::ajSeqFill", XS_Bio__Emboss_ajSeqFill, file);
        newXS("Bio::Emboss::ajSeqDefName", XS_Bio__Emboss_ajSeqDefName, file);
        newXS("Bio::Emboss::ajSeqBaseComp", XS_Bio__Emboss_ajSeqBaseComp, file);
        newXS("Bio::Emboss::ajIsAccession", XS_Bio__Emboss_ajIsAccession, file);
        newXS("Bio::Emboss::ajIsSeqversion", XS_Bio__Emboss_ajIsSeqversion, file);
        newXS("Bio::Emboss::ajSeqstrReverse", XS_Bio__Emboss_ajSeqstrReverse, file);
        newXS("Bio::Emboss::ajSeqstrComplementOnly", XS_Bio__Emboss_ajSeqstrComplementOnly, file);
        newXS("Bio::Emboss::ajSeqstrCalcMolwt", XS_Bio__Emboss_ajSeqstrCalcMolwt, file);
        newXS("Bio::Emboss::ajSeqstrCalcCrc", XS_Bio__Emboss_ajSeqstrCalcCrc, file);
        newXS("Bio::Emboss::ajSeqGarbageOn", XS_Bio__Emboss_ajSeqGarbageOn, file);
        newXS("Bio::Emboss::ajSeqGarbageOff", XS_Bio__Emboss_ajSeqGarbageOff, file);
        newXS("Bio::Emboss::ajSeqABITest", XS_Bio__Emboss_ajSeqABITest, file);
        newXS("Bio::Emboss::ajSeqABIReadSeq", XS_Bio__Emboss_ajSeqABIReadSeq, file);
        newXS("Bio::Emboss::ajSeqABIMachineName", XS_Bio__Emboss_ajSeqABIMachineName, file);
        newXS("Bio::Emboss::ajSeqABIGetNData", XS_Bio__Emboss_ajSeqABIGetNData, file);
        newXS("Bio::Emboss::ajSeqABIGetNBase", XS_Bio__Emboss_ajSeqABIGetNBase, file);
        newXS("Bio::Emboss::ajSeqABIGetData", XS_Bio__Emboss_ajSeqABIGetData, file);
        newXS("Bio::Emboss::ajSeqABIGetBasePosition", XS_Bio__Emboss_ajSeqABIGetBasePosition, file);
        newXS("Bio::Emboss::ajSeqABIGetSignal", XS_Bio__Emboss_ajSeqABIGetSignal, file);
        newXS("Bio::Emboss::ajSeqABIGetBaseSpace", XS_Bio__Emboss_ajSeqABIGetBaseSpace, file);
        newXS("Bio::Emboss::ajSeqABIGetBaseOffset", XS_Bio__Emboss_ajSeqABIGetBaseOffset, file);
        newXS("Bio::Emboss::ajSeqABIGetBasePosOffset", XS_Bio__Emboss_ajSeqABIGetBasePosOffset, file);
        newXS("Bio::Emboss::ajSeqABIGetFWO", XS_Bio__Emboss_ajSeqABIGetFWO, file);
        newXS("Bio::Emboss::ajSeqABIGetPrimerOffset", XS_Bio__Emboss_ajSeqABIGetPrimerOffset, file);
        newXS("Bio::Emboss::ajSeqABIGetPrimerPosition", XS_Bio__Emboss_ajSeqABIGetPrimerPosition, file);
        newXS("Bio::Emboss::ajSeqABIGetTraceOffset", XS_Bio__Emboss_ajSeqABIGetTraceOffset, file);
        newXS("Bio::Emboss::ajSeqABISampleName", XS_Bio__Emboss_ajSeqABISampleName, file);
        newXS("Bio::Emboss::ajSeqMethodTest", XS_Bio__Emboss_ajSeqMethodTest, file);
        newXS("Bio::Emboss::ajSeqMethod", XS_Bio__Emboss_ajSeqMethod, file);
        newXS("Bio::Emboss::ajSeqAccessAsis", XS_Bio__Emboss_ajSeqAccessAsis, file);
        newXS("Bio::Emboss::ajSeqAccessFile", XS_Bio__Emboss_ajSeqAccessFile, file);
        newXS("Bio::Emboss::ajSeqAccessOffset", XS_Bio__Emboss_ajSeqAccessOffset, file);
        newXS("Bio::Emboss::ajSeqPrintAccess", XS_Bio__Emboss_ajSeqPrintAccess, file);
        newXS("Bio::Emboss::ajSeqDbExit", XS_Bio__Emboss_ajSeqDbExit, file);
        newXS("Bio::Emboss::ajSeqinNew", XS_Bio__Emboss_ajSeqinNew, file);
        newXS("Bio::Emboss::ajSeqinDel", XS_Bio__Emboss_ajSeqinDel, file);
        newXS("Bio::Emboss::ajSeqinUsa", XS_Bio__Emboss_ajSeqinUsa, file);
        newXS("Bio::Emboss::ajSeqinSetNuc", XS_Bio__Emboss_ajSeqinSetNuc, file);
        newXS("Bio::Emboss::ajSeqinSetProt", XS_Bio__Emboss_ajSeqinSetProt, file);
        newXS("Bio::Emboss::ajSeqinSetRange", XS_Bio__Emboss_ajSeqinSetRange, file);
        newXS("Bio::Emboss::ajSeqAllRead", XS_Bio__Emboss_ajSeqAllRead, file);
        newXS("Bio::Emboss::ajSeqallFile", XS_Bio__Emboss_ajSeqallFile, file);
        newXS("Bio::Emboss::ajSeqallNext", XS_Bio__Emboss_ajSeqallNext, file);
        newXS("Bio::Emboss::ajSeqinClearPos", XS_Bio__Emboss_ajSeqinClearPos, file);
        newXS("Bio::Emboss::ajSeqinClear", XS_Bio__Emboss_ajSeqinClear, file);
        newXS("Bio::Emboss::ajSeqRead", XS_Bio__Emboss_ajSeqRead, file);
        newXS("Bio::Emboss::ajSeqsetRead", XS_Bio__Emboss_ajSeqsetRead, file);
        newXS("Bio::Emboss::ajSeqsetallRead", XS_Bio__Emboss_ajSeqsetallRead, file);
        newXS("Bio::Emboss::ajSeqsetFromList", XS_Bio__Emboss_ajSeqsetFromList, file);
        newXS("Bio::Emboss::ajSeqsetFromPair", XS_Bio__Emboss_ajSeqsetFromPair, file);
        newXS("Bio::Emboss::ajSeqsetApp", XS_Bio__Emboss_ajSeqsetApp, file);
        newXS("Bio::Emboss::ajSeqPrintInFormat", XS_Bio__Emboss_ajSeqPrintInFormat, file);
        newXS("Bio::Emboss::ajSeqFormatTest", XS_Bio__Emboss_ajSeqFormatTest, file);
        newXS("Bio::Emboss::ajSeqQueryNew", XS_Bio__Emboss_ajSeqQueryNew, file);
        newXS("Bio::Emboss::ajSeqQueryDel", XS_Bio__Emboss_ajSeqQueryDel, file);
        newXS("Bio::Emboss::ajSeqQueryClear", XS_Bio__Emboss_ajSeqQueryClear, file);
        newXS("Bio::Emboss::ajSeqQueryWild", XS_Bio__Emboss_ajSeqQueryWild, file);
        newXS("Bio::Emboss::ajSeqQueryStarclear", XS_Bio__Emboss_ajSeqQueryStarclear, file);
        newXS("Bio::Emboss::ajSeqQueryIs", XS_Bio__Emboss_ajSeqQueryIs, file);
        newXS("Bio::Emboss::ajSeqQueryTrace", XS_Bio__Emboss_ajSeqQueryTrace, file);
        newXS("Bio::Emboss::ajSeqParseFasta", XS_Bio__Emboss_ajSeqParseFasta, file);
        newXS("Bio::Emboss::ajSeqParseNcbi", XS_Bio__Emboss_ajSeqParseNcbi, file);
        newXS("Bio::Emboss::ajSeqGetFromUsa", XS_Bio__Emboss_ajSeqGetFromUsa, file);
        newXS("Bio::Emboss::ajSeqsetGetFromUsa", XS_Bio__Emboss_ajSeqsetGetFromUsa, file);
        newXS("Bio::Emboss::ajSeqReadExit", XS_Bio__Emboss_ajSeqReadExit, file);
        newXS("Bio::Emboss::ajSeqinTrace", XS_Bio__Emboss_ajSeqinTrace, file);
        newXS("Bio::Emboss::ajSeqTypeCheckS", XS_Bio__Emboss_ajSeqTypeCheckS, file);
        newXS("Bio::Emboss::ajSeqTypeCheckIn", XS_Bio__Emboss_ajSeqTypeCheckIn, file);
        newXS("Bio::Emboss::ajSeqTypeNucS", XS_Bio__Emboss_ajSeqTypeNucS, file);
        newXS("Bio::Emboss::ajSeqTypeDnaS", XS_Bio__Emboss_ajSeqTypeDnaS, file);
        newXS("Bio::Emboss::ajSeqTypeRnaS", XS_Bio__Emboss_ajSeqTypeRnaS, file);
        newXS("Bio::Emboss::ajSeqTypeGapdnaS", XS_Bio__Emboss_ajSeqTypeGapdnaS, file);
        newXS("Bio::Emboss::ajSeqTypeGaprnaS", XS_Bio__Emboss_ajSeqTypeGaprnaS, file);
        newXS("Bio::Emboss::ajSeqTypeGapnucS", XS_Bio__Emboss_ajSeqTypeGapnucS, file);
        newXS("Bio::Emboss::ajSeqTypeAnyprotS", XS_Bio__Emboss_ajSeqTypeAnyprotS, file);
        newXS("Bio::Emboss::ajSeqTypeProtS", XS_Bio__Emboss_ajSeqTypeProtS, file);
        newXS("Bio::Emboss::ajSeqTypeGapanyS", XS_Bio__Emboss_ajSeqTypeGapanyS, file);
        newXS("Bio::Emboss::ajSeqGap", XS_Bio__Emboss_ajSeqGap, file);
        newXS("Bio::Emboss::ajSeqGapLen", XS_Bio__Emboss_ajSeqGapLen, file);
        newXS("Bio::Emboss::ajSeqGapS", XS_Bio__Emboss_ajSeqGapS, file);
        newXS("Bio::Emboss::ajSeqSetNuc", XS_Bio__Emboss_ajSeqSetNuc, file);
        newXS("Bio::Emboss::ajSeqSetProt", XS_Bio__Emboss_ajSeqSetProt, file);
        newXS("Bio::Emboss::ajSeqsetSetNuc", XS_Bio__Emboss_ajSeqsetSetNuc, file);
        newXS("Bio::Emboss::ajSeqsetSetProt", XS_Bio__Emboss_ajSeqsetSetProt, file);
        newXS("Bio::Emboss::ajSeqType", XS_Bio__Emboss_ajSeqType, file);
        newXS("Bio::Emboss::ajSeqPrintType", XS_Bio__Emboss_ajSeqPrintType, file);
        newXS("Bio::Emboss::ajSeqTypeIsProt", XS_Bio__Emboss_ajSeqTypeIsProt, file);
        newXS("Bio::Emboss::ajSeqTypeIsNuc", XS_Bio__Emboss_ajSeqTypeIsNuc, file);
        newXS("Bio::Emboss::ajSeqTypeIsAny", XS_Bio__Emboss_ajSeqTypeIsAny, file);
        newXS("Bio::Emboss::ajSeqTypeSummary", XS_Bio__Emboss_ajSeqTypeSummary, file);
        newXS("Bio::Emboss::ajSeqTypeExit", XS_Bio__Emboss_ajSeqTypeExit, file);
        newXS("Bio::Emboss::ajSeqAllWrite", XS_Bio__Emboss_ajSeqAllWrite, file);
        newXS("Bio::Emboss::ajSeqsetWrite", XS_Bio__Emboss_ajSeqsetWrite, file);
        newXS("Bio::Emboss::ajSeqWriteClose", XS_Bio__Emboss_ajSeqWriteClose, file);
        newXS("Bio::Emboss::ajSeqWrite", XS_Bio__Emboss_ajSeqWrite, file);
        newXS("Bio::Emboss::ajSeqFileNewOut", XS_Bio__Emboss_ajSeqFileNewOut, file);
        newXS("Bio::Emboss::ajSeqoutOpen", XS_Bio__Emboss_ajSeqoutOpen, file);
        newXS("Bio::Emboss::ajSeqOutFormatSingle", XS_Bio__Emboss_ajSeqOutFormatSingle, file);
        newXS("Bio::Emboss::ajSeqOutSetFormat", XS_Bio__Emboss_ajSeqOutSetFormat, file);
        newXS("Bio::Emboss::ajSeqOutSetFormatC", XS_Bio__Emboss_ajSeqOutSetFormatC, file);
        newXS("Bio::Emboss::ajSeqOutFormatDefault", XS_Bio__Emboss_ajSeqOutFormatDefault, file);
        newXS("Bio::Emboss::ajSeqoutUsa", XS_Bio__Emboss_ajSeqoutUsa, file);
        newXS("Bio::Emboss::ajSeqoutClear", XS_Bio__Emboss_ajSeqoutClear, file);
        newXS("Bio::Emboss::ajSeqPrintOutFormat", XS_Bio__Emboss_ajSeqPrintOutFormat, file);
        newXS("Bio::Emboss::ajSeqFindOutFormat", XS_Bio__Emboss_ajSeqFindOutFormat, file);
        newXS("Bio::Emboss::ajSeqoutCheckGcg", XS_Bio__Emboss_ajSeqoutCheckGcg, file);
        newXS("Bio::Emboss::ajSeqoutDefName", XS_Bio__Emboss_ajSeqoutDefName, file);
        newXS("Bio::Emboss::ajSeqoutTrace", XS_Bio__Emboss_ajSeqoutTrace, file);
        newXS("Bio::Emboss::ajSeqoutCount", XS_Bio__Emboss_ajSeqoutCount, file);
        newXS("Bio::Emboss::ajSeqWriteXyz", XS_Bio__Emboss_ajSeqWriteXyz, file);
        newXS("Bio::Emboss::ajSssWriteXyz", XS_Bio__Emboss_ajSssWriteXyz, file);
        newXS("Bio::Emboss::ajSeqWriteExit", XS_Bio__Emboss_ajSeqWriteExit, file);
        newXS("Bio::Emboss::ajSortFloatDecI", XS_Bio__Emboss_ajSortFloatDecI, file);
        newXS("Bio::Emboss::ajSortIntDecI", XS_Bio__Emboss_ajSortIntDecI, file);
        newXS("Bio::Emboss::ajSortFloatIncI", XS_Bio__Emboss_ajSortFloatIncI, file);
        newXS("Bio::Emboss::ajSortIntIncI", XS_Bio__Emboss_ajSortIntIncI, file);
        newXS("Bio::Emboss::ajSortTwoIntIncI", XS_Bio__Emboss_ajSortTwoIntIncI, file);
        newXS("Bio::Emboss::ajSortFloatDec", XS_Bio__Emboss_ajSortFloatDec, file);
        newXS("Bio::Emboss::ajSortIntDec", XS_Bio__Emboss_ajSortIntDec, file);
        newXS("Bio::Emboss::ajSortFloatInc", XS_Bio__Emboss_ajSortFloatInc, file);
        newXS("Bio::Emboss::ajSortIntInc", XS_Bio__Emboss_ajSortIntInc, file);
        newXS("Bio::Emboss::ajCharNewC", XS_Bio__Emboss_ajCharNewC, file);
        newXS("Bio::Emboss::ajCharNewS", XS_Bio__Emboss_ajCharNewS, file);
        newXS("Bio::Emboss::ajCharNewRes", XS_Bio__Emboss_ajCharNewRes, file);
        newXS("Bio::Emboss::ajCharNewResC", XS_Bio__Emboss_ajCharNewResC, file);
        newXS("Bio::Emboss::ajCharNewResS", XS_Bio__Emboss_ajCharNewResS, file);
        newXS("Bio::Emboss::ajCharNewResLenC", XS_Bio__Emboss_ajCharNewResLenC, file);
        newXS("Bio::Emboss::ajCharDel", XS_Bio__Emboss_ajCharDel, file);
        newXS("Bio::Emboss::ajCharFmtLower", XS_Bio__Emboss_ajCharFmtLower, file);
        newXS("Bio::Emboss::ajCharFmtUpper", XS_Bio__Emboss_ajCharFmtUpper, file);
        newXS("Bio::Emboss::ajCharMatchC", XS_Bio__Emboss_ajCharMatchC, file);
        newXS("Bio::Emboss::ajCharMatchCaseC", XS_Bio__Emboss_ajCharMatchCaseC, file);
        newXS("Bio::Emboss::ajCharMatchWildC", XS_Bio__Emboss_ajCharMatchWildC, file);
        newXS("Bio::Emboss::ajCharMatchWildS", XS_Bio__Emboss_ajCharMatchWildS, file);
        newXS("Bio::Emboss::ajCharMatchWildNextC", XS_Bio__Emboss_ajCharMatchWildNextC, file);
        newXS("Bio::Emboss::ajCharMatchWildWordC", XS_Bio__Emboss_ajCharMatchWildWordC, file);
        newXS("Bio::Emboss::ajCharPrefixC", XS_Bio__Emboss_ajCharPrefixC, file);
        newXS("Bio::Emboss::ajCharPrefixS", XS_Bio__Emboss_ajCharPrefixS, file);
        newXS("Bio::Emboss::ajCharPrefixCaseC", XS_Bio__Emboss_ajCharPrefixCaseC, file);
        newXS("Bio::Emboss::ajCharPrefixCaseS", XS_Bio__Emboss_ajCharPrefixCaseS, file);
        newXS("Bio::Emboss::ajCharSuffixC", XS_Bio__Emboss_ajCharSuffixC, file);
        newXS("Bio::Emboss::ajCharSuffixS", XS_Bio__Emboss_ajCharSuffixS, file);
        newXS("Bio::Emboss::ajCharSuffixCaseC", XS_Bio__Emboss_ajCharSuffixCaseC, file);
        newXS("Bio::Emboss::ajCharSuffixCaseS", XS_Bio__Emboss_ajCharSuffixCaseS, file);
        newXS("Bio::Emboss::ajCharCmpCase", XS_Bio__Emboss_ajCharCmpCase, file);
        newXS("Bio::Emboss::ajCharCmpCaseLen", XS_Bio__Emboss_ajCharCmpCaseLen, file);
        newXS("Bio::Emboss::ajCharCmpWild", XS_Bio__Emboss_ajCharCmpWild, file);
        newXS("Bio::Emboss::ajCharParseC", XS_Bio__Emboss_ajCharParseC, file);
        newXS("Bio::Emboss::ajStrNew", XS_Bio__Emboss_ajStrNew, file);
        newXS("Bio::Emboss::ajStrNewC", XS_Bio__Emboss_ajStrNewC, file);
        newXS("Bio::Emboss::ajStrNewS", XS_Bio__Emboss_ajStrNewS, file);
        newXS("Bio::Emboss::ajStrNewRef", XS_Bio__Emboss_ajStrNewRef, file);
        newXS("Bio::Emboss::ajStrNewRes", XS_Bio__Emboss_ajStrNewRes, file);
        newXS("Bio::Emboss::ajStrNewResC", XS_Bio__Emboss_ajStrNewResC, file);
        newXS("Bio::Emboss::ajStrNewResS", XS_Bio__Emboss_ajStrNewResS, file);
        newXS("Bio::Emboss::ajStrNewResLenC", XS_Bio__Emboss_ajStrNewResLenC, file);
        newXS("Bio::Emboss::ajStrDel", XS_Bio__Emboss_ajStrDel, file);
        newXS("Bio::Emboss::ajStrDelStatic", XS_Bio__Emboss_ajStrDelStatic, file);
        newXS("Bio::Emboss::ajStrDelarray", XS_Bio__Emboss_ajStrDelarray, file);
        newXS("Bio::Emboss::ajStrAssignC", XS_Bio__Emboss_ajStrAssignC, file);
        newXS("Bio::Emboss::ajStrAssignK", XS_Bio__Emboss_ajStrAssignK, file);
        newXS("Bio::Emboss::ajStrAssignS", XS_Bio__Emboss_ajStrAssignS, file);
        newXS("Bio::Emboss::ajStrAssignEmptyC", XS_Bio__Emboss_ajStrAssignEmptyC, file);
        newXS("Bio::Emboss::ajStrAssignEmptyS", XS_Bio__Emboss_ajStrAssignEmptyS, file);
        newXS("Bio::Emboss::ajStrAssignLenC", XS_Bio__Emboss_ajStrAssignLenC, file);
        newXS("Bio::Emboss::ajStrAssignRef", XS_Bio__Emboss_ajStrAssignRef, file);
        newXS("Bio::Emboss::ajStrAssignResC", XS_Bio__Emboss_ajStrAssignResC, file);
        newXS("Bio::Emboss::ajStrAssignResS", XS_Bio__Emboss_ajStrAssignResS, file);
        newXS("Bio::Emboss::ajStrAssignSubC", XS_Bio__Emboss_ajStrAssignSubC, file);
        newXS("Bio::Emboss::ajStrAssignSubS", XS_Bio__Emboss_ajStrAssignSubS, file);
        newXS("Bio::Emboss::ajStrAppendC", XS_Bio__Emboss_ajStrAppendC, file);
        newXS("Bio::Emboss::ajStrAppendK", XS_Bio__Emboss_ajStrAppendK, file);
        newXS("Bio::Emboss::ajStrAppendS", XS_Bio__Emboss_ajStrAppendS, file);
        newXS("Bio::Emboss::ajStrAppendCountK", XS_Bio__Emboss_ajStrAppendCountK, file);
        newXS("Bio::Emboss::ajStrAppendLenC", XS_Bio__Emboss_ajStrAppendLenC, file);
        newXS("Bio::Emboss::ajStrAppendSubS", XS_Bio__Emboss_ajStrAppendSubS, file);
        newXS("Bio::Emboss::ajStrInsertC", XS_Bio__Emboss_ajStrInsertC, file);
        newXS("Bio::Emboss::ajStrInsertK", XS_Bio__Emboss_ajStrInsertK, file);
        newXS("Bio::Emboss::ajStrInsertS", XS_Bio__Emboss_ajStrInsertS, file);
        newXS("Bio::Emboss::ajStrJoinC", XS_Bio__Emboss_ajStrJoinC, file);
        newXS("Bio::Emboss::ajStrJoinS", XS_Bio__Emboss_ajStrJoinS, file);
        newXS("Bio::Emboss::ajStrMask", XS_Bio__Emboss_ajStrMask, file);
        newXS("Bio::Emboss::ajStrPasteS", XS_Bio__Emboss_ajStrPasteS, file);
        newXS("Bio::Emboss::ajStrPasteCountK", XS_Bio__Emboss_ajStrPasteCountK, file);
        newXS("Bio::Emboss::ajStrPasteMaxC", XS_Bio__Emboss_ajStrPasteMaxC, file);
        newXS("Bio::Emboss::ajStrPasteMaxS", XS_Bio__Emboss_ajStrPasteMaxS, file);
        newXS("Bio::Emboss::ajStrCutComments", XS_Bio__Emboss_ajStrCutComments, file);
        newXS("Bio::Emboss::ajStrCutCommentsStart", XS_Bio__Emboss_ajStrCutCommentsStart, file);
        newXS("Bio::Emboss::ajStrCutEnd", XS_Bio__Emboss_ajStrCutEnd, file);
        newXS("Bio::Emboss::ajStrCutRange", XS_Bio__Emboss_ajStrCutRange, file);
        newXS("Bio::Emboss::ajStrCutStart", XS_Bio__Emboss_ajStrCutStart, file);
        newXS("Bio::Emboss::ajStrKeepRange", XS_Bio__Emboss_ajStrKeepRange, file);
        newXS("Bio::Emboss::ajStrKeepSetC", XS_Bio__Emboss_ajStrKeepSetC, file);
        newXS("Bio::Emboss::ajStrKeepSetAlphaC", XS_Bio__Emboss_ajStrKeepSetAlphaC, file);
        newXS("Bio::Emboss::ajStrQuoteStrip", XS_Bio__Emboss_ajStrQuoteStrip, file);
        newXS("Bio::Emboss::ajStrQuoteStripAll", XS_Bio__Emboss_ajStrQuoteStripAll, file);
        newXS("Bio::Emboss::ajStrRemoveGap", XS_Bio__Emboss_ajStrRemoveGap, file);
        newXS("Bio::Emboss::ajStrRemoveHtml", XS_Bio__Emboss_ajStrRemoveHtml, file);
        newXS("Bio::Emboss::ajStrRemoveLastNewline", XS_Bio__Emboss_ajStrRemoveLastNewline, file);
        newXS("Bio::Emboss::ajStrRemoveSetC", XS_Bio__Emboss_ajStrRemoveSetC, file);
        newXS("Bio::Emboss::ajStrRemoveWhite", XS_Bio__Emboss_ajStrRemoveWhite, file);
        newXS("Bio::Emboss::ajStrRemoveWhiteExcess", XS_Bio__Emboss_ajStrRemoveWhiteExcess, file);
        newXS("Bio::Emboss::ajStrRemoveWild", XS_Bio__Emboss_ajStrRemoveWild, file);
        newXS("Bio::Emboss::ajStrTrimC", XS_Bio__Emboss_ajStrTrimC, file);
        newXS("Bio::Emboss::ajStrTrimEndC", XS_Bio__Emboss_ajStrTrimEndC, file);
        newXS("Bio::Emboss::ajStrTrimStartC", XS_Bio__Emboss_ajStrTrimStartC, file);
        newXS("Bio::Emboss::ajStrTrimWhite", XS_Bio__Emboss_ajStrTrimWhite, file);
        newXS("Bio::Emboss::ajStrTrimWhiteEnd", XS_Bio__Emboss_ajStrTrimWhiteEnd, file);
        newXS("Bio::Emboss::ajStrTruncateLen", XS_Bio__Emboss_ajStrTruncateLen, file);
        newXS("Bio::Emboss::ajStrTruncatePos", XS_Bio__Emboss_ajStrTruncatePos, file);
        newXS("Bio::Emboss::ajStrExchangeCC", XS_Bio__Emboss_ajStrExchangeCC, file);
        newXS("Bio::Emboss::ajStrExchangeCS", XS_Bio__Emboss_ajStrExchangeCS, file);
        newXS("Bio::Emboss::ajStrExchangeKK", XS_Bio__Emboss_ajStrExchangeKK, file);
        newXS("Bio::Emboss::ajStrExchangeSC", XS_Bio__Emboss_ajStrExchangeSC, file);
        newXS("Bio::Emboss::ajStrExchangeSS", XS_Bio__Emboss_ajStrExchangeSS, file);
        newXS("Bio::Emboss::ajStrExchangeSetCC", XS_Bio__Emboss_ajStrExchangeSetCC, file);
        newXS("Bio::Emboss::ajStrExchangeSetSS", XS_Bio__Emboss_ajStrExchangeSetSS, file);
        newXS("Bio::Emboss::ajStrRandom", XS_Bio__Emboss_ajStrRandom, file);
        newXS("Bio::Emboss::ajStrReverse", XS_Bio__Emboss_ajStrReverse, file);
        newXS("Bio::Emboss::ajStrCalcCountC", XS_Bio__Emboss_ajStrCalcCountC, file);
        newXS("Bio::Emboss::ajStrCalcCountK", XS_Bio__Emboss_ajStrCalcCountK, file);
        newXS("Bio::Emboss::ajStrHasParentheses", XS_Bio__Emboss_ajStrHasParentheses, file);
        newXS("Bio::Emboss::ajStrIsAlnum", XS_Bio__Emboss_ajStrIsAlnum, file);
        newXS("Bio::Emboss::ajStrIsAlpha", XS_Bio__Emboss_ajStrIsAlpha, file);
        newXS("Bio::Emboss::ajStrIsBool", XS_Bio__Emboss_ajStrIsBool, file);
        newXS("Bio::Emboss::ajStrIsDouble", XS_Bio__Emboss_ajStrIsDouble, file);
        newXS("Bio::Emboss::ajStrIsFloat", XS_Bio__Emboss_ajStrIsFloat, file);
        newXS("Bio::Emboss::ajStrIsHex", XS_Bio__Emboss_ajStrIsHex, file);
        newXS("Bio::Emboss::ajStrIsInt", XS_Bio__Emboss_ajStrIsInt, file);
        newXS("Bio::Emboss::ajStrIsLong", XS_Bio__Emboss_ajStrIsLong, file);
        newXS("Bio::Emboss::ajStrIsLower", XS_Bio__Emboss_ajStrIsLower, file);
        newXS("Bio::Emboss::ajStrIsNum", XS_Bio__Emboss_ajStrIsNum, file);
        newXS("Bio::Emboss::ajStrIsUpper", XS_Bio__Emboss_ajStrIsUpper, file);
        newXS("Bio::Emboss::ajStrIsWhite", XS_Bio__Emboss_ajStrIsWhite, file);
        newXS("Bio::Emboss::ajStrIsWild", XS_Bio__Emboss_ajStrIsWild, file);
        newXS("Bio::Emboss::ajStrIsWord", XS_Bio__Emboss_ajStrIsWord, file);
        newXS("Bio::Emboss::ajStrWhole", XS_Bio__Emboss_ajStrWhole, file);
        newXS("Bio::Emboss::ajStrGetCharFirst", XS_Bio__Emboss_ajStrGetCharFirst, file);
        newXS("Bio::Emboss::ajStrGetCharLast", XS_Bio__Emboss_ajStrGetCharLast, file);
        newXS("Bio::Emboss::ajStrGetCharPos", XS_Bio__Emboss_ajStrGetCharPos, file);
        newXS("Bio::Emboss::ajStrGetLen", XS_Bio__Emboss_ajStrGetLen, file);
        newXS("Bio::Emboss::ajStrGetPtr", XS_Bio__Emboss_ajStrGetPtr, file);
        newXS("Bio::Emboss::ajStrGetRes", XS_Bio__Emboss_ajStrGetRes, file);
        newXS("Bio::Emboss::ajStrGetRoom", XS_Bio__Emboss_ajStrGetRoom, file);
        newXS("Bio::Emboss::ajStrGetUse", XS_Bio__Emboss_ajStrGetUse, file);
        newXS("Bio::Emboss::ajStrGetValid", XS_Bio__Emboss_ajStrGetValid, file);
        newXS("Bio::Emboss::ajStrGetuniquePtr", XS_Bio__Emboss_ajStrGetuniquePtr, file);
        newXS("Bio::Emboss::ajStrGetuniqueStr", XS_Bio__Emboss_ajStrGetuniqueStr, file);
        newXS("Bio::Emboss::ajStrSetClear", XS_Bio__Emboss_ajStrSetClear, file);
        newXS("Bio::Emboss::ajStrSetRes", XS_Bio__Emboss_ajStrSetRes, file);
        newXS("Bio::Emboss::ajStrSetResRound", XS_Bio__Emboss_ajStrSetResRound, file);
        newXS("Bio::Emboss::ajStrSetValid", XS_Bio__Emboss_ajStrSetValid, file);
        newXS("Bio::Emboss::ajStrSetValidLen", XS_Bio__Emboss_ajStrSetValidLen, file);
        newXS("Bio::Emboss::ajStrToBool", XS_Bio__Emboss_ajStrToBool, file);
        newXS("Bio::Emboss::ajStrToDouble", XS_Bio__Emboss_ajStrToDouble, file);
        newXS("Bio::Emboss::ajStrToFloat", XS_Bio__Emboss_ajStrToFloat, file);
        newXS("Bio::Emboss::ajStrToHex", XS_Bio__Emboss_ajStrToHex, file);
        newXS("Bio::Emboss::ajStrToInt", XS_Bio__Emboss_ajStrToInt, file);
        newXS("Bio::Emboss::ajStrToLong", XS_Bio__Emboss_ajStrToLong, file);
        newXS("Bio::Emboss::ajStrFromBool", XS_Bio__Emboss_ajStrFromBool, file);
        newXS("Bio::Emboss::ajStrFromDouble", XS_Bio__Emboss_ajStrFromDouble, file);
        newXS("Bio::Emboss::ajStrFromDoubleExp", XS_Bio__Emboss_ajStrFromDoubleExp, file);
        newXS("Bio::Emboss::ajStrFromFloat", XS_Bio__Emboss_ajStrFromFloat, file);
        newXS("Bio::Emboss::ajStrFromInt", XS_Bio__Emboss_ajStrFromInt, file);
        newXS("Bio::Emboss::ajStrFromLong", XS_Bio__Emboss_ajStrFromLong, file);
        newXS("Bio::Emboss::ajStrFmtBlock", XS_Bio__Emboss_ajStrFmtBlock, file);
        newXS("Bio::Emboss::ajStrFmtLower", XS_Bio__Emboss_ajStrFmtLower, file);
        newXS("Bio::Emboss::ajStrFmtLowerSub", XS_Bio__Emboss_ajStrFmtLowerSub, file);
        newXS("Bio::Emboss::ajStrFmtQuote", XS_Bio__Emboss_ajStrFmtQuote, file);
        newXS("Bio::Emboss::ajStrFmtTitle", XS_Bio__Emboss_ajStrFmtTitle, file);
        newXS("Bio::Emboss::ajStrFmtUpper", XS_Bio__Emboss_ajStrFmtUpper, file);
        newXS("Bio::Emboss::ajStrFmtUpperSub", XS_Bio__Emboss_ajStrFmtUpperSub, file);
        newXS("Bio::Emboss::ajStrFmtWrap", XS_Bio__Emboss_ajStrFmtWrap, file);
        newXS("Bio::Emboss::ajStrFmtWrapLeft", XS_Bio__Emboss_ajStrFmtWrapLeft, file);
        newXS("Bio::Emboss::ajStrMatchC", XS_Bio__Emboss_ajStrMatchC, file);
        newXS("Bio::Emboss::ajStrMatchS", XS_Bio__Emboss_ajStrMatchS, file);
        newXS("Bio::Emboss::ajStrMatchCaseC", XS_Bio__Emboss_ajStrMatchCaseC, file);
        newXS("Bio::Emboss::ajStrMatchCaseS", XS_Bio__Emboss_ajStrMatchCaseS, file);
        newXS("Bio::Emboss::ajStrMatchWildC", XS_Bio__Emboss_ajStrMatchWildC, file);
        newXS("Bio::Emboss::ajStrMatchWildS", XS_Bio__Emboss_ajStrMatchWildS, file);
        newXS("Bio::Emboss::ajStrMatchWildWordC", XS_Bio__Emboss_ajStrMatchWildWordC, file);
        newXS("Bio::Emboss::ajStrMatchWildWordS", XS_Bio__Emboss_ajStrMatchWildWordS, file);
        newXS("Bio::Emboss::ajStrMatchWordAllS", XS_Bio__Emboss_ajStrMatchWordAllS, file);
        newXS("Bio::Emboss::ajStrMatchWordOneS", XS_Bio__Emboss_ajStrMatchWordOneS, file);
        newXS("Bio::Emboss::ajStrPrefixC", XS_Bio__Emboss_ajStrPrefixC, file);
        newXS("Bio::Emboss::ajStrPrefixS", XS_Bio__Emboss_ajStrPrefixS, file);
        newXS("Bio::Emboss::ajStrPrefixCaseC", XS_Bio__Emboss_ajStrPrefixCaseC, file);
        newXS("Bio::Emboss::ajStrPrefixCaseS", XS_Bio__Emboss_ajStrPrefixCaseS, file);
        newXS("Bio::Emboss::ajStrSuffixC", XS_Bio__Emboss_ajStrSuffixC, file);
        newXS("Bio::Emboss::ajStrSuffixS", XS_Bio__Emboss_ajStrSuffixS, file);
        newXS("Bio::Emboss::ajStrCmpC", XS_Bio__Emboss_ajStrCmpC, file);
        newXS("Bio::Emboss::ajStrCmpLenC", XS_Bio__Emboss_ajStrCmpLenC, file);
        newXS("Bio::Emboss::ajStrCmpS", XS_Bio__Emboss_ajStrCmpS, file);
        newXS("Bio::Emboss::ajStrCmpCaseS", XS_Bio__Emboss_ajStrCmpCaseS, file);
        newXS("Bio::Emboss::ajStrCmpLenS", XS_Bio__Emboss_ajStrCmpLenS, file);
        newXS("Bio::Emboss::ajStrCmpWildC", XS_Bio__Emboss_ajStrCmpWildC, file);
        newXS("Bio::Emboss::ajStrCmpWildS", XS_Bio__Emboss_ajStrCmpWildS, file);
        newXS("Bio::Emboss::ajStrVcmp", XS_Bio__Emboss_ajStrVcmp, file);
        newXS("Bio::Emboss::ajStrFindC", XS_Bio__Emboss_ajStrFindC, file);
        newXS("Bio::Emboss::ajStrFindS", XS_Bio__Emboss_ajStrFindS, file);
        newXS("Bio::Emboss::ajStrFindAnyC", XS_Bio__Emboss_ajStrFindAnyC, file);
        newXS("Bio::Emboss::ajStrFindAnyK", XS_Bio__Emboss_ajStrFindAnyK, file);
        newXS("Bio::Emboss::ajStrFindAnyS", XS_Bio__Emboss_ajStrFindAnyS, file);
        newXS("Bio::Emboss::ajStrFindCaseC", XS_Bio__Emboss_ajStrFindCaseC, file);
        newXS("Bio::Emboss::ajStrFindCaseS", XS_Bio__Emboss_ajStrFindCaseS, file);
        newXS("Bio::Emboss::ajStrFindlastC", XS_Bio__Emboss_ajStrFindlastC, file);
        newXS("Bio::Emboss::ajStrFindlastS", XS_Bio__Emboss_ajStrFindlastS, file);
        newXS("Bio::Emboss::ajStrExtractFirst", XS_Bio__Emboss_ajStrExtractFirst, file);
        newXS("Bio::Emboss::ajStrExtractWord", XS_Bio__Emboss_ajStrExtractWord, file);
        newXS("Bio::Emboss::ajStrParseC", XS_Bio__Emboss_ajStrParseC, file);
        newXS("Bio::Emboss::ajStrParseCount", XS_Bio__Emboss_ajStrParseCount, file);
        newXS("Bio::Emboss::ajStrParseCountC", XS_Bio__Emboss_ajStrParseCountC, file);
        newXS("Bio::Emboss::ajStrParseCountS", XS_Bio__Emboss_ajStrParseCountS, file);
        newXS("Bio::Emboss::ajStrParseCountMultiC", XS_Bio__Emboss_ajStrParseCountMultiC, file);
        newXS("Bio::Emboss::ajStrParseSplit", XS_Bio__Emboss_ajStrParseSplit, file);
        newXS("Bio::Emboss::ajStrParseWhite", XS_Bio__Emboss_ajStrParseWhite, file);
        newXS("Bio::Emboss::ajStrStat", XS_Bio__Emboss_ajStrStat, file);
        newXS("Bio::Emboss::ajStrTrace", XS_Bio__Emboss_ajStrTrace, file);
        newXS("Bio::Emboss::ajStrTraceFull", XS_Bio__Emboss_ajStrTraceFull, file);
        newXS("Bio::Emboss::ajStrTraceTitle", XS_Bio__Emboss_ajStrTraceTitle, file);
        newXS("Bio::Emboss::ajStrExit", XS_Bio__Emboss_ajStrExit, file);
        newXS("Bio::Emboss::ajStrIterNew", XS_Bio__Emboss_ajStrIterNew, file);
        newXS("Bio::Emboss::ajStrIterNewBack", XS_Bio__Emboss_ajStrIterNewBack, file);
        newXS("Bio::Emboss::ajStrIterDel", XS_Bio__Emboss_ajStrIterDel, file);
        newXS("Bio::Emboss::ajStrIterDone", XS_Bio__Emboss_ajStrIterDone, file);
        newXS("Bio::Emboss::ajStrIterDoneBack", XS_Bio__Emboss_ajStrIterDoneBack, file);
        newXS("Bio::Emboss::ajStrIterBegin", XS_Bio__Emboss_ajStrIterBegin, file);
        newXS("Bio::Emboss::ajStrIterEnd", XS_Bio__Emboss_ajStrIterEnd, file);
        newXS("Bio::Emboss::ajStrIterGetC", XS_Bio__Emboss_ajStrIterGetC, file);
        newXS("Bio::Emboss::ajStrIterGetK", XS_Bio__Emboss_ajStrIterGetK, file);
        newXS("Bio::Emboss::ajStrIterPutK", XS_Bio__Emboss_ajStrIterPutK, file);
        newXS("Bio::Emboss::ajStrIterNext", XS_Bio__Emboss_ajStrIterNext, file);
        newXS("Bio::Emboss::ajStrIterNextBack", XS_Bio__Emboss_ajStrIterNextBack, file);
        newXS("Bio::Emboss::ajStrTokenNewC", XS_Bio__Emboss_ajStrTokenNewC, file);
        newXS("Bio::Emboss::ajStrTokenNewS", XS_Bio__Emboss_ajStrTokenNewS, file);
        newXS("Bio::Emboss::ajStrTokenDel", XS_Bio__Emboss_ajStrTokenDel, file);
        newXS("Bio::Emboss::ajStrTokenAssign", XS_Bio__Emboss_ajStrTokenAssign, file);
        newXS("Bio::Emboss::ajStrTokenAssignC", XS_Bio__Emboss_ajStrTokenAssignC, file);
        newXS("Bio::Emboss::ajStrTokenAssignS", XS_Bio__Emboss_ajStrTokenAssignS, file);
        newXS("Bio::Emboss::ajStrTokenReset", XS_Bio__Emboss_ajStrTokenReset, file);
        newXS("Bio::Emboss::ajStrTokenTrace", XS_Bio__Emboss_ajStrTokenTrace, file);
        newXS("Bio::Emboss::ajStrTokenNextFind", XS_Bio__Emboss_ajStrTokenNextFind, file);
        newXS("Bio::Emboss::ajStrTokenNextFindC", XS_Bio__Emboss_ajStrTokenNextFindC, file);
        newXS("Bio::Emboss::ajStrTokenNextParse", XS_Bio__Emboss_ajStrTokenNextParse, file);
        newXS("Bio::Emboss::ajStrTokenNextParseC", XS_Bio__Emboss_ajStrTokenNextParseC, file);
        newXS("Bio::Emboss::ajStrTokenNextParseS", XS_Bio__Emboss_ajStrTokenNextParseS, file);
        newXS("Bio::Emboss::ajStrTokenRestParse", XS_Bio__Emboss_ajStrTokenRestParse, file);
        newXS("Bio::Emboss::ajSysBasename", XS_Bio__Emboss_ajSysBasename, file);
        newXS("Bio::Emboss::ajSysItoC", XS_Bio__Emboss_ajSysItoC, file);
        newXS("Bio::Emboss::ajSysItoUC", XS_Bio__Emboss_ajSysItoUC, file);
        newXS("Bio::Emboss::ajSysWhich", XS_Bio__Emboss_ajSysWhich, file);
        newXS("Bio::Emboss::ajSystem", XS_Bio__Emboss_ajSystem, file);
        newXS("Bio::Emboss::ajSysUnlink", XS_Bio__Emboss_ajSysUnlink, file);
        newXS("Bio::Emboss::ajSysCanon", XS_Bio__Emboss_ajSysCanon, file);
        newXS("Bio::Emboss::ajSysArglist", XS_Bio__Emboss_ajSysArglist, file);
        newXS("Bio::Emboss::ajSysArgListFree", XS_Bio__Emboss_ajSysArgListFree, file);
        newXS("Bio::Emboss::ajSysFdopen", XS_Bio__Emboss_ajSysFdopen, file);
        newXS("Bio::Emboss::ajSysStrdup", XS_Bio__Emboss_ajSysStrdup, file);
        newXS("Bio::Emboss::ajSysIsRegular", XS_Bio__Emboss_ajSysIsRegular, file);
        newXS("Bio::Emboss::ajSysIsDirectory", XS_Bio__Emboss_ajSysIsDirectory, file);
        newXS("Bio::Emboss::ajSysStrtok", XS_Bio__Emboss_ajSysStrtok, file);
        newXS("Bio::Emboss::ajSysStrtokR", XS_Bio__Emboss_ajSysStrtokR, file);
        newXS("Bio::Emboss::ajSysFgets", XS_Bio__Emboss_ajSysFgets, file);
        newXS("Bio::Emboss::ajSysFopen", XS_Bio__Emboss_ajSysFopen, file);
        newXS("Bio::Emboss::ajSysExit", XS_Bio__Emboss_ajSysExit, file);
        newXS("Bio::Emboss::ajTableGet", XS_Bio__Emboss_ajTableGet, file);
        newXS("Bio::Emboss::ajTableKey", XS_Bio__Emboss_ajTableKey, file);
        newXS("Bio::Emboss::ajTableTrace", XS_Bio__Emboss_ajTableTrace, file);
        newXS("Bio::Emboss::ajStrTableTrace", XS_Bio__Emboss_ajStrTableTrace, file);
        newXS("Bio::Emboss::ajTablePut", XS_Bio__Emboss_ajTablePut, file);
        newXS("Bio::Emboss::ajTableLength", XS_Bio__Emboss_ajTableLength, file);
        newXS("Bio::Emboss::ajTableRemove", XS_Bio__Emboss_ajTableRemove, file);
        newXS("Bio::Emboss::ajTableToarray", XS_Bio__Emboss_ajTableToarray, file);
        newXS("Bio::Emboss::ajTableFree", XS_Bio__Emboss_ajTableFree, file);
        newXS("Bio::Emboss::ajStrTableNewCaseC", XS_Bio__Emboss_ajStrTableNewCaseC, file);
        newXS("Bio::Emboss::ajStrTableNewCase", XS_Bio__Emboss_ajStrTableNewCase, file);
        newXS("Bio::Emboss::ajStrTableNewC", XS_Bio__Emboss_ajStrTableNewC, file);
        newXS("Bio::Emboss::ajStrTableNew", XS_Bio__Emboss_ajStrTableNew, file);
        newXS("Bio::Emboss::ajStrTableHashCaseC", XS_Bio__Emboss_ajStrTableHashCaseC, file);
        newXS("Bio::Emboss::ajStrTableHashCase", XS_Bio__Emboss_ajStrTableHashCase, file);
        newXS("Bio::Emboss::ajStrTableHashC", XS_Bio__Emboss_ajStrTableHashC, file);
        newXS("Bio::Emboss::ajStrTableHash", XS_Bio__Emboss_ajStrTableHash, file);
        newXS("Bio::Emboss::ajStrTableCmpCaseC", XS_Bio__Emboss_ajStrTableCmpCaseC, file);
        newXS("Bio::Emboss::ajStrTableCmpCase", XS_Bio__Emboss_ajStrTableCmpCase, file);
        newXS("Bio::Emboss::ajStrTableCmpC", XS_Bio__Emboss_ajStrTableCmpC, file);
        newXS("Bio::Emboss::ajStrTableCmp", XS_Bio__Emboss_ajStrTableCmp, file);
        newXS("Bio::Emboss::ajStrTablePrint", XS_Bio__Emboss_ajStrTablePrint, file);
        newXS("Bio::Emboss::ajStrTablePrintC", XS_Bio__Emboss_ajStrTablePrintC, file);
        newXS("Bio::Emboss::ajStrTableFree", XS_Bio__Emboss_ajStrTableFree, file);
        newXS("Bio::Emboss::ajTableExit", XS_Bio__Emboss_ajTableExit, file);
        newXS("Bio::Emboss::ajTimeTodayRef", XS_Bio__Emboss_ajTimeTodayRef, file);
        newXS("Bio::Emboss::ajTimeToday", XS_Bio__Emboss_ajTimeToday, file);
        newXS("Bio::Emboss::ajTimeTodayF", XS_Bio__Emboss_ajTimeTodayF, file);
        newXS("Bio::Emboss::ajTimeTodayRefF", XS_Bio__Emboss_ajTimeTodayRefF, file);
        newXS("Bio::Emboss::ajTimeTrace", XS_Bio__Emboss_ajTimeTrace, file);
        newXS("Bio::Emboss::ajTimeSet", XS_Bio__Emboss_ajTimeSet, file);
        newXS("Bio::Emboss::ajTimeSetS", XS_Bio__Emboss_ajTimeSetS, file);
        newXS("Bio::Emboss::ajTimeLocal", XS_Bio__Emboss_ajTimeLocal, file);
        newXS("Bio::Emboss::ajTimeNew", XS_Bio__Emboss_ajTimeNew, file);
        newXS("Bio::Emboss::ajTimeDel", XS_Bio__Emboss_ajTimeDel, file);
        newXS("Bio::Emboss::ajTimeExit", XS_Bio__Emboss_ajTimeExit, file);
        newXS("Bio::Emboss::ajTrnDel", XS_Bio__Emboss_ajTrnDel, file);
        newXS("Bio::Emboss::ajTrnNewC", XS_Bio__Emboss_ajTrnNewC, file);
        newXS("Bio::Emboss::ajTrnNewI", XS_Bio__Emboss_ajTrnNewI, file);
        newXS("Bio::Emboss::ajTrnNew", XS_Bio__Emboss_ajTrnNew, file);
        newXS("Bio::Emboss::ajTrnReadFile", XS_Bio__Emboss_ajTrnReadFile, file);
        newXS("Bio::Emboss::ajTrnNewPep", XS_Bio__Emboss_ajTrnNewPep, file);
        newXS("Bio::Emboss::ajTrnCodon", XS_Bio__Emboss_ajTrnCodon, file);
        newXS("Bio::Emboss::ajTrnRevCodon", XS_Bio__Emboss_ajTrnRevCodon, file);
        newXS("Bio::Emboss::ajTrnCodonC", XS_Bio__Emboss_ajTrnCodonC, file);
        newXS("Bio::Emboss::ajTrnRevCodonC", XS_Bio__Emboss_ajTrnRevCodonC, file);
        newXS("Bio::Emboss::ajTrnCodonK", XS_Bio__Emboss_ajTrnCodonK, file);
        newXS("Bio::Emboss::ajTrnRevCodonK", XS_Bio__Emboss_ajTrnRevCodonK, file);
        newXS("Bio::Emboss::ajTrnC", XS_Bio__Emboss_ajTrnC, file);
        newXS("Bio::Emboss::ajTrnRevC", XS_Bio__Emboss_ajTrnRevC, file);
        newXS("Bio::Emboss::ajTrnAltRevC", XS_Bio__Emboss_ajTrnAltRevC, file);
        newXS("Bio::Emboss::ajTrnStr", XS_Bio__Emboss_ajTrnStr, file);
        newXS("Bio::Emboss::ajTrnRevStr", XS_Bio__Emboss_ajTrnRevStr, file);
        newXS("Bio::Emboss::ajTrnAltRevStr", XS_Bio__Emboss_ajTrnAltRevStr, file);
        newXS("Bio::Emboss::ajTrnSeq", XS_Bio__Emboss_ajTrnSeq, file);
        newXS("Bio::Emboss::ajTrnRevSeq", XS_Bio__Emboss_ajTrnRevSeq, file);
        newXS("Bio::Emboss::ajTrnAltRevSeq", XS_Bio__Emboss_ajTrnAltRevSeq, file);
        newXS("Bio::Emboss::ajTrnCFrame", XS_Bio__Emboss_ajTrnCFrame, file);
        newXS("Bio::Emboss::ajTrnStrFrame", XS_Bio__Emboss_ajTrnStrFrame, file);
        newXS("Bio::Emboss::ajTrnSeqFrame", XS_Bio__Emboss_ajTrnSeqFrame, file);
        newXS("Bio::Emboss::ajTrnSeqFramePep", XS_Bio__Emboss_ajTrnSeqFramePep, file);
        newXS("Bio::Emboss::ajTrnCDangle", XS_Bio__Emboss_ajTrnCDangle, file);
        newXS("Bio::Emboss::ajTrnStrDangle", XS_Bio__Emboss_ajTrnStrDangle, file);
        newXS("Bio::Emboss::ajTrnSeqOrig", XS_Bio__Emboss_ajTrnSeqOrig, file);
        newXS("Bio::Emboss::ajTrnGetTitle", XS_Bio__Emboss_ajTrnGetTitle, file);
        newXS("Bio::Emboss::ajTrnGetFileName", XS_Bio__Emboss_ajTrnGetFileName, file);
        newXS("Bio::Emboss::ajTrnStartStop", XS_Bio__Emboss_ajTrnStartStop, file);
        newXS("Bio::Emboss::ajTrnStartStopC", XS_Bio__Emboss_ajTrnStartStopC, file);
        newXS("Bio::Emboss::ajTrnName", XS_Bio__Emboss_ajTrnName, file);
        newXS("Bio::Emboss::ajTrnExit", XS_Bio__Emboss_ajTrnExit, file);
        newXS("Bio::Emboss::ajTreeNew", XS_Bio__Emboss_ajTreeNew, file);
        newXS("Bio::Emboss::ajTreestrNew", XS_Bio__Emboss_ajTreestrNew, file);
        newXS("Bio::Emboss::ajTreestrCopy", XS_Bio__Emboss_ajTreestrCopy, file);
        newXS("Bio::Emboss::ajTreeCopy", XS_Bio__Emboss_ajTreeCopy, file);
        newXS("Bio::Emboss::ajTreeLength", XS_Bio__Emboss_ajTreeLength, file);
        newXS("Bio::Emboss::ajTreestrLength", XS_Bio__Emboss_ajTreestrLength, file);
        newXS("Bio::Emboss::ajTreeFree", XS_Bio__Emboss_ajTreeFree, file);
        newXS("Bio::Emboss::ajTreestrFree", XS_Bio__Emboss_ajTreestrFree, file);
        newXS("Bio::Emboss::ajTreeDel", XS_Bio__Emboss_ajTreeDel, file);
        newXS("Bio::Emboss::ajTreestrDel", XS_Bio__Emboss_ajTreestrDel, file);
        newXS("Bio::Emboss::ajTreeToArray", XS_Bio__Emboss_ajTreeToArray, file);
        newXS("Bio::Emboss::ajTreestrToArray", XS_Bio__Emboss_ajTreestrToArray, file);
        newXS("Bio::Emboss::ajTreeDummyFunction", XS_Bio__Emboss_ajTreeDummyFunction, file);
        newXS("Bio::Emboss::ajTreeAddData", XS_Bio__Emboss_ajTreeAddData, file);
        newXS("Bio::Emboss::ajTreeAddNode", XS_Bio__Emboss_ajTreeAddNode, file);
        newXS("Bio::Emboss::ajTreeAddSubNode", XS_Bio__Emboss_ajTreeAddSubNode, file);
        newXS("Bio::Emboss::ajTreeTrace", XS_Bio__Emboss_ajTreeTrace, file);
        newXS("Bio::Emboss::ajTreeExit", XS_Bio__Emboss_ajTreeExit, file);
        newXS("Bio::Emboss::ajExit", XS_Bio__Emboss_ajExit, file);
        newXS("Bio::Emboss::ajExitBad", XS_Bio__Emboss_ajExitBad, file);
        newXS("Bio::Emboss::ajExitAbort", XS_Bio__Emboss_ajExitAbort, file);
        newXS("Bio::Emboss::ajLogInfo", XS_Bio__Emboss_ajLogInfo, file);
        newXS("Bio::Emboss::ajUtilUid", XS_Bio__Emboss_ajUtilUid, file);
        newXS("Bio::Emboss::ajUtilBigendian", XS_Bio__Emboss_ajUtilBigendian, file);
        newXS("Bio::Emboss::ajUtilRev2", XS_Bio__Emboss_ajUtilRev2, file);
        newXS("Bio::Emboss::ajUtilRev4", XS_Bio__Emboss_ajUtilRev4, file);
        newXS("Bio::Emboss::ajUtilRev8", XS_Bio__Emboss_ajUtilRev8, file);
        newXS("Bio::Emboss::ajUtilRevShort", XS_Bio__Emboss_ajUtilRevShort, file);
        newXS("Bio::Emboss::ajUtilRevInt", XS_Bio__Emboss_ajUtilRevInt, file);
        newXS("Bio::Emboss::ajUtilRevLong", XS_Bio__Emboss_ajUtilRevLong, file);
        newXS("Bio::Emboss::ajUtilCatch", XS_Bio__Emboss_ajUtilCatch, file);
        newXS("Bio::Emboss::aj3dVectorNew", XS_Bio__Emboss_aj3dVectorNew, file);
        newXS("Bio::Emboss::aj3dVectorCreate", XS_Bio__Emboss_aj3dVectorCreate, file);
        newXS("Bio::Emboss::aj3dVectorDel", XS_Bio__Emboss_aj3dVectorDel, file);
        newXS("Bio::Emboss::aj3dVectorCrossProduct", XS_Bio__Emboss_aj3dVectorCrossProduct, file);
        newXS("Bio::Emboss::aj3dVectorBetweenPoints", XS_Bio__Emboss_aj3dVectorBetweenPoints, file);
        newXS("Bio::Emboss::aj3dVectorLength", XS_Bio__Emboss_aj3dVectorLength, file);
        newXS("Bio::Emboss::aj3dVectorAngle", XS_Bio__Emboss_aj3dVectorAngle, file);
        newXS("Bio::Emboss::aj3dVectorDihedralAngle", XS_Bio__Emboss_aj3dVectorDihedralAngle, file);
        newXS("Bio::Emboss::aj3dVectorDotProduct", XS_Bio__Emboss_aj3dVectorDotProduct, file);
        newXS("Bio::Emboss::aj3dVectorSum", XS_Bio__Emboss_aj3dVectorSum, file);
        newXS("Bio::Emboss::embComComplexity", XS_Bio__Emboss_embComComplexity, file);
        newXS("Bio::Emboss::embComWriteFile", XS_Bio__Emboss_embComWriteFile, file);
        newXS("Bio::Emboss::embComWriteValueOfSeq", XS_Bio__Emboss_embComWriteValueOfSeq, file);
        newXS("Bio::Emboss::embComUnused", XS_Bio__Emboss_embComUnused, file);
        newXS("Bio::Emboss::embConsCalc", XS_Bio__Emboss_embConsCalc, file);
        newXS("Bio::Emboss::embDataListDel", XS_Bio__Emboss_embDataListDel, file);
        newXS("Bio::Emboss::embDataListRead", XS_Bio__Emboss_embDataListRead, file);
        newXS("Bio::Emboss::embDataListGetTables", XS_Bio__Emboss_embDataListGetTables, file);
        newXS("Bio::Emboss::embDataListGetTable", XS_Bio__Emboss_embDataListGetTable, file);
        newXS("Bio::Emboss::embDbiFieldNew", XS_Bio__Emboss_embDbiFieldNew, file);
        newXS("Bio::Emboss::embDbiCmpId", XS_Bio__Emboss_embDbiCmpId, file);
        newXS("Bio::Emboss::embDbiCmpFieldId", XS_Bio__Emboss_embDbiCmpFieldId, file);
        newXS("Bio::Emboss::embDbiCmpFieldField", XS_Bio__Emboss_embDbiCmpFieldField, file);
        newXS("Bio::Emboss::embDbiEntryNew", XS_Bio__Emboss_embDbiEntryNew, file);
        newXS("Bio::Emboss::embDbiEntryDel", XS_Bio__Emboss_embDbiEntryDel, file);
        newXS("Bio::Emboss::embDbiFileList", XS_Bio__Emboss_embDbiFileList, file);
        newXS("Bio::Emboss::embDbiFileListExc", XS_Bio__Emboss_embDbiFileListExc, file);
        newXS("Bio::Emboss::embDbiFlatOpenlib", XS_Bio__Emboss_embDbiFlatOpenlib, file);
        newXS("Bio::Emboss::embDbiRmFile", XS_Bio__Emboss_embDbiRmFile, file);
        newXS("Bio::Emboss::embDbiRmFileI", XS_Bio__Emboss_embDbiRmFileI, file);
        newXS("Bio::Emboss::embDbiRmEntryFile", XS_Bio__Emboss_embDbiRmEntryFile, file);
        newXS("Bio::Emboss::embDbiSortFile", XS_Bio__Emboss_embDbiSortFile, file);
        newXS("Bio::Emboss::embDbiSysCmd", XS_Bio__Emboss_embDbiSysCmd, file);
        newXS("Bio::Emboss::embDbiHeaderSize", XS_Bio__Emboss_embDbiHeaderSize, file);
        newXS("Bio::Emboss::embDbiHeader", XS_Bio__Emboss_embDbiHeader, file);
        newXS("Bio::Emboss::embDbiFileSingle", XS_Bio__Emboss_embDbiFileSingle, file);
        newXS("Bio::Emboss::embDbiFileIn", XS_Bio__Emboss_embDbiFileIn, file);
        newXS("Bio::Emboss::embDbiFileOut", XS_Bio__Emboss_embDbiFileOut, file);
        newXS("Bio::Emboss::embDbiFileIndex", XS_Bio__Emboss_embDbiFileIndex, file);
        newXS("Bio::Emboss::embDbiWriteDivision", XS_Bio__Emboss_embDbiWriteDivision, file);
        newXS("Bio::Emboss::embDbiWriteDivisionRecord", XS_Bio__Emboss_embDbiWriteDivisionRecord, file);
        newXS("Bio::Emboss::embDbiWriteEntryRecord", XS_Bio__Emboss_embDbiWriteEntryRecord, file);
        newXS("Bio::Emboss::embDbiWriteHit", XS_Bio__Emboss_embDbiWriteHit, file);
        newXS("Bio::Emboss::embDbiWriteTrg", XS_Bio__Emboss_embDbiWriteTrg, file);
        newXS("Bio::Emboss::embDbiSortOpen", XS_Bio__Emboss_embDbiSortOpen, file);
        newXS("Bio::Emboss::embDbiSortClose", XS_Bio__Emboss_embDbiSortClose, file);
        newXS("Bio::Emboss::embDbiMemEntry", XS_Bio__Emboss_embDbiMemEntry, file);
        newXS("Bio::Emboss::embDbiSortWriteEntry", XS_Bio__Emboss_embDbiSortWriteEntry, file);
        newXS("Bio::Emboss::embDbiMemWriteEntry", XS_Bio__Emboss_embDbiMemWriteEntry, file);
        newXS("Bio::Emboss::embDbiSortWriteFields", XS_Bio__Emboss_embDbiSortWriteFields, file);
        newXS("Bio::Emboss::embDbiMemWriteFields", XS_Bio__Emboss_embDbiMemWriteFields, file);
        newXS("Bio::Emboss::embDbiDateSet", XS_Bio__Emboss_embDbiDateSet, file);
        newXS("Bio::Emboss::embDbiMaxlen", XS_Bio__Emboss_embDbiMaxlen, file);
        newXS("Bio::Emboss::embDbiLogHeader", XS_Bio__Emboss_embDbiLogHeader, file);
        newXS("Bio::Emboss::embDbiLogFields", XS_Bio__Emboss_embDbiLogFields, file);
        newXS("Bio::Emboss::embDbiLogSource", XS_Bio__Emboss_embDbiLogSource, file);
        newXS("Bio::Emboss::embDbiLogCmdline", XS_Bio__Emboss_embDbiLogCmdline, file);
        newXS("Bio::Emboss::embDbiLogFile", XS_Bio__Emboss_embDbiLogFile, file);
        newXS("Bio::Emboss::embDbiLogFinal", XS_Bio__Emboss_embDbiLogFinal, file);
        newXS("Bio::Emboss::embDbiExit", XS_Bio__Emboss_embDbiExit, file);
        newXS("Bio::Emboss::embDmxScophitsToHitlist", XS_Bio__Emboss_embDmxScophitsToHitlist, file);
        newXS("Bio::Emboss::embDmxScophitToHit", XS_Bio__Emboss_embDmxScophitToHit, file);
        newXS("Bio::Emboss::embDmxScophitsAccToHitlist", XS_Bio__Emboss_embDmxScophitsAccToHitlist, file);
        newXS("Bio::Emboss::embDmxHitsWrite", XS_Bio__Emboss_embDmxHitsWrite, file);
        newXS("Bio::Emboss::embDmxScopToScophit", XS_Bio__Emboss_embDmxScopToScophit, file);
        newXS("Bio::Emboss::embDmxScopalgToScop", XS_Bio__Emboss_embDmxScopalgToScop, file);
        newXS("Bio::Emboss::embDmxScophitsOverlapAcc", XS_Bio__Emboss_embDmxScophitsOverlapAcc, file);
        newXS("Bio::Emboss::embDmxScophitsOverlap", XS_Bio__Emboss_embDmxScophitsOverlap, file);
        newXS("Bio::Emboss::embDmxScophitMerge", XS_Bio__Emboss_embDmxScophitMerge, file);
        newXS("Bio::Emboss::embDmxScophitMergeInsertOther", XS_Bio__Emboss_embDmxScophitMergeInsertOther, file);
        newXS("Bio::Emboss::embDmxScophitMergeInsertOtherTarget", XS_Bio__Emboss_embDmxScophitMergeInsertOtherTarget, file);
        newXS("Bio::Emboss::embDmxScophitMergeInsertOtherTargetBoth", XS_Bio__Emboss_embDmxScophitMergeInsertOtherTargetBoth, file);
        newXS("Bio::Emboss::embDmxScophitMergeInsertThis", XS_Bio__Emboss_embDmxScophitMergeInsertThis, file);
        newXS("Bio::Emboss::embDmxScophitMergeInsertThisTarget", XS_Bio__Emboss_embDmxScophitMergeInsertThisTarget, file);
        newXS("Bio::Emboss::embDmxScophitMergeInsertThisTargetBoth", XS_Bio__Emboss_embDmxScophitMergeInsertThisTargetBoth, file);
        newXS("Bio::Emboss::embDmxSeqNR", XS_Bio__Emboss_embDmxSeqNR, file);
        newXS("Bio::Emboss::embDmxSeqNRRange", XS_Bio__Emboss_embDmxSeqNRRange, file);
        newXS("Bio::Emboss::embDmxSeqCompall", XS_Bio__Emboss_embDmxSeqCompall, file);
        newXS("Bio::Emboss::embDmxScophitReadAllFasta", XS_Bio__Emboss_embDmxScophitReadAllFasta, file);
        newXS("Bio::Emboss::embDmxHitlistToScophits", XS_Bio__Emboss_embDmxHitlistToScophits, file);
        newXS("Bio::Emboss::embScopToPdbid", XS_Bio__Emboss_embScopToPdbid, file);
        newXS("Bio::Emboss::embScopToSp", XS_Bio__Emboss_embScopToSp, file);
        newXS("Bio::Emboss::embScopToAcc", XS_Bio__Emboss_embScopToAcc, file);
        newXS("Bio::Emboss::embEstSetDebug", XS_Bio__Emboss_embEstSetDebug, file);
        newXS("Bio::Emboss::embEstSetVerbose", XS_Bio__Emboss_embEstSetVerbose, file);
        newXS("Bio::Emboss::embEstMatInit", XS_Bio__Emboss_embEstMatInit, file);
        newXS("Bio::Emboss::embEstFindSpliceSites", XS_Bio__Emboss_embEstFindSpliceSites, file);
        newXS("Bio::Emboss::embEstShuffleSeq", XS_Bio__Emboss_embEstShuffleSeq, file);
        newXS("Bio::Emboss::embEstFreeAlign", XS_Bio__Emboss_embEstFreeAlign, file);
        newXS("Bio::Emboss::embEstPrintAlign", XS_Bio__Emboss_embEstPrintAlign, file);
        newXS("Bio::Emboss::embEstAlignNonRecursive", XS_Bio__Emboss_embEstAlignNonRecursive, file);
        newXS("Bio::Emboss::embEstAlignLinearSpace", XS_Bio__Emboss_embEstAlignLinearSpace, file);
        newXS("Bio::Emboss::embEstOutBlastStyle", XS_Bio__Emboss_embEstOutBlastStyle, file);
        newXS("Bio::Emboss::embExit", XS_Bio__Emboss_embExit, file);
        newXS("Bio::Emboss::embExitBad", XS_Bio__Emboss_embExitBad, file);
        newXS("Bio::Emboss::embGrpMakeNewGnode", XS_Bio__Emboss_embGrpMakeNewGnode, file);
        newXS("Bio::Emboss::embGrpMakeNewPnode", XS_Bio__Emboss_embGrpMakeNewPnode, file);
        newXS("Bio::Emboss::embGrpSortGroupsList", XS_Bio__Emboss_embGrpSortGroupsList, file);
        newXS("Bio::Emboss::embGrpSortProgsList", XS_Bio__Emboss_embGrpSortProgsList, file);
        newXS("Bio::Emboss::embGrpCompareTwoGnodes", XS_Bio__Emboss_embGrpCompareTwoGnodes, file);
        newXS("Bio::Emboss::embGrpCompareTwoPnodes", XS_Bio__Emboss_embGrpCompareTwoPnodes, file);
        newXS("Bio::Emboss::embGrpOutputGroupsList", XS_Bio__Emboss_embGrpOutputGroupsList, file);
        newXS("Bio::Emboss::embGrpOutputProgsList", XS_Bio__Emboss_embGrpOutputProgsList, file);
        newXS("Bio::Emboss::embGrpGroupsListDel", XS_Bio__Emboss_embGrpGroupsListDel, file);
        newXS("Bio::Emboss::embGrpProgsListDel", XS_Bio__Emboss_embGrpProgsListDel, file);
        newXS("Bio::Emboss::embGrpKeySearchProgs", XS_Bio__Emboss_embGrpKeySearchProgs, file);
        newXS("Bio::Emboss::embGrpKeySearchSeeAlso", XS_Bio__Emboss_embGrpKeySearchSeeAlso, file);
        newXS("Bio::Emboss::embGrpProgsMakeUnique", XS_Bio__Emboss_embGrpProgsMakeUnique, file);
        newXS("Bio::Emboss::embGrpGroupMakeUnique", XS_Bio__Emboss_embGrpGroupMakeUnique, file);
        newXS("Bio::Emboss::embGrpExit", XS_Bio__Emboss_embGrpExit, file);
        newXS("Bio::Emboss::embIepPhToHconc", XS_Bio__Emboss_embIepPhToHconc, file);
        newXS("Bio::Emboss::embIepPhFromHconc", XS_Bio__Emboss_embIepPhFromHconc, file);
        newXS("Bio::Emboss::embIepPkToK", XS_Bio__Emboss_embIepPkToK, file);
        newXS("Bio::Emboss::embIepPkFromK", XS_Bio__Emboss_embIepPkFromK, file);
        newXS("Bio::Emboss::embIepPkRead", XS_Bio__Emboss_embIepPkRead, file);
        newXS("Bio::Emboss::embIepCompC", XS_Bio__Emboss_embIepCompC, file);
        newXS("Bio::Emboss::embIepCompS", XS_Bio__Emboss_embIepCompS, file);
        newXS("Bio::Emboss::embIepCalcK", XS_Bio__Emboss_embIepCalcK, file);
        newXS("Bio::Emboss::embIepGetProto", XS_Bio__Emboss_embIepGetProto, file);
        newXS("Bio::Emboss::embIepGetCharge", XS_Bio__Emboss_embIepGetCharge, file);
        newXS("Bio::Emboss::embIepPhConverge", XS_Bio__Emboss_embIepPhConverge, file);
        newXS("Bio::Emboss::embIepIepC", XS_Bio__Emboss_embIepIepC, file);
        newXS("Bio::Emboss::embIepIepS", XS_Bio__Emboss_embIepIepS, file);
        newXS("Bio::Emboss::embBtreeEmblKW", XS_Bio__Emboss_embBtreeEmblKW, file);
        newXS("Bio::Emboss::embBtreeEmblTX", XS_Bio__Emboss_embBtreeEmblTX, file);
        newXS("Bio::Emboss::embBtreeEmblAC", XS_Bio__Emboss_embBtreeEmblAC, file);
        newXS("Bio::Emboss::embBtreeEmblSV", XS_Bio__Emboss_embBtreeEmblSV, file);
        newXS("Bio::Emboss::embBtreeEmblDE", XS_Bio__Emboss_embBtreeEmblDE, file);
        newXS("Bio::Emboss::embBtreeGenBankAC", XS_Bio__Emboss_embBtreeGenBankAC, file);
        newXS("Bio::Emboss::embBtreeGenBankKW", XS_Bio__Emboss_embBtreeGenBankKW, file);
        newXS("Bio::Emboss::embBtreeGenBankDE", XS_Bio__Emboss_embBtreeGenBankDE, file);
        newXS("Bio::Emboss::embBtreeGenBankTX", XS_Bio__Emboss_embBtreeGenBankTX, file);
        newXS("Bio::Emboss::embBtreeFastaDE", XS_Bio__Emboss_embBtreeFastaDE, file);
        newXS("Bio::Emboss::embBtreeReadDir", XS_Bio__Emboss_embBtreeReadDir, file);
        newXS("Bio::Emboss::embBtreeEntryNew", XS_Bio__Emboss_embBtreeEntryNew, file);
        newXS("Bio::Emboss::embBtreeEntryDel", XS_Bio__Emboss_embBtreeEntryDel, file);
        newXS("Bio::Emboss::embBtreeSetFields", XS_Bio__Emboss_embBtreeSetFields, file);
        newXS("Bio::Emboss::embBtreeSetDbInfo", XS_Bio__Emboss_embBtreeSetDbInfo, file);
        newXS("Bio::Emboss::embBtreeGetFiles", XS_Bio__Emboss_embBtreeGetFiles, file);
        newXS("Bio::Emboss::embBtreeWriteEntryFile", XS_Bio__Emboss_embBtreeWriteEntryFile, file);
        newXS("Bio::Emboss::embBtreeGetRsInfo", XS_Bio__Emboss_embBtreeGetRsInfo, file);
        newXS("Bio::Emboss::embBtreeOpenCaches", XS_Bio__Emboss_embBtreeOpenCaches, file);
        newXS("Bio::Emboss::embBtreeCloseCaches", XS_Bio__Emboss_embBtreeCloseCaches, file);
        newXS("Bio::Emboss::embBtreeDumpParameters", XS_Bio__Emboss_embBtreeDumpParameters, file);
        newXS("Bio::Emboss::embMatMatchDel", XS_Bio__Emboss_embMatMatchDel, file);
        newXS("Bio::Emboss::embMatPrintsInit", XS_Bio__Emboss_embMatPrintsInit, file);
        newXS("Bio::Emboss::embMatProtReadInt", XS_Bio__Emboss_embMatProtReadInt, file);
        newXS("Bio::Emboss::embMatProtDelInt", XS_Bio__Emboss_embMatProtDelInt, file);
        newXS("Bio::Emboss::embMatProtScanInt", XS_Bio__Emboss_embMatProtScanInt, file);
        newXS("Bio::Emboss::embMiscMatchPattern", XS_Bio__Emboss_embMiscMatchPattern, file);
        newXS("Bio::Emboss::embMolGetFrags", XS_Bio__Emboss_embMolGetFrags, file);
        newXS("Bio::Emboss::embNmerNuc2int", XS_Bio__Emboss_embNmerNuc2int, file);
        newXS("Bio::Emboss::embNmerInt2nuc", XS_Bio__Emboss_embNmerInt2nuc, file);
        newXS("Bio::Emboss::embNmerProt2int", XS_Bio__Emboss_embNmerProt2int, file);
        newXS("Bio::Emboss::embNmerInt2prot", XS_Bio__Emboss_embNmerInt2prot, file);
        newXS("Bio::Emboss::embNmerGetNoElements", XS_Bio__Emboss_embNmerGetNoElements, file);
        newXS("Bio::Emboss::embPatlistSeqSearch", XS_Bio__Emboss_embPatlistSeqSearch, file);
        newXS("Bio::Emboss::embPatlistRegexSearch", XS_Bio__Emboss_embPatlistRegexSearch, file);
        newXS("Bio::Emboss::embPatternRegexSearch", XS_Bio__Emboss_embPatternRegexSearch, file);
        newXS("Bio::Emboss::embPatternSeqSearch", XS_Bio__Emboss_embPatternSeqSearch, file);
        newXS("Bio::Emboss::embPatternSeqCompile", XS_Bio__Emboss_embPatternSeqCompile, file);
        newXS("Bio::Emboss::embPdbidToSp", XS_Bio__Emboss_embPdbidToSp, file);
        newXS("Bio::Emboss::embPdbidToAcc", XS_Bio__Emboss_embPdbidToAcc, file);
        newXS("Bio::Emboss::embAtomInContact", XS_Bio__Emboss_embAtomInContact, file);
        newXS("Bio::Emboss::embAtomDistance", XS_Bio__Emboss_embAtomDistance, file);
        newXS("Bio::Emboss::embVdwRad", XS_Bio__Emboss_embVdwRad, file);
        newXS("Bio::Emboss::embPdbToIdx", XS_Bio__Emboss_embPdbToIdx, file);
        newXS("Bio::Emboss::embPdbListHeterogens", XS_Bio__Emboss_embPdbListHeterogens, file);
        newXS("Bio::Emboss::embPdbResidueIndexI", XS_Bio__Emboss_embPdbResidueIndexI, file);
        newXS("Bio::Emboss::embPdbResidueIndexC", XS_Bio__Emboss_embPdbResidueIndexC, file);
        newXS("Bio::Emboss::embPdbResidueIndexICA", XS_Bio__Emboss_embPdbResidueIndexICA, file);
        newXS("Bio::Emboss::embPdbResidueIndexCCA", XS_Bio__Emboss_embPdbResidueIndexCCA, file);
        newXS("Bio::Emboss::embStrideToThree", XS_Bio__Emboss_embStrideToThree, file);
        newXS("Bio::Emboss::embPropAminoRead", XS_Bio__Emboss_embPropAminoRead, file);
        newXS("Bio::Emboss::embPropCalcMolwt", XS_Bio__Emboss_embPropCalcMolwt, file);
        newXS("Bio::Emboss::embPropCalcMolwtMod", XS_Bio__Emboss_embPropCalcMolwtMod, file);
        newXS("Bio::Emboss::embPropCalcMolextcoeff", XS_Bio__Emboss_embPropCalcMolextcoeff, file);
        newXS("Bio::Emboss::embPropCharToThree", XS_Bio__Emboss_embPropCharToThree, file);
        newXS("Bio::Emboss::embPropIntToThree", XS_Bio__Emboss_embPropIntToThree, file);
        newXS("Bio::Emboss::embPropCalcFragments", XS_Bio__Emboss_embPropCalcFragments, file);
        newXS("Bio::Emboss::embPropProtGaps", XS_Bio__Emboss_embPropProtGaps, file);
        newXS("Bio::Emboss::embPropProt1to3", XS_Bio__Emboss_embPropProt1to3, file);
        newXS("Bio::Emboss::embPropPurine", XS_Bio__Emboss_embPropPurine, file);
        newXS("Bio::Emboss::embPropPyrimidine", XS_Bio__Emboss_embPropPyrimidine, file);
        newXS("Bio::Emboss::embPropTransversion", XS_Bio__Emboss_embPropTransversion, file);
        newXS("Bio::Emboss::embPropTransition", XS_Bio__Emboss_embPropTransition, file);
        newXS("Bio::Emboss::embPropExit", XS_Bio__Emboss_embPropExit, file);
        newXS("Bio::Emboss::embReadAminoDataDoubleC", XS_Bio__Emboss_embReadAminoDataDoubleC, file);
        newXS("Bio::Emboss::embReadAminoDataFloatC", XS_Bio__Emboss_embReadAminoDataFloatC, file);
        newXS("Bio::Emboss::embReadAminoDataIntC", XS_Bio__Emboss_embReadAminoDataIntC, file);
        newXS("Bio::Emboss::embShowNew", XS_Bio__Emboss_embShowNew, file);
        newXS("Bio::Emboss::embShowDel", XS_Bio__Emboss_embShowDel, file);
        newXS("Bio::Emboss::embShowAddSeq", XS_Bio__Emboss_embShowAddSeq, file);
        newXS("Bio::Emboss::embShowAddBlank", XS_Bio__Emboss_embShowAddBlank, file);
        newXS("Bio::Emboss::embShowAddTicks", XS_Bio__Emboss_embShowAddTicks, file);
        newXS("Bio::Emboss::embShowAddTicknum", XS_Bio__Emboss_embShowAddTicknum, file);
        newXS("Bio::Emboss::embShowAddComp", XS_Bio__Emboss_embShowAddComp, file);
        newXS("Bio::Emboss::embShowAddTran", XS_Bio__Emboss_embShowAddTran, file);
        newXS("Bio::Emboss::embShowAddRE", XS_Bio__Emboss_embShowAddRE, file);
        newXS("Bio::Emboss::embShowAddFT", XS_Bio__Emboss_embShowAddFT, file);
        newXS("Bio::Emboss::embShowAddNote", XS_Bio__Emboss_embShowAddNote, file);
        newXS("Bio::Emboss::embShowPrint", XS_Bio__Emboss_embShowPrint, file);
        newXS("Bio::Emboss::embShowUpperRange", XS_Bio__Emboss_embShowUpperRange, file);
        newXS("Bio::Emboss::embShowColourRange", XS_Bio__Emboss_embShowColourRange, file);
        newXS("Bio::Emboss::embWordLength", XS_Bio__Emboss_embWordLength, file);
        newXS("Bio::Emboss::embWordClear", XS_Bio__Emboss_embWordClear, file);
        newXS("Bio::Emboss::embWordPrintTable", XS_Bio__Emboss_embWordPrintTable, file);
        newXS("Bio::Emboss::embWordPrintTableFI", XS_Bio__Emboss_embWordPrintTableFI, file);
        newXS("Bio::Emboss::embWordPrintTableF", XS_Bio__Emboss_embWordPrintTableF, file);
        newXS("Bio::Emboss::embWordFreeTable", XS_Bio__Emboss_embWordFreeTable, file);
        newXS("Bio::Emboss::embWordMatchListDelete", XS_Bio__Emboss_embWordMatchListDelete, file);
        newXS("Bio::Emboss::embWordMatchListPrint", XS_Bio__Emboss_embWordMatchListPrint, file);
        newXS("Bio::Emboss::embWordMatchListConvToFeat", XS_Bio__Emboss_embWordMatchListConvToFeat, file);
        newXS("Bio::Emboss::embWordGetTable", XS_Bio__Emboss_embWordGetTable, file);
        newXS("Bio::Emboss::embWordBuildMatchTable", XS_Bio__Emboss_embWordBuildMatchTable, file);
        newXS("Bio::Emboss::embWordMatchMin", XS_Bio__Emboss_embWordMatchMin, file);
        newXS("Bio::Emboss::embWordMatchIter", XS_Bio__Emboss_embWordMatchIter, file);
        newXS("Bio::Emboss::embWordUnused", XS_Bio__Emboss_embWordUnused, file);
        newXS("Bio::Emboss::embWordExit", XS_Bio__Emboss_embWordExit, file);
        newXS("Bio::Emboss::ajAcdDebug", XS_Bio__Emboss_ajAcdDebug, file);
        newXS("Bio::Emboss::ajAcdDebugIsSet", XS_Bio__Emboss_ajAcdDebugIsSet, file);
        newXS("Bio::Emboss::ajAcdFilter", XS_Bio__Emboss_ajAcdFilter, file);
        newXS("Bio::Emboss::ajAcdGetDiscretestatesI", XS_Bio__Emboss_ajAcdGetDiscretestatesI, file);
        newXS("Bio::Emboss::ajAcdGetListI", XS_Bio__Emboss_ajAcdGetListI, file);
        newXS("Bio::Emboss::ajAcdGetSelectI", XS_Bio__Emboss_ajAcdGetSelectI, file);
        newXS("Bio::Emboss::ajAcdGetSeqsetallI", XS_Bio__Emboss_ajAcdGetSeqsetallI, file);
        newXS("Bio::Emboss::ajAcdGetTreeI", XS_Bio__Emboss_ajAcdGetTreeI, file);
        newXS("Bio::Emboss::ajAcdProgram", XS_Bio__Emboss_ajAcdProgram, file);
        newXS("Bio::Emboss::ajAcdProgramS", XS_Bio__Emboss_ajAcdProgramS, file);
        newXS("Bio::Emboss::ajAcdStdout", XS_Bio__Emboss_ajAcdStdout, file);
        newXS("Bio::Emboss::ajAcdValue", XS_Bio__Emboss_ajAcdValue, file);
        newXS("Bio::Emboss::ajHistSetBlackandWhite", XS_Bio__Emboss_ajHistSetBlackandWhite, file);
        newXS("Bio::Emboss::ajHistSetColour", XS_Bio__Emboss_ajHistSetColour, file);
        newXS("Bio::Emboss::ajHistSetPattern", XS_Bio__Emboss_ajHistSetPattern, file);
        newXS("Bio::Emboss::ajSeqallReverse", XS_Bio__Emboss_ajSeqallReverse, file);
        newXS("Bio::Emboss::ajSeqallToLower", XS_Bio__Emboss_ajSeqallToLower, file);
        newXS("Bio::Emboss::ajSeqallToUpper", XS_Bio__Emboss_ajSeqallToUpper, file);
        newXS("Bio::Emboss::ajSeqAssAcc", XS_Bio__Emboss_ajSeqAssAcc, file);
        newXS("Bio::Emboss::ajSeqAssAccC", XS_Bio__Emboss_ajSeqAssAccC, file);
        newXS("Bio::Emboss::ajSeqAssDesc", XS_Bio__Emboss_ajSeqAssDesc, file);
        newXS("Bio::Emboss::ajSeqAssDescC", XS_Bio__Emboss_ajSeqAssDescC, file);
        newXS("Bio::Emboss::ajSeqAssEntry", XS_Bio__Emboss_ajSeqAssEntry, file);
        newXS("Bio::Emboss::ajSeqAssEntryC", XS_Bio__Emboss_ajSeqAssEntryC, file);
        newXS("Bio::Emboss::ajSeqAssFile", XS_Bio__Emboss_ajSeqAssFile, file);
        newXS("Bio::Emboss::ajSeqAssFull", XS_Bio__Emboss_ajSeqAssFull, file);
        newXS("Bio::Emboss::ajSeqAssFullC", XS_Bio__Emboss_ajSeqAssFullC, file);
        newXS("Bio::Emboss::ajSeqAssGi", XS_Bio__Emboss_ajSeqAssGi, file);
        newXS("Bio::Emboss::ajSeqAssGiC", XS_Bio__Emboss_ajSeqAssGiC, file);
        newXS("Bio::Emboss::ajSeqAssName", XS_Bio__Emboss_ajSeqAssName, file);
        newXS("Bio::Emboss::ajSeqAssNameC", XS_Bio__Emboss_ajSeqAssNameC, file);
        newXS("Bio::Emboss::ajSeqAssSeq", XS_Bio__Emboss_ajSeqAssSeq, file);
        newXS("Bio::Emboss::ajSeqAssSeqC", XS_Bio__Emboss_ajSeqAssSeqC, file);
        newXS("Bio::Emboss::ajSeqAssSeqCI", XS_Bio__Emboss_ajSeqAssSeqCI, file);
        newXS("Bio::Emboss::ajSeqAssSv", XS_Bio__Emboss_ajSeqAssSv, file);
        newXS("Bio::Emboss::ajSeqAssSvC", XS_Bio__Emboss_ajSeqAssSvC, file);
        newXS("Bio::Emboss::ajSeqAssUfo", XS_Bio__Emboss_ajSeqAssUfo, file);
        newXS("Bio::Emboss::ajSeqAssUfoC", XS_Bio__Emboss_ajSeqAssUfoC, file);
        newXS("Bio::Emboss::ajSeqAssUsa", XS_Bio__Emboss_ajSeqAssUsa, file);
        newXS("Bio::Emboss::ajSeqAssUsaC", XS_Bio__Emboss_ajSeqAssUsaC, file);
        newXS("Bio::Emboss::ajSeqBegin", XS_Bio__Emboss_ajSeqBegin, file);
        newXS("Bio::Emboss::ajSeqChar", XS_Bio__Emboss_ajSeqChar, file);
        newXS("Bio::Emboss::ajSeqCharCopy", XS_Bio__Emboss_ajSeqCharCopy, file);
        newXS("Bio::Emboss::ajSeqCharCopyL", XS_Bio__Emboss_ajSeqCharCopyL, file);
        newXS("Bio::Emboss::ajSeqCheckGcg", XS_Bio__Emboss_ajSeqCheckGcg, file);
        newXS("Bio::Emboss::ajSeqCompOnly", XS_Bio__Emboss_ajSeqCompOnly, file);
        newXS("Bio::Emboss::ajSeqCompOnlyStr", XS_Bio__Emboss_ajSeqCompOnlyStr, file);
        newXS("Bio::Emboss::ajSeqCopyFeat", XS_Bio__Emboss_ajSeqCopyFeat, file);
        newXS("Bio::Emboss::ajSeqCount", XS_Bio__Emboss_ajSeqCount, file);
        newXS("Bio::Emboss::ajSeqCrc", XS_Bio__Emboss_ajSeqCrc, file);
        newXS("Bio::Emboss::ajSeqEnd", XS_Bio__Emboss_ajSeqEnd, file);
        newXS("Bio::Emboss::ajSeqGetAcc", XS_Bio__Emboss_ajSeqGetAcc, file);
        newXS("Bio::Emboss::ajSeqGetDesc", XS_Bio__Emboss_ajSeqGetDesc, file);
        newXS("Bio::Emboss::ajSeqGetEntry", XS_Bio__Emboss_ajSeqGetEntry, file);
        newXS("Bio::Emboss::ajSeqGetGi", XS_Bio__Emboss_ajSeqGetGi, file);
        newXS("Bio::Emboss::ajSeqGetName", XS_Bio__Emboss_ajSeqGetName, file);
        newXS("Bio::Emboss::ajSeqGetReverse", XS_Bio__Emboss_ajSeqGetReverse, file);
        newXS("Bio::Emboss::ajSeqGetReversed", XS_Bio__Emboss_ajSeqGetReversed, file);
        newXS("Bio::Emboss::ajSeqGetSv", XS_Bio__Emboss_ajSeqGetSv, file);
        newXS("Bio::Emboss::ajSeqGetTax", XS_Bio__Emboss_ajSeqGetTax, file);
        newXS("Bio::Emboss::ajSeqGetUsa", XS_Bio__Emboss_ajSeqGetUsa, file);
        newXS("Bio::Emboss::ajSeqLen", XS_Bio__Emboss_ajSeqLen, file);
        newXS("Bio::Emboss::ajSeqMakeUsa", XS_Bio__Emboss_ajSeqMakeUsa, file);
        newXS("Bio::Emboss::ajSeqMakeUsaS", XS_Bio__Emboss_ajSeqMakeUsaS, file);
        newXS("Bio::Emboss::ajSeqMW", XS_Bio__Emboss_ajSeqMW, file);
        newXS("Bio::Emboss::ajSeqName", XS_Bio__Emboss_ajSeqName, file);
        newXS("Bio::Emboss::ajSeqNewC", XS_Bio__Emboss_ajSeqNewC, file);
        newXS("Bio::Emboss::ajSeqNewL", XS_Bio__Emboss_ajSeqNewL, file);
        newXS("Bio::Emboss::ajSeqNewS", XS_Bio__Emboss_ajSeqNewS, file);
        newXS("Bio::Emboss::ajSeqNewRange", XS_Bio__Emboss_ajSeqNewRange, file);
        newXS("Bio::Emboss::ajSeqNewRangeCI", XS_Bio__Emboss_ajSeqNewRangeCI, file);
        newXS("Bio::Emboss::ajSeqNewStr", XS_Bio__Emboss_ajSeqNewStr, file);
        newXS("Bio::Emboss::ajSeqOffset", XS_Bio__Emboss_ajSeqOffset, file);
        newXS("Bio::Emboss::ajSeqOffend", XS_Bio__Emboss_ajSeqOffend, file);
        newXS("Bio::Emboss::ajSeqPos", XS_Bio__Emboss_ajSeqPos, file);
        newXS("Bio::Emboss::ajSeqPosI", XS_Bio__Emboss_ajSeqPosI, file);
        newXS("Bio::Emboss::ajSeqPosII", XS_Bio__Emboss_ajSeqPosII, file);
        newXS("Bio::Emboss::ajSeqReplace", XS_Bio__Emboss_ajSeqReplace, file);
        newXS("Bio::Emboss::ajSeqReplaceC", XS_Bio__Emboss_ajSeqReplaceC, file);
        newXS("Bio::Emboss::ajSeqRev", XS_Bio__Emboss_ajSeqRev, file);
        newXS("Bio::Emboss::ajSeqReverse", XS_Bio__Emboss_ajSeqReverse, file);
        newXS("Bio::Emboss::ajSeqReverseStr", XS_Bio__Emboss_ajSeqReverseStr, file);
        newXS("Bio::Emboss::ajSeqRevOnly", XS_Bio__Emboss_ajSeqRevOnly, file);
        newXS("Bio::Emboss::ajSeqSetRangeDir", XS_Bio__Emboss_ajSeqSetRangeDir, file);
        newXS("Bio::Emboss::ajSeqStr", XS_Bio__Emboss_ajSeqStr, file);
        newXS("Bio::Emboss::ajSeqStrCopy", XS_Bio__Emboss_ajSeqStrCopy, file);
        newXS("Bio::Emboss::ajSeqToLower", XS_Bio__Emboss_ajSeqToLower, file);
        newXS("Bio::Emboss::ajSeqToUpper", XS_Bio__Emboss_ajSeqToUpper, file);
        newXS("Bio::Emboss::ajSeqTrueBegin", XS_Bio__Emboss_ajSeqTrueBegin, file);
        newXS("Bio::Emboss::ajSeqTrueEnd", XS_Bio__Emboss_ajSeqTrueEnd, file);
        newXS("Bio::Emboss::ajSeqTrueLen", XS_Bio__Emboss_ajSeqTrueLen, file);
        newXS("Bio::Emboss::ajSeqTruePos", XS_Bio__Emboss_ajSeqTruePos, file);
        newXS("Bio::Emboss::ajSeqTruePosI", XS_Bio__Emboss_ajSeqTruePosI, file);
        newXS("Bio::Emboss::ajSeqTruePosII", XS_Bio__Emboss_ajSeqTruePosII, file);
        newXS("Bio::Emboss::ajCharFree", XS_Bio__Emboss_ajCharFree, file);
        newXS("Bio::Emboss::ajCharNew", XS_Bio__Emboss_ajCharNew, file);
        newXS("Bio::Emboss::ajCharNewL", XS_Bio__Emboss_ajCharNewL, file);
        newXS("Bio::Emboss::ajCharNewLS", XS_Bio__Emboss_ajCharNewLS, file);
        newXS("Bio::Emboss::ajCharPos", XS_Bio__Emboss_ajCharPos, file);
        newXS("Bio::Emboss::ajCharToLower", XS_Bio__Emboss_ajCharToLower, file);
        newXS("Bio::Emboss::ajCharToUpper", XS_Bio__Emboss_ajCharToUpper, file);
        newXS("Bio::Emboss::ajStrApp", XS_Bio__Emboss_ajStrApp, file);
        newXS("Bio::Emboss::ajStrAppC", XS_Bio__Emboss_ajStrAppC, file);
        newXS("Bio::Emboss::ajStrAppCI", XS_Bio__Emboss_ajStrAppCI, file);
        newXS("Bio::Emboss::ajStrAppK", XS_Bio__Emboss_ajStrAppK, file);
        newXS("Bio::Emboss::ajStrAppKI", XS_Bio__Emboss_ajStrAppKI, file);
        newXS("Bio::Emboss::ajStrAppSub", XS_Bio__Emboss_ajStrAppSub, file);
        newXS("Bio::Emboss::ajStrArrayDel", XS_Bio__Emboss_ajStrArrayDel, file);
        newXS("Bio::Emboss::ajStrAss", XS_Bio__Emboss_ajStrAss, file);
        newXS("Bio::Emboss::ajStrAssC", XS_Bio__Emboss_ajStrAssC, file);
        newXS("Bio::Emboss::ajStrAssCI", XS_Bio__Emboss_ajStrAssCI, file);
        newXS("Bio::Emboss::ajStrAssCL", XS_Bio__Emboss_ajStrAssCL, file);
        newXS("Bio::Emboss::ajStrAssI", XS_Bio__Emboss_ajStrAssI, file);
        newXS("Bio::Emboss::ajStrAssK", XS_Bio__Emboss_ajStrAssK, file);
        newXS("Bio::Emboss::ajStrAssL", XS_Bio__Emboss_ajStrAssL, file);
        newXS("Bio::Emboss::ajStrAssS", XS_Bio__Emboss_ajStrAssS, file);
        newXS("Bio::Emboss::ajStrAssSub", XS_Bio__Emboss_ajStrAssSub, file);
        newXS("Bio::Emboss::ajStrAssSubC", XS_Bio__Emboss_ajStrAssSubC, file);
        newXS("Bio::Emboss::ajStrBlock", XS_Bio__Emboss_ajStrBlock, file);
        newXS("Bio::Emboss::ajStrChar", XS_Bio__Emboss_ajStrChar, file);
        newXS("Bio::Emboss::ajStrChomp", XS_Bio__Emboss_ajStrChomp, file);
        newXS("Bio::Emboss::ajStrChompC", XS_Bio__Emboss_ajStrChompC, file);
        newXS("Bio::Emboss::ajStrChompEnd", XS_Bio__Emboss_ajStrChompEnd, file);
        newXS("Bio::Emboss::ajStrChop", XS_Bio__Emboss_ajStrChop, file);
        newXS("Bio::Emboss::ajStrClean", XS_Bio__Emboss_ajStrClean, file);
        newXS("Bio::Emboss::ajStrCleanWhite", XS_Bio__Emboss_ajStrCleanWhite, file);
        newXS("Bio::Emboss::ajStrClear", XS_Bio__Emboss_ajStrClear, file);
        newXS("Bio::Emboss::ajStrCmpCase", XS_Bio__Emboss_ajStrCmpCase, file);
        newXS("Bio::Emboss::ajStrCmpCaseCC", XS_Bio__Emboss_ajStrCmpCaseCC, file);
        newXS("Bio::Emboss::ajStrCmp", XS_Bio__Emboss_ajStrCmp, file);
        newXS("Bio::Emboss::ajStrCmpO", XS_Bio__Emboss_ajStrCmpO, file);
        newXS("Bio::Emboss::ajStrCmpWild", XS_Bio__Emboss_ajStrCmpWild, file);
        newXS("Bio::Emboss::ajStrCmpWildCC", XS_Bio__Emboss_ajStrCmpWildCC, file);
        newXS("Bio::Emboss::ajStrConvert", XS_Bio__Emboss_ajStrConvert, file);
        newXS("Bio::Emboss::ajStrConvertCC", XS_Bio__Emboss_ajStrConvertCC, file);
        newXS("Bio::Emboss::ajStrCopy", XS_Bio__Emboss_ajStrCopy, file);
        newXS("Bio::Emboss::ajStrCopyC", XS_Bio__Emboss_ajStrCopyC, file);
        newXS("Bio::Emboss::ajStrCountC", XS_Bio__Emboss_ajStrCountC, file);
        newXS("Bio::Emboss::ajStrCountK", XS_Bio__Emboss_ajStrCountK, file);
        newXS("Bio::Emboss::ajStrCut", XS_Bio__Emboss_ajStrCut, file);
        newXS("Bio::Emboss::ajStrDegap", XS_Bio__Emboss_ajStrDegap, file);
        newXS("Bio::Emboss::ajStrDelim", XS_Bio__Emboss_ajStrDelim, file);
        newXS("Bio::Emboss::ajStrDelReuse", XS_Bio__Emboss_ajStrDelReuse, file);
        newXS("Bio::Emboss::ajStrDup", XS_Bio__Emboss_ajStrDup, file);
        newXS("Bio::Emboss::ajStrFind", XS_Bio__Emboss_ajStrFind, file);
        newXS("Bio::Emboss::ajStrFindCase", XS_Bio__Emboss_ajStrFindCase, file);
        newXS("Bio::Emboss::ajStrFindK", XS_Bio__Emboss_ajStrFindK, file);
        newXS("Bio::Emboss::ajStrFill", XS_Bio__Emboss_ajStrFill, file);
        newXS("Bio::Emboss::ajStrFix", XS_Bio__Emboss_ajStrFix, file);
        newXS("Bio::Emboss::ajStrFixI", XS_Bio__Emboss_ajStrFixI, file);
        newXS("Bio::Emboss::ajStrFromDoubleE", XS_Bio__Emboss_ajStrFromDoubleE, file);
        newXS("Bio::Emboss::ajStrInsert", XS_Bio__Emboss_ajStrInsert, file);
        newXS("Bio::Emboss::ajStrIsSpace", XS_Bio__Emboss_ajStrIsSpace, file);
        newXS("Bio::Emboss::ajStrIter", XS_Bio__Emboss_ajStrIter, file);
        newXS("Bio::Emboss::ajStrIterBack", XS_Bio__Emboss_ajStrIterBack, file);
        newXS("Bio::Emboss::ajStrIterBackNext", XS_Bio__Emboss_ajStrIterBackNext, file);
        newXS("Bio::Emboss::ajStrIterFree", XS_Bio__Emboss_ajStrIterFree, file);
        newXS("Bio::Emboss::ajStrKeepAlphaC", XS_Bio__Emboss_ajStrKeepAlphaC, file);
        newXS("Bio::Emboss::ajStrKeepC", XS_Bio__Emboss_ajStrKeepC, file);
        newXS("Bio::Emboss::ajStrLen", XS_Bio__Emboss_ajStrLen, file);
        newXS("Bio::Emboss::ajStrListToArray", XS_Bio__Emboss_ajStrListToArray, file);
        newXS("Bio::Emboss::ajStrMatch", XS_Bio__Emboss_ajStrMatch, file);
        newXS("Bio::Emboss::ajStrMatchCase", XS_Bio__Emboss_ajStrMatchCase, file);
        newXS("Bio::Emboss::ajStrMatchCaseCC", XS_Bio__Emboss_ajStrMatchCaseCC, file);
        newXS("Bio::Emboss::ajStrMatchCC", XS_Bio__Emboss_ajStrMatchCC, file);
        newXS("Bio::Emboss::ajStrMatchWild", XS_Bio__Emboss_ajStrMatchWild, file);
        newXS("Bio::Emboss::ajStrMatchWildCC", XS_Bio__Emboss_ajStrMatchWildCC, file);
        newXS("Bio::Emboss::ajStrMatchWildCO", XS_Bio__Emboss_ajStrMatchWildCO, file);
        newXS("Bio::Emboss::ajStrMatchWord", XS_Bio__Emboss_ajStrMatchWord, file);
        newXS("Bio::Emboss::ajStrMatchWordCC", XS_Bio__Emboss_ajStrMatchWordCC, file);
        newXS("Bio::Emboss::ajStrMod", XS_Bio__Emboss_ajStrMod, file);
        newXS("Bio::Emboss::ajStrModL", XS_Bio__Emboss_ajStrModL, file);
        newXS("Bio::Emboss::ajStrModMinL", XS_Bio__Emboss_ajStrModMinL, file);
        newXS("Bio::Emboss::ajStrNCmpC", XS_Bio__Emboss_ajStrNCmpC, file);
        newXS("Bio::Emboss::ajStrNCmpCaseCC", XS_Bio__Emboss_ajStrNCmpCaseCC, file);
        newXS("Bio::Emboss::ajStrNCmpO", XS_Bio__Emboss_ajStrNCmpO, file);
        newXS("Bio::Emboss::ajStrNewCIL", XS_Bio__Emboss_ajStrNewCIL, file);
        newXS("Bio::Emboss::ajStrNewCL", XS_Bio__Emboss_ajStrNewCL, file);
        newXS("Bio::Emboss::ajStrNewL", XS_Bio__Emboss_ajStrNewL, file);
        newXS("Bio::Emboss::ajStrNull", XS_Bio__Emboss_ajStrNull, file);
        newXS("Bio::Emboss::ajStrParentheses", XS_Bio__Emboss_ajStrParentheses, file);
        newXS("Bio::Emboss::ajStrPos", XS_Bio__Emboss_ajStrPos, file);
        newXS("Bio::Emboss::ajStrPosI", XS_Bio__Emboss_ajStrPosI, file);
        newXS("Bio::Emboss::ajStrPosII", XS_Bio__Emboss_ajStrPosII, file);
        newXS("Bio::Emboss::ajStrPrefix", XS_Bio__Emboss_ajStrPrefix, file);
        newXS("Bio::Emboss::ajStrPrefixCC", XS_Bio__Emboss_ajStrPrefixCC, file);
        newXS("Bio::Emboss::ajStrPrefixCase", XS_Bio__Emboss_ajStrPrefixCase, file);
        newXS("Bio::Emboss::ajStrPrefixCaseCC", XS_Bio__Emboss_ajStrPrefixCaseCC, file);
        newXS("Bio::Emboss::ajStrPrefixCaseCO", XS_Bio__Emboss_ajStrPrefixCaseCO, file);
        newXS("Bio::Emboss::ajStrPrefixCO", XS_Bio__Emboss_ajStrPrefixCO, file);
        newXS("Bio::Emboss::ajStrQuote", XS_Bio__Emboss_ajStrQuote, file);
        newXS("Bio::Emboss::ajStrReplace", XS_Bio__Emboss_ajStrReplace, file);
        newXS("Bio::Emboss::ajStrReplaceC", XS_Bio__Emboss_ajStrReplaceC, file);
        newXS("Bio::Emboss::ajStrReplaceK", XS_Bio__Emboss_ajStrReplaceK, file);
        newXS("Bio::Emboss::ajStrReplaceS", XS_Bio__Emboss_ajStrReplaceS, file);
        newXS("Bio::Emboss::ajStrRef", XS_Bio__Emboss_ajStrRef, file);
        newXS("Bio::Emboss::ajStrRemoveCharsC", XS_Bio__Emboss_ajStrRemoveCharsC, file);
        newXS("Bio::Emboss::ajStrRemoveNewline", XS_Bio__Emboss_ajStrRemoveNewline, file);
        newXS("Bio::Emboss::ajStrRev", XS_Bio__Emboss_ajStrRev, file);
        newXS("Bio::Emboss::ajStrRFindC", XS_Bio__Emboss_ajStrRFindC, file);
        newXS("Bio::Emboss::ajStrRoom", XS_Bio__Emboss_ajStrRoom, file);
        newXS("Bio::Emboss::ajStrSet", XS_Bio__Emboss_ajStrSet, file);
        newXS("Bio::Emboss::ajStrSetC", XS_Bio__Emboss_ajStrSetC, file);
        newXS("Bio::Emboss::ajStrSize", XS_Bio__Emboss_ajStrSize, file);
        newXS("Bio::Emboss::ajStrStr", XS_Bio__Emboss_ajStrStr, file);
        newXS("Bio::Emboss::ajStrStrMod", XS_Bio__Emboss_ajStrStrMod, file);
        newXS("Bio::Emboss::ajStrSub", XS_Bio__Emboss_ajStrSub, file);
        newXS("Bio::Emboss::ajStrSubstitute", XS_Bio__Emboss_ajStrSubstitute, file);
        newXS("Bio::Emboss::ajStrSubstituteCC", XS_Bio__Emboss_ajStrSubstituteCC, file);
        newXS("Bio::Emboss::ajStrSubstituteKK", XS_Bio__Emboss_ajStrSubstituteKK, file);
        newXS("Bio::Emboss::ajStrSuffix", XS_Bio__Emboss_ajStrSuffix, file);
        newXS("Bio::Emboss::ajStrSuffixCC", XS_Bio__Emboss_ajStrSuffixCC, file);
        newXS("Bio::Emboss::ajStrSuffixCO", XS_Bio__Emboss_ajStrSuffixCO, file);
        newXS("Bio::Emboss::ajStrTok", XS_Bio__Emboss_ajStrTok, file);
        newXS("Bio::Emboss::ajStrTokC", XS_Bio__Emboss_ajStrTokC, file);
        newXS("Bio::Emboss::ajStrTokCC", XS_Bio__Emboss_ajStrTokCC, file);
        newXS("Bio::Emboss::ajStrToken", XS_Bio__Emboss_ajStrToken, file);
        newXS("Bio::Emboss::ajStrTokenAss", XS_Bio__Emboss_ajStrTokenAss, file);
        newXS("Bio::Emboss::ajStrTokenClear", XS_Bio__Emboss_ajStrTokenClear, file);
        newXS("Bio::Emboss::ajStrTokenCount", XS_Bio__Emboss_ajStrTokenCount, file);
        newXS("Bio::Emboss::ajStrTokenCountR", XS_Bio__Emboss_ajStrTokenCountR, file);
        newXS("Bio::Emboss::ajStrTokenInit", XS_Bio__Emboss_ajStrTokenInit, file);
        newXS("Bio::Emboss::ajStrTokenRest", XS_Bio__Emboss_ajStrTokenRest, file);
        newXS("Bio::Emboss::ajStrToLower", XS_Bio__Emboss_ajStrToLower, file);
        newXS("Bio::Emboss::ajStrToLowerII", XS_Bio__Emboss_ajStrToLowerII, file);
        newXS("Bio::Emboss::ajStrToTitle", XS_Bio__Emboss_ajStrToTitle, file);
        newXS("Bio::Emboss::ajStrToUpper", XS_Bio__Emboss_ajStrToUpper, file);
        newXS("Bio::Emboss::ajStrToUpperII", XS_Bio__Emboss_ajStrToUpperII, file);
        newXS("Bio::Emboss::ajStrTrim", XS_Bio__Emboss_ajStrTrim, file);
        newXS("Bio::Emboss::ajStrTruncate", XS_Bio__Emboss_ajStrTruncate, file);
        newXS("Bio::Emboss::ajStrWildPrefix", XS_Bio__Emboss_ajStrWildPrefix, file);
        newXS("Bio::Emboss::ajStrWrap", XS_Bio__Emboss_ajStrWrap, file);
        newXS("Bio::Emboss::ajStrWrapLeft", XS_Bio__Emboss_ajStrWrapLeft, file);
        newXS("Bio::Emboss::ajStrUncomment", XS_Bio__Emboss_ajStrUncomment, file);
        newXS("Bio::Emboss::ajStrUncommentStart", XS_Bio__Emboss_ajStrUncommentStart, file);

